pub struct MessageConfig { /* private fields */ }Available on
native and crate feature core and crate feature messages only.Expand description
Configuration for message level tags
Implementations
Sourceimpl MessageConfig
impl MessageConfig
Sourcepub fn new() -> MessageConfig
pub fn new() -> MessageConfig
Creates a new MessageConfig with default level tags
Examples
use reinhardt_core::messages::MessageConfig;
let config = MessageConfig::new();
assert_eq!(config.get_tag(reinhardt_core::messages::Level::Info), Some("info"));Sourcepub fn set_tag(&mut self, level: i32, tag: String)
pub fn set_tag(&mut self, level: i32, tag: String)
Sets a custom tag for a specific level value
Examples
use reinhardt_core::messages::MessageConfig;
let mut config = MessageConfig::new();
config.set_tag(42, "custom".to_string());
assert_eq!(config.get_tag(reinhardt_core::messages::Level::Custom(42)), Some("custom"));Sourcepub fn get_tag(&self, level: Level) -> Option<&str>
pub fn get_tag(&self, level: Level) -> Option<&str>
Gets the tag for a specific level
Examples
use reinhardt_core::messages::MessageConfig;
let config = MessageConfig::new();
assert_eq!(config.get_tag(reinhardt_core::messages::Level::Info), Some("info"));
assert_eq!(config.get_tag(reinhardt_core::messages::Level::Custom(99)), None);Gets all configured level tags
Examples
use reinhardt_core::messages::MessageConfig;
let config = MessageConfig::new();
let tags = config.get_all_tags();
assert_eq!(tags.len(), 5);Trait Implementations
Sourceimpl Clone for MessageConfig
impl Clone for MessageConfig
Sourcefn clone(&self) -> MessageConfig
fn clone(&self) -> MessageConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageConfig
impl Debug for MessageConfig
Sourceimpl Default for MessageConfig
impl Default for MessageConfig
Sourcefn default() -> MessageConfig
fn default() -> MessageConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MessageConfig
impl<'de> Deserialize<'de> for MessageConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MessageConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MessageConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for MessageConfig
impl Serialize for MessageConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more