pub enum ValidatorConfig {
Show 15 variants
String(StringValidatorConfig),
Numeric(NumericValidatorConfig),
Email(EmailValidatorConfig),
Url(UrlValidatorConfig),
IpAddress(IpAddressValidatorConfig),
PhoneNumber(PhoneNumberValidatorConfig),
Color(ColorValidatorConfig),
Uuid(UuidValidatorConfig),
Slug(SlugValidatorConfig),
Date(DateTimeValidatorConfig),
Time(DateTimeValidatorConfig),
DateTime(DateTimeValidatorConfig),
FileType(FileTypeValidatorConfig),
FileSize(FileSizeValidatorConfig),
ImageDimension(ImageDimensionValidatorConfig),
}native and crate feature core and crate feature serde and crate feature validators only.Expand description
Unified validator configuration enum
This enum represents all supported validator types and their configurations. It can be serialized to and deserialized from JSON or other formats.
Variants
String(StringValidatorConfig)
String length and pattern validation
Numeric(NumericValidatorConfig)
Numeric range validation
Email(EmailValidatorConfig)
Email format validation
Url(UrlValidatorConfig)
URL format validation
IpAddress(IpAddressValidatorConfig)
IP address validation
PhoneNumber(PhoneNumberValidatorConfig)
Phone number validation
Color(ColorValidatorConfig)
Color format validation
Uuid(UuidValidatorConfig)
UUID format validation
Slug(SlugValidatorConfig)
Slug format validation
Date(DateTimeValidatorConfig)
Date format validation
Time(DateTimeValidatorConfig)
Time format validation
DateTime(DateTimeValidatorConfig)
DateTime format validation
FileType(FileTypeValidatorConfig)
File type validation
FileSize(FileSizeValidatorConfig)
File size validation
ImageDimension(ImageDimensionValidatorConfig)
Image dimension validation
Implementations
Sourceimpl ValidatorConfig
impl ValidatorConfig
Sourcepub fn string() -> StringValidatorConfig
pub fn string() -> StringValidatorConfig
Create a string validator configuration
Sourcepub fn numeric() -> NumericValidatorConfig
pub fn numeric() -> NumericValidatorConfig
Create a numeric validator configuration
Sourcepub fn email() -> EmailValidatorConfig
pub fn email() -> EmailValidatorConfig
Create an email validator configuration
Sourcepub fn url() -> UrlValidatorConfig
pub fn url() -> UrlValidatorConfig
Create a URL validator configuration
Sourcepub fn ip_address() -> IpAddressValidatorConfig
pub fn ip_address() -> IpAddressValidatorConfig
Create an IP address validator configuration
Sourcepub fn phone_number() -> PhoneNumberValidatorConfig
pub fn phone_number() -> PhoneNumberValidatorConfig
Create a phone number validator configuration
Sourcepub fn color() -> ColorValidatorConfig
pub fn color() -> ColorValidatorConfig
Create a color validator configuration
Sourcepub fn uuid() -> UuidValidatorConfig
pub fn uuid() -> UuidValidatorConfig
Create a UUID validator configuration
Sourcepub fn slug() -> SlugValidatorConfig
pub fn slug() -> SlugValidatorConfig
Create a slug validator configuration