#[non_exhaustive]pub enum Schema {
Array(Array),
Object(Object),
OneOf(OneOf),
AllOf(AllOf),
AnyOf(AnyOf),
}Available on crate feature
openapi and non-WebAssembly only.Expand description
Is super type for OpenAPI Schema Object. Schema is reusable resource what can be
referenced from path operations and other components using Ref.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Array(Array)
Defines array schema from another schema. Typically used with
Schema::Object. Slice and Vec types are translated to Schema::Array types.
Object(Object)
Defines object schema. Object is either object holding properties which are other Schemas
or can be a field within the Object.
OneOf(OneOf)
Creates a OneOf type composite Object schema. This schema
is used to map multiple schemas together where API endpoint could return any of them.
Schema::OneOf is created form mixed enum where enum contains various variants.
AllOf(AllOf)
Creates a AllOf type composite Object schema.
AnyOf(AnyOf)
Creates a AnyOf type composite Object schema.