ValidatorError

Enum ValidatorError 

#[non_exhaustive]
pub enum ValidatorError {
Show 38 variants InvalidEmail(String), InvalidUrl(String), TooSmall { value: String, min: String, }, TooLarge { value: String, max: String, }, TooShort { length: usize, min: usize, }, TooLong { length: usize, max: usize, }, PatternMismatch(String), NotUnique { field: String, value: String, }, InvalidSlug(String), InvalidUUID(String), InvalidIPAddress(String), InvalidDate(String), InvalidTime(String), InvalidDateTime(String), InvalidJSON(String), InvalidCreditCard(String), CardTypeNotAllowed { card_type: String, allowed_types: String, }, InvalidPhoneNumber(String), CountryCodeNotAllowed { country_code: String, allowed_countries: String, }, InvalidIBAN(String), IBANCountryNotAllowed { country_code: String, allowed_codes: String, }, InvalidFileExtension { extension: String, allowed_extensions: String, }, InvalidMimeType { mime_type: String, allowed_mime_types: String, }, ForeignKeyNotFound { field: String, value: String, table: String, }, FileSizeTooSmall { size_bytes: u64, min_bytes: u64, }, FileSizeTooLarge { size_bytes: u64, max_bytes: u64, }, AllValidatorsFailed { errors: String, }, CompositeValidationFailed(String), InvalidPostalCode { postal_code: String, }, PostalCodeCountryNotRecognized { postal_code: String, }, PostalCodeCountryNotAllowed { country: String, allowed_countries: String, }, ImageWidthTooSmall { width: u32, min_width: u32, }, ImageWidthTooLarge { width: u32, max_width: u32, }, ImageHeightTooSmall { height: u32, min_height: u32, }, ImageHeightTooLarge { height: u32, max_height: u32, }, InvalidAspectRatio { actual_width: u32, actual_height: u32, expected_width: u32, expected_height: u32, }, ImageReadError(String), Custom(String),
}
Available on crate feature core and non-WebAssembly only.
Validation errors produced by validators.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidEmail(String)

Invalid email address format.



InvalidUrl(String)

Invalid URL format.



TooSmall

Numeric value is below the minimum.

Fields

value: String

The value that was too small.

min: String

The minimum allowed value.



TooLarge

Numeric value exceeds the maximum.

Fields

value: String

The value that was too large.

max: String

The maximum allowed value.



TooShort

String length is below the minimum.

Fields

length: usize

The actual length.

min: usize

The minimum required length.



TooLong

String length exceeds the maximum.

Fields

length: usize

The actual length.

max: usize

The maximum allowed length.



PatternMismatch(String)

Value does not match the expected pattern.



NotUnique

Unique constraint violation.

Fields

field: String

Name of the field with the unique constraint.

value: String

The duplicate value.



InvalidSlug(String)

Invalid slug format.



InvalidUUID(String)

Invalid UUID format.



InvalidIPAddress(String)

Invalid IP address format.



InvalidDate(String)

Invalid date format.



InvalidTime(String)

Invalid time format.



InvalidDateTime(String)

Invalid datetime format.



InvalidJSON(String)

Invalid JSON format.



InvalidCreditCard(String)

Invalid credit card number.



CardTypeNotAllowed

Credit card type is not in the allowed list.

Fields

card_type: String

The detected card type.

allowed_types: String

Comma-separated list of allowed card types.



InvalidPhoneNumber(String)

Invalid phone number format.



CountryCodeNotAllowed

Country code is not in the allowed list.

Fields

country_code: String

The disallowed country code.

allowed_countries: String

Comma-separated list of allowed countries.



InvalidIBAN(String)

Invalid IBAN format.



IBANCountryNotAllowed

IBAN country code is not in the allowed list.

Fields

country_code: String

The disallowed IBAN country code.

allowed_codes: String

Comma-separated list of allowed IBAN country codes.



InvalidFileExtension

File extension is not in the allowed list.

Fields

extension: String

The disallowed file extension.

allowed_extensions: String

Comma-separated list of allowed extensions.



InvalidMimeType

MIME type is not in the allowed list.

Fields

mime_type: String

The disallowed MIME type.

allowed_mime_types: String

Comma-separated list of allowed MIME types.



ForeignKeyNotFound

Foreign key reference does not exist.

Fields

field: String

Name of the foreign key field.

value: String

The value that was not found.

table: String

Name of the referenced table.



FileSizeTooSmall

File size is below the minimum.

Fields

size_bytes: u64

Actual file size in bytes.

min_bytes: u64

Minimum allowed size in bytes.



FileSizeTooLarge

File size exceeds the maximum.

Fields

size_bytes: u64

Actual file size in bytes.

max_bytes: u64

Maximum allowed size in bytes.



AllValidatorsFailed

All validators in an OR composition failed.

Fields

errors: String

Combined error messages from all failed validators.



CompositeValidationFailed(String)

Composite validation failure.



InvalidPostalCode

Invalid postal code format.

Fields

postal_code: String

The invalid postal code.



PostalCodeCountryNotRecognized

Postal code country could not be determined.

Fields

postal_code: String

The postal code whose country was not recognized.



PostalCodeCountryNotAllowed

Postal code country is not in the allowed list.

Fields

country: String

The disallowed country.

allowed_countries: String

Comma-separated list of allowed countries.



ImageWidthTooSmall

Image width is below the minimum.

Fields

width: u32

Actual image width in pixels.

min_width: u32

Minimum required width in pixels.



ImageWidthTooLarge

Image width exceeds the maximum.

Fields

width: u32

Actual image width in pixels.

max_width: u32

Maximum allowed width in pixels.



ImageHeightTooSmall

Image height is below the minimum.

Fields

height: u32

Actual image height in pixels.

min_height: u32

Minimum required height in pixels.



ImageHeightTooLarge

Image height exceeds the maximum.

Fields

height: u32

Actual image height in pixels.

max_height: u32

Maximum allowed height in pixels.



InvalidAspectRatio

Image aspect ratio does not match the expected ratio.

Fields

actual_width: u32

Actual image width.

actual_height: u32

Actual image height.

expected_width: u32

Expected width for the aspect ratio.

expected_height: u32

Expected height for the aspect ratio.



ImageReadError(String)

Failed to read image data.



Custom(String)

Custom validation error with user-defined message.