pub struct ModelFormConfig {
pub fields: Option<Vec<String>>,
pub exclude: Vec<String>,
pub widgets: HashMap<String, Widget>,
pub labels: HashMap<String, String>,
pub help_texts: HashMap<String, String>,
}Available on crate feature
forms and non-WebAssembly only.Expand description
ModelForm configuration
Fields
fields: Option<Vec<String>>Fields to include in the form (None = all fields)
exclude: Vec<String>Fields to exclude from the form
widgets: HashMap<String, Widget>Custom widgets for specific fields
labels: HashMap<String, String>Custom labels for specific fields
help_texts: HashMap<String, String>Custom help text for specific fields
Implementations
Sourceimpl ModelFormConfig
impl ModelFormConfig
Sourcepub fn new() -> ModelFormConfig
pub fn new() -> ModelFormConfig
Creates a new default configuration.
Sourcepub fn fields(self, fields: Vec<String>) -> ModelFormConfig
pub fn fields(self, fields: Vec<String>) -> ModelFormConfig
Sets the list of fields to include in the generated form.
Sourcepub fn exclude(self, exclude: Vec<String>) -> ModelFormConfig
pub fn exclude(self, exclude: Vec<String>) -> ModelFormConfig
Sets the list of fields to exclude from the generated form.
Sourcepub fn widget(self, field: String, widget: Widget) -> ModelFormConfig
pub fn widget(self, field: String, widget: Widget) -> ModelFormConfig
Overrides the widget for a specific field.
Sourcepub fn label(self, field: String, label: String) -> ModelFormConfig
pub fn label(self, field: String, label: String) -> ModelFormConfig
Sets a custom label for a specific field.
Sourcepub fn help_text(self, field: String, text: String) -> ModelFormConfig
pub fn help_text(self, field: String, text: String) -> ModelFormConfig
Sets custom help text for a specific field.