pub enum SchemaType {
Type(Type),
Array(Vec<Type>),
AnyValue,
}Available on crate feature
openapi and native only.Expand description
Variants
Type(Type)
Single type known from OpenAPI spec 3.0
Array(Vec<Type>)
Multiple types rendered as slice
AnyValue
Type that is considered typeless. AnyValue will omit the type definition from the schema
making it to accept any type possible.
Implementations
Sourceimpl SchemaType
impl SchemaType
Sourcepub fn new(type: Type) -> SchemaType
Available on crate feature rest only.
pub fn new(type: Type) -> SchemaType
rest only.Instantiate new SchemaType of given Type
Method accepts one argument type to create SchemaType for.
Examples
Create string SchemaType
let ty = SchemaType::new(Type::String);Sourcepub fn any() -> SchemaType
Available on crate feature rest only.
pub fn any() -> SchemaType
rest only.This is same as calling SchemaType::AnyValue but in a function form () -> SchemaType
allowing it to be used as argument for serde’s default = "...".
Sourcepub fn is_any_value(&self) -> bool
Available on crate feature rest only.
pub fn is_any_value(&self) -> bool
rest only.Check whether this SchemaType is any value (typeless) returning true on any value
schema type.