#[non_exhaustive]pub struct ApiKeyValue {
pub name: String,
pub description: Option<String>,
pub extensions: Option<Extensions>,
}Available on crate feature
openapi and non-WebAssembly only.Expand description
Value object for ApiKey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the ApiKey parameter.
description: Option<String>Description of the the ApiKey SecurityScheme. Supports markdown syntax.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl ApiKeyValue
impl ApiKeyValue
Sourcepub fn new<S>(name: S) -> ApiKeyValue
Available on crate feature rest only.
pub fn new<S>(name: S) -> ApiKeyValue
rest only.Constructs new api key value.
Examples
Create new api key security schema with name api_key.
let api_key = ApiKeyValue::new("api_key");Sourcepub fn with_description<S>(name: S, description: S) -> ApiKeyValue
Available on crate feature rest only.
pub fn with_description<S>(name: S, description: S) -> ApiKeyValue
rest only.Construct a new api key with optional description supporting markdown syntax.
Examples
Create new api key security schema with name api_key with description.
let api_key = ApiKeyValue::with_description("api_key", "my api_key token");Trait Implementations
Sourceimpl Clone for ApiKeyValue
impl Clone for ApiKeyValue
Sourcefn clone(&self) -> ApiKeyValue
fn clone(&self) -> ApiKeyValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ApiKeyValue
impl<'de> Deserialize<'de> for ApiKeyValue
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ApiKeyValue, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ApiKeyValue, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ApiKeyValue
impl PartialEq for ApiKeyValue
Sourceimpl Serialize for ApiKeyValue
impl Serialize for ApiKeyValue
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for ApiKeyValue
impl StructuralPartialEq for ApiKeyValue