Http

Struct Http 

#[non_exhaustive]
pub struct Http { pub scheme: HttpAuthScheme, pub bearer_format: Option<String>, pub description: Option<String>, pub extensions: Option<Extensions>, }
Available on crate feature openapi and non-WebAssembly only.
Http authentication SecurityScheme builder.

Methods can be chained to configure bearer_format or to add description.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
scheme: HttpAuthScheme

Http authorization scheme in HTTP Authorization header value.

bearer_format: Option<String>

Optional hint to client how the bearer token is formatted. Valid only with HttpAuthScheme::Bearer.

description: Option<String>

Optional description of Http SecurityScheme supporting markdown syntax.

extensions: Option<Extensions>

Optional extensions “x-something”.

Implementations

Source

impl Http

pub fn builder() -> HttpBuilder

Available on crate feature rest only.

Construct a new HttpBuilder.

This is effectively same as calling HttpBuilder::new

Source

impl Http

pub fn new(scheme: HttpAuthScheme) -> Http

Available on crate feature rest only.

Create new http authentication security schema.

Accepts one argument which defines the scheme of the http authentication.

Examples

Create http security schema with basic authentication.

SecurityScheme::Http(Http::new(HttpAuthScheme::Basic));