#[non_exhaustive]pub struct MediaType {
pub schema: Option<RefOr<Schema>>,
pub example: Option<Value>,
pub examples: BTreeMap<String, RefOr<Example>>,
pub encoding: BTreeMap<String, Encoding>,
pub extensions: Option<Extensions>,
}openapi and non-WebAssembly only.Expand description
Content holds request body content or response content.
Content implements OpenAPI spec Media Type Object
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema: Option<RefOr<Schema>>Schema used in response body or request body.
example: Option<Value>Example for request body or response body.
examples: BTreeMap<String, RefOr<Example>>Examples of the request body or response body. Content::examples should match to
media type and specified schema if present. Content::examples and
Content::example are mutually exclusive. If both are defined examples will
override value in example.
encoding: BTreeMap<String, Encoding>A map between a property name and its encoding information.
The key, being the property name, MUST exist in the Content::schema as a property, with
schema being a Schema::Object and this object containing the same property key in
Object::properties.
The encoding object SHALL only apply to request_body objects when the media type is
multipart or application/x-www-form-urlencoded.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Content
impl Content
Sourcepub fn builder() -> ContentBuilder
Available on crate feature rest only.
pub fn builder() -> ContentBuilder
rest only.Construct a new ContentBuilder.
This is effectively same as calling ContentBuilder::new