#[non_exhaustive]pub struct Paths {
pub paths: BTreeMap<String, PathItem>,
pub extensions: Option<Extensions>,
}openapi only.Expand description
Implements OpenAPI Paths Object.
Holds relative paths to matching endpoints and operations. The path is appended to the url
from Server object to construct a full url for endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.paths: BTreeMap<String, PathItem>extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Paths
impl Paths
Sourcepub fn builder() -> PathsBuilder
Available on native and crate feature rest only.
pub fn builder() -> PathsBuilder
native and crate feature rest only.Construct a new PathsBuilder.
This is effectively same as calling PathsBuilder::new
Sourceimpl Paths
impl Paths
Sourcepub fn new() -> Paths
Available on native and crate feature rest only.
pub fn new() -> Paths
native and crate feature rest only.Construct a new Paths object.
Sourcepub fn get_path_item<P>(&self, path: P) -> Option<&PathItem>
Available on native and crate feature rest only.
pub fn get_path_item<P>(&self, path: P) -> Option<&PathItem>
native and crate feature rest only.Return Option of reference to PathItem by given relative path P if one exists
in Paths::paths map. Otherwise will return None.
Examples
Get user path item.
let path_item = paths.get_path_item("/api/v1/user");Sourcepub fn get_path_operation<P>(
&self,
path: P,
http_method: HttpMethod,
) -> Option<&Operation>
Available on native and crate feature rest only.
pub fn get_path_operation<P>( &self, path: P, http_method: HttpMethod, ) -> Option<&Operation>
native and crate feature rest only.Return Option of reference to Operation from map of paths or None if not found.
- First will try to find
PathItemby given relative pathPe.g."/api/v1/user". - Then tries to find
OperationfromPathItem’s operations by givenHttpMethod.
Examples
Get user operation from paths.
let operation = paths.get_path_operation("/api/v1/user", HttpMethod::Get);Sourcepub fn add_path_operation<P, O>(
&mut self,
path: P,
http_methods: Vec<HttpMethod>,
operation: O,
)
Available on native and crate feature rest only.
pub fn add_path_operation<P, O>( &mut self, path: P, http_methods: Vec<HttpMethod>, operation: O, )
native and crate feature rest only.Append path operation to the list of paths.
Method accepts three arguments; path to add operation for, http_methods list of
allowed HTTP methods for the Operation and operation to be added under the path.
If path already exists, the provided Operation will be set to existing path item for
given list of HttpMethods.
Sourcepub fn merge(&mut self, other_paths: Paths)
Available on native and crate feature rest only.
pub fn merge(&mut self, other_paths: Paths)
native and crate feature rest only.Merge other_paths into self. On conflicting path the path item operations will be
merged into existing PathItem. Otherwise path with PathItem will be appended to
self. All Extensions will be merged from other_paths into self.