#[non_exhaustive]pub struct Responses {
pub responses: BTreeMap<String, RefOr<Response>>,
pub extensions: Option<Extensions>,
}Available on crate feature
openapi and non-WebAssembly only.Expand description
Implements OpenAPI Responses Object.
Responses is a map holding api operation responses identified by their status code.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.responses: BTreeMap<String, RefOr<Response>>Map containing status code as a key with represented response as a value.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Responses
impl Responses
Sourcepub fn builder() -> ResponsesBuilder
Available on crate feature rest only.
pub fn builder() -> ResponsesBuilder
rest only.Construct a new ResponsesBuilder.
This is effectively same as calling ResponsesBuilder::new