pub enum ArrayType {
Show 24 variants
Bool,
TinyInt,
SmallInt,
Int,
BigInt,
TinyUnsigned,
SmallUnsigned,
Unsigned,
BigUnsigned,
Float,
Double,
String,
Char,
Bytes,
ChronoDate,
ChronoTime,
ChronoDateTime,
ChronoDateTimeUtc,
ChronoDateTimeLocal,
ChronoDateTimeWithTimeZone,
Uuid,
Json,
Decimal,
BigDecimal,
}database and non-WebAssembly only.Expand description
Represents the element type of an array value.
This enum is used to track the type of elements in a SQL array, which is important for proper SQL generation in backends that support typed arrays (e.g., PostgreSQL).
Variants
Bool
Boolean array
TinyInt
8-bit signed integer array
SmallInt
16-bit signed integer array
Int
32-bit signed integer array
BigInt
64-bit signed integer array
TinyUnsigned
8-bit unsigned integer array
SmallUnsigned
16-bit unsigned integer array
Unsigned
32-bit unsigned integer array
BigUnsigned
64-bit unsigned integer array
Float
32-bit floating point array
Double
64-bit floating point array
String
String array
Char
Character array
Bytes
Binary data array
ChronoDate
with-chrono only.Chrono date array
ChronoTime
with-chrono only.Chrono time array
ChronoDateTime
with-chrono only.Chrono datetime array (naive)
ChronoDateTimeUtc
with-chrono only.Chrono datetime array (UTC)
ChronoDateTimeLocal
with-chrono only.Chrono datetime array (Local)
ChronoDateTimeWithTimeZone
with-chrono only.Chrono datetime array (with timezone)
Uuid
with-uuid only.UUID array
Json
with-json only.JSON array
Decimal
with-rust_decimal only.Rust Decimal array
BigDecimal
with-bigdecimal only.BigDecimal array