pub enum ColumnRef {
Column(Arc<dyn Iden>),
TableColumn(Arc<dyn Iden>, Arc<dyn Iden>),
SchemaTableColumn(Arc<dyn Iden>, Arc<dyn Iden>, Arc<dyn Iden>),
Asterisk,
TableAsterisk(Arc<dyn Iden>),
}Available on
native and crate feature database only.Expand description
Reference to a column in a SQL query.
This enum represents different ways to reference a column, from simple column names to fully qualified references.
Variants
Column(Arc<dyn Iden>)
Simple column reference (e.g., name)
TableColumn(Arc<dyn Iden>, Arc<dyn Iden>)
Table-qualified column reference (e.g., users.name)
SchemaTableColumn(Arc<dyn Iden>, Arc<dyn Iden>, Arc<dyn Iden>)
Schema and table-qualified column reference (e.g., public.users.name)
Asterisk
Asterisk for selecting all columns (e.g., *)
TableAsterisk(Arc<dyn Iden>)
Table-qualified asterisk (e.g., users.*)
Implementations
Sourceimpl ColumnRef
impl ColumnRef
Sourcepub fn column<I>(column: I) -> ColumnRefwhere
I: IntoIden,
pub fn column<I>(column: I) -> ColumnRefwhere
I: IntoIden,
Create a simple column reference.
Example
use reinhardt_query::ColumnRef;
let col = ColumnRef::column("name");Sourcepub fn table_column<T, C>(table: T, column: C) -> ColumnRef
pub fn table_column<T, C>(table: T, column: C) -> ColumnRef
Create a table-qualified column reference.
Example
use reinhardt_query::ColumnRef;
let col = ColumnRef::table_column("users", "name");Sourcepub fn schema_table_column<S, T, C>(schema: S, table: T, column: C) -> ColumnRef
pub fn schema_table_column<S, T, C>(schema: S, table: T, column: C) -> ColumnRef
Create a schema and table-qualified column reference.
Example
use reinhardt_query::ColumnRef;
let col = ColumnRef::schema_table_column("public", "users", "name");Sourcepub fn asterisk() -> ColumnRef
pub fn asterisk() -> ColumnRef
Create an asterisk reference for all columns.
Example
use reinhardt_query::ColumnRef;
let col = ColumnRef::asterisk();Sourcepub fn table_asterisk<T>(table: T) -> ColumnRefwhere
T: IntoIden,
pub fn table_asterisk<T>(table: T) -> ColumnRefwhere
T: IntoIden,
Create a table-qualified asterisk reference.
Example
use reinhardt_query::ColumnRef;
let col = ColumnRef::table_asterisk("users");Trait Implementations
Sourceimpl From<ColumnRef> for SimpleExpr
impl From<ColumnRef> for SimpleExpr
Sourcefn from(c: ColumnRef) -> SimpleExpr
fn from(c: ColumnRef) -> SimpleExpr
Converts to this type from the input type.
Sourceimpl IntoColumnRef for ColumnRef
impl IntoColumnRef for ColumnRef
Sourcefn into_column_ref(self) -> ColumnRef
fn into_column_ref(self) -> ColumnRef
Convert this type into a
ColumnRef.Auto Trait Implementations
impl !RefUnwindSafe for ColumnRef
impl !UnwindSafe for ColumnRef
impl Freeze for ColumnRef
impl Send for ColumnRef
impl Sync for ColumnRef
impl Unpin for ColumnRef
impl UnsafeUnpin for ColumnRef