pub struct AttachDatabaseStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
ATTACH DATABASE statement builder (SQLite-specific)
This struct provides a fluent API for constructing ATTACH DATABASE queries. ATTACH DATABASE allows attaching additional database files to the current connection.
Examples
use reinhardt_query::prelude::*;
// ATTACH DATABASE 'path/to/db.sqlite' AS auxiliary
let query = Query::attach_database()
.file_path("path/to/db.sqlite")
.as_name("auxiliary");Implementations
Sourceimpl AttachDatabaseStatement
impl AttachDatabaseStatement
Sourcepub fn new() -> AttachDatabaseStatement
pub fn new() -> AttachDatabaseStatement
Create a new ATTACH DATABASE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::attach_database();Sourcepub fn take(&mut self) -> AttachDatabaseStatement
pub fn take(&mut self) -> AttachDatabaseStatement
Take the ownership of data in the current AttachDatabaseStatement
Sourcepub fn file_path<S>(&mut self, path: S) -> &mut AttachDatabaseStatement
pub fn file_path<S>(&mut self, path: S) -> &mut AttachDatabaseStatement
Set the file path to the database file
Examples
use reinhardt_query::prelude::*;
let query = Query::attach_database()
.file_path("path/to/db.sqlite");Sourcepub fn as_name<N>(&mut self, name: N) -> &mut AttachDatabaseStatementwhere
N: IntoIden,
pub fn as_name<N>(&mut self, name: N) -> &mut AttachDatabaseStatementwhere
N: IntoIden,
Set the alias name for the attached database
Examples
use reinhardt_query::prelude::*;
let query = Query::attach_database()
.file_path("path/to/db.sqlite")
.as_name("auxiliary");Trait Implementations
Sourceimpl Clone for AttachDatabaseStatement
impl Clone for AttachDatabaseStatement
Sourcefn clone(&self) -> AttachDatabaseStatement
fn clone(&self) -> AttachDatabaseStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachDatabaseStatement
impl Debug for AttachDatabaseStatement
Sourceimpl Default for AttachDatabaseStatement
impl Default for AttachDatabaseStatement
Sourcefn default() -> AttachDatabaseStatement
fn default() -> AttachDatabaseStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for AttachDatabaseStatement
impl QueryStatementBuilder for AttachDatabaseStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for AttachDatabaseStatement