pub struct CommentStatement { /* private fields */ }Available on
native and crate feature database only.Expand description
COMMENT ON statement builder
This struct provides a fluent API for constructing COMMENT ON queries.
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::CommentTarget;
// COMMENT ON TABLE "users" IS 'User account information'
let query = Query::comment()
.target(CommentTarget::Table("users".into_iden()))
.comment("User account information");
// COMMENT ON COLUMN "users"."email" IS 'User email address'
let query = Query::comment()
.target(CommentTarget::Column("users".into_iden(), "email".into_iden()))
.comment("User email address");
// COMMENT ON TABLE "users" IS NULL (remove comment)
let query = Query::comment()
.target(CommentTarget::Table("users".into_iden()))
.comment_null();Implementations
Sourceimpl CommentStatement
impl CommentStatement
Sourcepub fn new() -> CommentStatement
pub fn new() -> CommentStatement
Create a new COMMENT ON statement
Examples
use reinhardt_query::prelude::*;
let query = Query::comment();Sourcepub fn take(&mut self) -> CommentStatement
pub fn take(&mut self) -> CommentStatement
Take the ownership of data in the current CommentStatement
Sourcepub fn target(self, target: CommentTarget) -> CommentStatement
pub fn target(self, target: CommentTarget) -> CommentStatement
Set the target object for the comment
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::CommentTarget;
let query = Query::comment()
.target(CommentTarget::Table("users".into_iden()));Sourcepub fn comment<S>(self, comment: S) -> CommentStatement
pub fn comment<S>(self, comment: S) -> CommentStatement
Set the comment text
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::CommentTarget;
let query = Query::comment()
.target(CommentTarget::Table("users".into_iden()))
.comment("User account information");Sourcepub fn comment_null(self) -> CommentStatement
pub fn comment_null(self) -> CommentStatement
Set the comment to NULL (remove comment)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::CommentTarget;
let query = Query::comment()
.target(CommentTarget::Table("users".into_iden()))
.comment_null();Trait Implementations
Sourceimpl Clone for CommentStatement
impl Clone for CommentStatement
Sourcefn clone(&self) -> CommentStatement
fn clone(&self) -> CommentStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommentStatement
impl Debug for CommentStatement
Sourceimpl Default for CommentStatement
impl Default for CommentStatement
Sourcefn default() -> CommentStatement
fn default() -> CommentStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for CommentStatement
impl QueryStatementBuilder for CommentStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for CommentStatement