pub struct CreateDatabaseStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
CREATE DATABASE statement builder
This struct provides a fluent API for constructing CREATE DATABASE queries. It supports both PostgreSQL and MySQL database creation options.
Examples
use reinhardt_query::prelude::*;
// CREATE DATABASE mydb
let query = Query::create_database()
.name("mydb");
// CREATE DATABASE IF NOT EXISTS mydb
let query = Query::create_database()
.name("mydb")
.if_not_exists();
// CREATE DATABASE mydb OWNER alice (PostgreSQL)
let query = Query::create_database()
.name("mydb")
.owner("alice");
// CREATE DATABASE mydb TEMPLATE template0 ENCODING 'UTF8' (PostgreSQL)
let query = Query::create_database()
.name("mydb")
.template("template0")
.encoding("UTF8");
// CREATE DATABASE mydb CHARACTER SET utf8mb4 (MySQL)
let query = Query::create_database()
.name("mydb")
.character_set("utf8mb4");Implementations
Sourceimpl CreateDatabaseStatement
impl CreateDatabaseStatement
Sourcepub fn new() -> CreateDatabaseStatement
pub fn new() -> CreateDatabaseStatement
Create a new CREATE DATABASE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database();Sourcepub fn take(&mut self) -> CreateDatabaseStatement
pub fn take(&mut self) -> CreateDatabaseStatement
Take the ownership of data in the current CreateDatabaseStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut CreateDatabaseStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut CreateDatabaseStatementwhere
N: IntoIden,
Set the database name
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb");Sourcepub fn if_not_exists(&mut self) -> &mut CreateDatabaseStatement
pub fn if_not_exists(&mut self) -> &mut CreateDatabaseStatement
Add IF NOT EXISTS clause
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.if_not_exists();Sourcepub fn owner<O>(&mut self, owner: O) -> &mut CreateDatabaseStatementwhere
O: IntoIden,
pub fn owner<O>(&mut self, owner: O) -> &mut CreateDatabaseStatementwhere
O: IntoIden,
Set OWNER (PostgreSQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.owner("alice");Sourcepub fn template<T>(&mut self, template: T) -> &mut CreateDatabaseStatementwhere
T: IntoIden,
pub fn template<T>(&mut self, template: T) -> &mut CreateDatabaseStatementwhere
T: IntoIden,
Set TEMPLATE database (PostgreSQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.template("template0");Sourcepub fn encoding<S>(&mut self, encoding: S) -> &mut CreateDatabaseStatement
pub fn encoding<S>(&mut self, encoding: S) -> &mut CreateDatabaseStatement
Set ENCODING (PostgreSQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.encoding("UTF8");Sourcepub fn lc_collate<S>(&mut self, lc_collate: S) -> &mut CreateDatabaseStatement
pub fn lc_collate<S>(&mut self, lc_collate: S) -> &mut CreateDatabaseStatement
Set LC_COLLATE (PostgreSQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.lc_collate("en_US.UTF-8");Sourcepub fn lc_ctype<S>(&mut self, lc_ctype: S) -> &mut CreateDatabaseStatement
pub fn lc_ctype<S>(&mut self, lc_ctype: S) -> &mut CreateDatabaseStatement
Set LC_CTYPE (PostgreSQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.lc_ctype("en_US.UTF-8");Sourcepub fn character_set<S>(&mut self, charset: S) -> &mut CreateDatabaseStatement
pub fn character_set<S>(&mut self, charset: S) -> &mut CreateDatabaseStatement
Set CHARACTER SET (MySQL)
Examples
use reinhardt_query::prelude::*;
let query = Query::create_database()
.name("mydb")
.character_set("utf8mb4");Trait Implementations
Sourceimpl Clone for CreateDatabaseStatement
impl Clone for CreateDatabaseStatement
Sourcefn clone(&self) -> CreateDatabaseStatement
fn clone(&self) -> CreateDatabaseStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateDatabaseStatement
impl Debug for CreateDatabaseStatement
Sourceimpl Default for CreateDatabaseStatement
impl Default for CreateDatabaseStatement
Sourcefn default() -> CreateDatabaseStatement
fn default() -> CreateDatabaseStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for CreateDatabaseStatement
impl QueryStatementBuilder for CreateDatabaseStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for CreateDatabaseStatement