pub struct RefreshMaterializedViewStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
REFRESH MATERIALIZED VIEW statement builder
This struct provides a fluent API for constructing REFRESH MATERIALIZED VIEW queries.
Examples
ⓘ
use reinhardt_query::prelude::*;
// Basic refresh
let query = Query::refresh_materialized_view()
.name("my_mv");
// Refresh concurrently
let query = Query::refresh_materialized_view()
.name("my_mv")
.concurrently();
// Refresh with data
let query = Query::refresh_materialized_view()
.name("my_mv")
.with_data(true);Implementations
Sourceimpl RefreshMaterializedViewStatement
impl RefreshMaterializedViewStatement
Sourcepub fn new() -> RefreshMaterializedViewStatement
pub fn new() -> RefreshMaterializedViewStatement
Create a new REFRESH MATERIALIZED VIEW statement
Sourcepub fn take(&mut self) -> RefreshMaterializedViewStatement
pub fn take(&mut self) -> RefreshMaterializedViewStatement
Take the ownership of data in the current statement
Sourcepub fn name<N>(&mut self, name: N) -> &mut RefreshMaterializedViewStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut RefreshMaterializedViewStatementwhere
N: IntoIden,
Sourcepub fn concurrently(&mut self) -> &mut RefreshMaterializedViewStatement
pub fn concurrently(&mut self) -> &mut RefreshMaterializedViewStatement
Sourcepub fn with_data(
&mut self,
with_data: bool,
) -> &mut RefreshMaterializedViewStatement
pub fn with_data( &mut self, with_data: bool, ) -> &mut RefreshMaterializedViewStatement
Set WITH DATA or WITH NO DATA clause
Examples
ⓘ
use reinhardt_query::prelude::*;
// WITH DATA (default behavior)
let query = Query::refresh_materialized_view()
.name("my_mv")
.with_data(true);
// WITH NO DATA (clears the materialized view)
let query = Query::refresh_materialized_view()
.name("my_mv")
.with_data(false);Trait Implementations
Sourceimpl Clone for RefreshMaterializedViewStatement
impl Clone for RefreshMaterializedViewStatement
Sourcefn clone(&self) -> RefreshMaterializedViewStatement
fn clone(&self) -> RefreshMaterializedViewStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RefreshMaterializedViewStatement
impl Default for RefreshMaterializedViewStatement
Sourcefn default() -> RefreshMaterializedViewStatement
fn default() -> RefreshMaterializedViewStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for RefreshMaterializedViewStatement
impl QueryStatementBuilder for RefreshMaterializedViewStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for RefreshMaterializedViewStatement