pub struct AlterFunctionStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
ALTER FUNCTION statement builder
This struct provides a fluent API for constructing ALTER FUNCTION queries.
Examples
use reinhardt_query::prelude::*;
// ALTER FUNCTION my_func RENAME TO new_func
let query = Query::alter_function()
.name("my_func")
.rename_to("new_func");
// ALTER FUNCTION my_func OWNER TO new_owner
let query = Query::alter_function()
.name("my_func")
.owner_to("new_owner");Implementations
Sourceimpl AlterFunctionStatement
impl AlterFunctionStatement
Sourcepub fn new() -> AlterFunctionStatement
pub fn new() -> AlterFunctionStatement
Create a new ALTER FUNCTION statement
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function();Sourcepub fn take(&mut self) -> AlterFunctionStatement
pub fn take(&mut self) -> AlterFunctionStatement
Take the ownership of data in the current AlterFunctionStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
Set the function name
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function()
.name("my_func");Sourcepub fn add_parameter<N, T>(
&mut self,
name: N,
param_type: T,
) -> &mut AlterFunctionStatement
pub fn add_parameter<N, T>( &mut self, name: N, param_type: T, ) -> &mut AlterFunctionStatement
Add a function parameter (for identifying which overloaded function to alter)
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function()
.name("my_func")
.add_parameter("a", "integer")
.rename_to("new_func");Sourcepub fn rename_to<N>(&mut self, new_name: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
pub fn rename_to<N>(&mut self, new_name: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
RENAME TO new_name
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function()
.name("my_func")
.rename_to("new_func");Sourcepub fn owner_to<N>(&mut self, new_owner: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
pub fn owner_to<N>(&mut self, new_owner: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
OWNER TO new_owner
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function()
.name("my_func")
.owner_to("new_owner");Sourcepub fn set_schema<N>(&mut self, new_schema: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
pub fn set_schema<N>(&mut self, new_schema: N) -> &mut AlterFunctionStatementwhere
N: IntoIden,
SET SCHEMA new_schema
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_function()
.name("my_func")
.set_schema("new_schema");Sourcepub fn set_behavior(
&mut self,
behavior: FunctionBehavior,
) -> &mut AlterFunctionStatement
pub fn set_behavior( &mut self, behavior: FunctionBehavior, ) -> &mut AlterFunctionStatement
Set behavior (IMMUTABLE/STABLE/VOLATILE)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::FunctionBehavior;
let query = Query::alter_function()
.name("my_func")
.set_behavior(FunctionBehavior::Immutable);Sourcepub fn set_security(
&mut self,
security: FunctionSecurity,
) -> &mut AlterFunctionStatement
pub fn set_security( &mut self, security: FunctionSecurity, ) -> &mut AlterFunctionStatement
Set security (DEFINER/INVOKER)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::FunctionSecurity;
let query = Query::alter_function()
.name("my_func")
.set_security(FunctionSecurity::Definer);Trait Implementations
Sourceimpl Clone for AlterFunctionStatement
impl Clone for AlterFunctionStatement
Sourcefn clone(&self) -> AlterFunctionStatement
fn clone(&self) -> AlterFunctionStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlterFunctionStatement
impl Debug for AlterFunctionStatement
Sourceimpl Default for AlterFunctionStatement
impl Default for AlterFunctionStatement
Sourcefn default() -> AlterFunctionStatement
fn default() -> AlterFunctionStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for AlterFunctionStatement
impl QueryStatementBuilder for AlterFunctionStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for AlterFunctionStatement