pub struct AlterTypeStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
ALTER TYPE statement builder
This struct provides a fluent API for constructing ALTER TYPE queries.
Examples
use reinhardt_query::prelude::*;
// ALTER TYPE mood RENAME TO feeling
let query = Query::alter_type()
.name("mood")
.rename_to("feeling");
// ALTER TYPE mood ADD VALUE 'excited' BEFORE 'happy'
let query = Query::alter_type()
.name("mood")
.add_value("excited", Some("happy"));
// ALTER TYPE mood RENAME VALUE 'happy' TO 'joyful'
let query = Query::alter_type()
.name("mood")
.rename_value("happy", "joyful");Implementations
Sourceimpl AlterTypeStatement
impl AlterTypeStatement
Sourcepub fn new() -> AlterTypeStatement
pub fn new() -> AlterTypeStatement
Create a new ALTER TYPE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type();Sourcepub fn take(&mut self) -> AlterTypeStatement
pub fn take(&mut self) -> AlterTypeStatement
Take the ownership of data in the current AlterTypeStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut AlterTypeStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut AlterTypeStatementwhere
N: IntoIden,
Set the type name
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_type");Sourcepub fn rename_to<N>(&mut self, new_name: N) -> &mut AlterTypeStatementwhere
N: IntoIden,
pub fn rename_to<N>(&mut self, new_name: N) -> &mut AlterTypeStatementwhere
N: IntoIden,
Add RENAME TO operation
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("old_name")
.rename_to("new_name");Sourcepub fn owner_to<O>(&mut self, owner: O) -> &mut AlterTypeStatementwhere
O: IntoIden,
pub fn owner_to<O>(&mut self, owner: O) -> &mut AlterTypeStatementwhere
O: IntoIden,
Add OWNER TO operation
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_type")
.owner_to("new_owner");Sourcepub fn set_schema<S>(&mut self, schema: S) -> &mut AlterTypeStatementwhere
S: IntoIden,
pub fn set_schema<S>(&mut self, schema: S) -> &mut AlterTypeStatementwhere
S: IntoIden,
Add SET SCHEMA operation
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_type")
.set_schema("new_schema");Sourcepub fn add_value(
&mut self,
value: &str,
before_after: Option<&str>,
) -> &mut AlterTypeStatement
pub fn add_value( &mut self, value: &str, before_after: Option<&str>, ) -> &mut AlterTypeStatement
Add VALUE to ENUM type (optionally before/after existing value)
Examples
use reinhardt_query::prelude::*;
// ADD VALUE 'excited'
let query = Query::alter_type()
.name("mood")
.add_value("excited", None);
// ADD VALUE 'excited' BEFORE 'happy'
let query = Query::alter_type()
.name("mood")
.add_value("excited", Some("happy"));Sourcepub fn rename_value(
&mut self,
old_value: &str,
new_value: &str,
) -> &mut AlterTypeStatement
pub fn rename_value( &mut self, old_value: &str, new_value: &str, ) -> &mut AlterTypeStatement
Rename an ENUM value
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("mood")
.rename_value("happy", "joyful");Sourcepub fn add_constraint(
&mut self,
name: &str,
check: &str,
) -> &mut AlterTypeStatement
pub fn add_constraint( &mut self, name: &str, check: &str, ) -> &mut AlterTypeStatement
Add constraint to DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_domain")
.add_constraint("positive_check", "CHECK (VALUE > 0)");Sourcepub fn drop_constraint(
&mut self,
name: &str,
if_exists: bool,
) -> &mut AlterTypeStatement
pub fn drop_constraint( &mut self, name: &str, if_exists: bool, ) -> &mut AlterTypeStatement
Drop constraint from DOMAIN type
Examples
use reinhardt_query::prelude::*;
// DROP CONSTRAINT my_constraint
let query = Query::alter_type()
.name("my_domain")
.drop_constraint("my_constraint", false);
// DROP CONSTRAINT IF EXISTS my_constraint
let query = Query::alter_type()
.name("my_domain")
.drop_constraint("my_constraint", true);Sourcepub fn set_default(&mut self, value: &str) -> &mut AlterTypeStatement
pub fn set_default(&mut self, value: &str) -> &mut AlterTypeStatement
Set default value for DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_domain")
.set_default("0");Sourcepub fn drop_default(&mut self) -> &mut AlterTypeStatement
pub fn drop_default(&mut self) -> &mut AlterTypeStatement
Drop default value from DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_domain")
.drop_default();Sourcepub fn set_not_null(&mut self) -> &mut AlterTypeStatement
pub fn set_not_null(&mut self) -> &mut AlterTypeStatement
Set NOT NULL for DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_domain")
.set_not_null();Sourcepub fn drop_not_null(&mut self) -> &mut AlterTypeStatement
pub fn drop_not_null(&mut self) -> &mut AlterTypeStatement
Drop NOT NULL from DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_type()
.name("my_domain")
.drop_not_null();Trait Implementations
Sourceimpl Clone for AlterTypeStatement
impl Clone for AlterTypeStatement
Sourcefn clone(&self) -> AlterTypeStatement
fn clone(&self) -> AlterTypeStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlterTypeStatement
impl Debug for AlterTypeStatement
Sourceimpl Default for AlterTypeStatement
impl Default for AlterTypeStatement
Sourcefn default() -> AlterTypeStatement
fn default() -> AlterTypeStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for AlterTypeStatement
impl QueryStatementBuilder for AlterTypeStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for AlterTypeStatement