pub struct CreateProcedureStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
CREATE PROCEDURE statement builder
This struct provides a fluent API for constructing CREATE PROCEDURE queries.
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::{FunctionLanguage, FunctionBehavior};
// CREATE PROCEDURE my_proc() LANGUAGE SQL AS 'SELECT 1'
let query = Query::create_procedure()
.name("my_proc")
.language(FunctionLanguage::Sql)
.body("SELECT 1");
// CREATE OR REPLACE PROCEDURE my_proc(a integer)
// LANGUAGE PLPGSQL IMMUTABLE AS 'BEGIN INSERT INTO log VALUES (a); END;'
let query = Query::create_procedure()
.name("my_proc")
.or_replace()
.add_parameter("a", "integer")
.language(FunctionLanguage::PlPgSql)
.behavior(FunctionBehavior::Immutable)
.body("BEGIN INSERT INTO log VALUES (a); END;");Implementations
Sourceimpl CreateProcedureStatement
impl CreateProcedureStatement
Sourcepub fn new() -> CreateProcedureStatement
pub fn new() -> CreateProcedureStatement
Create a new CREATE PROCEDURE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::create_procedure();Sourcepub fn take(&mut self) -> CreateProcedureStatement
pub fn take(&mut self) -> CreateProcedureStatement
Take the ownership of data in the current CreateProcedureStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut CreateProcedureStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut CreateProcedureStatementwhere
N: IntoIden,
Set the procedure name
Examples
use reinhardt_query::prelude::*;
let query = Query::create_procedure()
.name("my_proc");Sourcepub fn or_replace(&mut self) -> &mut CreateProcedureStatement
pub fn or_replace(&mut self) -> &mut CreateProcedureStatement
Add OR REPLACE clause
Examples
use reinhardt_query::prelude::*;
let query = Query::create_procedure()
.name("my_proc")
.or_replace();Sourcepub fn add_parameter<N, T>(
&mut self,
name: N,
param_type: T,
) -> &mut CreateProcedureStatement
pub fn add_parameter<N, T>( &mut self, name: N, param_type: T, ) -> &mut CreateProcedureStatement
Add a procedure parameter
Examples
use reinhardt_query::prelude::*;
let query = Query::create_procedure()
.name("my_proc")
.add_parameter("param1", "integer")
.add_parameter("param2", "text");Sourcepub fn language(
&mut self,
language: FunctionLanguage,
) -> &mut CreateProcedureStatement
pub fn language( &mut self, language: FunctionLanguage, ) -> &mut CreateProcedureStatement
Set LANGUAGE
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::FunctionLanguage;
let query = Query::create_procedure()
.name("my_proc")
.language(FunctionLanguage::PlPgSql);Sourcepub fn behavior(
&mut self,
behavior: FunctionBehavior,
) -> &mut CreateProcedureStatement
pub fn behavior( &mut self, behavior: FunctionBehavior, ) -> &mut CreateProcedureStatement
Set procedure behavior (IMMUTABLE/STABLE/VOLATILE)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::FunctionBehavior;
let query = Query::create_procedure()
.name("my_proc")
.behavior(FunctionBehavior::Immutable);Sourcepub fn security(
&mut self,
security: FunctionSecurity,
) -> &mut CreateProcedureStatement
pub fn security( &mut self, security: FunctionSecurity, ) -> &mut CreateProcedureStatement
Set security context (DEFINER/INVOKER)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::function::FunctionSecurity;
let query = Query::create_procedure()
.name("my_proc")
.security(FunctionSecurity::Definer);Trait Implementations
Sourceimpl Clone for CreateProcedureStatement
impl Clone for CreateProcedureStatement
Sourcefn clone(&self) -> CreateProcedureStatement
fn clone(&self) -> CreateProcedureStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateProcedureStatement
impl Debug for CreateProcedureStatement
Sourceimpl Default for CreateProcedureStatement
impl Default for CreateProcedureStatement
Sourcefn default() -> CreateProcedureStatement
fn default() -> CreateProcedureStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for CreateProcedureStatement
impl QueryStatementBuilder for CreateProcedureStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for CreateProcedureStatement