pub struct CreateTableStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
CREATE TABLE statement builder
This struct provides a fluent API for constructing CREATE TABLE queries.
Examples
ⓘ
use reinhardt_query::prelude::*;
use reinhardt_query::types::ddl::ColumnType;
let query = Query::create_table()
.table("users")
.if_not_exists()
.col(
ColumnDef::new("id")
.column_type(ColumnType::Integer)
.primary_key(true)
.auto_increment(true)
)
.col(
ColumnDef::new("name")
.column_type(ColumnType::String(Some(100)))
.not_null(true)
);Implementations
Sourceimpl CreateTableStatement
impl CreateTableStatement
Sourcepub fn new() -> CreateTableStatement
pub fn new() -> CreateTableStatement
Create a new CREATE TABLE statement
Sourcepub fn take(&mut self) -> CreateTableStatement
pub fn take(&mut self) -> CreateTableStatement
Take the ownership of data in the current CreateTableStatement
Sourcepub fn table<T>(&mut self, tbl: T) -> &mut CreateTableStatementwhere
T: IntoTableRef,
pub fn table<T>(&mut self, tbl: T) -> &mut CreateTableStatementwhere
T: IntoTableRef,
Sourcepub fn if_not_exists(&mut self) -> &mut CreateTableStatement
pub fn if_not_exists(&mut self) -> &mut CreateTableStatement
Sourcepub fn col(&mut self, column: ColumnDef) -> &mut CreateTableStatement
pub fn col(&mut self, column: ColumnDef) -> &mut CreateTableStatement
Sourcepub fn cols<I>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = ColumnDef>,
pub fn cols<I>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = ColumnDef>,
Add multiple column definitions
Examples
ⓘ
use reinhardt_query::prelude::*;
use reinhardt_query::types::ddl::{ColumnDef, ColumnType};
let query = Query::create_table()
.table("users")
.cols(vec![
ColumnDef::new("id").column_type(ColumnType::Integer),
ColumnDef::new("name").column_type(ColumnType::String(Some(100))),
]);Sourcepub fn constraint(
&mut self,
constraint: TableConstraint,
) -> &mut CreateTableStatement
pub fn constraint( &mut self, constraint: TableConstraint, ) -> &mut CreateTableStatement
Sourcepub fn constraints<I>(&mut self, constraints: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = TableConstraint>,
pub fn constraints<I>(&mut self, constraints: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = TableConstraint>,
Add multiple table constraints
Examples
ⓘ
use reinhardt_query::prelude::*;
use reinhardt_query::types::ddl::TableConstraint;
let query = Query::create_table()
.table("order_items")
.constraints(vec![
TableConstraint::PrimaryKey {
name: None,
columns: vec!["order_id".into(), "item_id".into()],
},
TableConstraint::ForeignKey {
name: Some("fk_order".into()),
columns: vec!["order_id".into()],
ref_table: Box::new("orders".into()),
ref_columns: vec!["id".into()],
on_delete: None,
on_update: None,
},
]);Sourcepub fn index(&mut self, index: IndexDef) -> &mut CreateTableStatement
pub fn index(&mut self, index: IndexDef) -> &mut CreateTableStatement
Sourcepub fn indexes<I>(&mut self, indexes: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = IndexDef>,
pub fn indexes<I>(&mut self, indexes: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = IndexDef>,
Add multiple index definitions
Sourcepub fn comment<S>(&mut self, comment: S) -> &mut CreateTableStatement
pub fn comment<S>(&mut self, comment: S) -> &mut CreateTableStatement
Sourcepub fn primary_key<I, C>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = C>,
C: IntoIden,
pub fn primary_key<I, C>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = C>,
C: IntoIden,
Sourcepub fn unique<I, C>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = C>,
C: IntoIden,
pub fn unique<I, C>(&mut self, columns: I) -> &mut CreateTableStatementwhere
I: IntoIterator<Item = C>,
C: IntoIden,
Sourcepub fn foreign_key<I1, C1, T, I2, C2>(
&mut self,
columns: I1,
ref_table: T,
ref_columns: I2,
on_delete: Option<ForeignKeyAction>,
on_update: Option<ForeignKeyAction>,
) -> &mut CreateTableStatementwhere
I1: IntoIterator<Item = C1>,
C1: IntoIden,
T: IntoTableRef,
I2: IntoIterator<Item = C2>,
C2: IntoIden,
pub fn foreign_key<I1, C1, T, I2, C2>(
&mut self,
columns: I1,
ref_table: T,
ref_columns: I2,
on_delete: Option<ForeignKeyAction>,
on_update: Option<ForeignKeyAction>,
) -> &mut CreateTableStatementwhere
I1: IntoIterator<Item = C1>,
C1: IntoIden,
T: IntoTableRef,
I2: IntoIterator<Item = C2>,
C2: IntoIden,
Add a foreign key constraint
This is a convenience method for adding a FOREIGN KEY constraint.
Examples
ⓘ
use reinhardt_query::prelude::*;
use reinhardt_query::types::ddl::ForeignKeyAction;
let query = Query::create_table()
.table("posts")
.foreign_key(
vec!["user_id"],
"users",
vec!["id"],
Some(ForeignKeyAction::Cascade),
None,
);Sourcepub fn foreign_key_from_builder(
&mut self,
fk: &mut ForeignKeyCreateStatement,
) -> &mut CreateTableStatement
pub fn foreign_key_from_builder( &mut self, fk: &mut ForeignKeyCreateStatement, ) -> &mut CreateTableStatement
Add a foreign key constraint from a ForeignKeyCreateStatement builder.
This method accepts the builder-pattern style used by
ForeignKey::create().
Examples
ⓘ
use reinhardt_query::prelude::*;
let mut fk = ForeignKey::create();
fk.from_tbl(Alias::new("posts"))
.from_col(Alias::new("user_id"))
.to_tbl(Alias::new("users"))
.to_col(Alias::new("id"));
let mut stmt = Query::create_table();
stmt.table("posts")
.foreign_key_from_builder(&mut fk);Trait Implementations
Sourceimpl Clone for CreateTableStatement
impl Clone for CreateTableStatement
Sourcefn clone(&self) -> CreateTableStatement
fn clone(&self) -> CreateTableStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTableStatement
impl Debug for CreateTableStatement
Sourceimpl Default for CreateTableStatement
impl Default for CreateTableStatement
Sourcefn default() -> CreateTableStatement
fn default() -> CreateTableStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for CreateTableStatement
impl QueryStatementBuilder for CreateTableStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for CreateTableStatement