pub struct CreateTypeStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
CREATE TYPE statement builder
This struct provides a fluent API for constructing CREATE TYPE queries.
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::type_def::TypeKind;
// CREATE TYPE mood AS ENUM ('happy', 'sad', 'neutral')
let query = Query::create_type()
.name("mood")
.as_enum(vec!["happy".to_string(), "sad".to_string(), "neutral".to_string()]);
// CREATE TYPE address AS (street text, city text, zip integer)
let query = Query::create_type()
.name("address")
.as_composite(vec![
("street".to_string(), "text".to_string()),
("city".to_string(), "text".to_string()),
("zip".to_string(), "integer".to_string()),
]);Implementations
Sourceimpl CreateTypeStatement
impl CreateTypeStatement
Sourcepub fn new() -> CreateTypeStatement
pub fn new() -> CreateTypeStatement
Create a new CREATE TYPE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type();Sourcepub fn take(&mut self) -> CreateTypeStatement
pub fn take(&mut self) -> CreateTypeStatement
Take the ownership of data in the current CreateTypeStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut CreateTypeStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut CreateTypeStatementwhere
N: IntoIden,
Set the type name
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("my_type");Sourcepub fn as_enum(&mut self, values: Vec<String>) -> &mut CreateTypeStatement
pub fn as_enum(&mut self, values: Vec<String>) -> &mut CreateTypeStatement
Create an ENUM type with the given values
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("mood")
.as_enum(vec!["happy".to_string(), "sad".to_string()]);Sourcepub fn as_composite(
&mut self,
attributes: Vec<(String, String)>,
) -> &mut CreateTypeStatement
pub fn as_composite( &mut self, attributes: Vec<(String, String)>, ) -> &mut CreateTypeStatement
Create a COMPOSITE type with the given attributes
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("address")
.as_composite(vec![
("street".to_string(), "text".to_string()),
("city".to_string(), "text".to_string()),
]);Sourcepub fn as_domain(&mut self, base_type: String) -> &mut CreateTypeStatement
pub fn as_domain(&mut self, base_type: String) -> &mut CreateTypeStatement
Create a DOMAIN type with the given base type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("positive_int")
.as_domain("integer".to_string())
.constraint("positive_check".to_string(), "CHECK (VALUE > 0)".to_string());Sourcepub fn constraint(
&mut self,
_name: String,
check: String,
) -> &mut CreateTypeStatement
pub fn constraint( &mut self, _name: String, check: String, ) -> &mut CreateTypeStatement
Add a constraint to a DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("positive_int")
.as_domain("integer".to_string())
.constraint("positive_check".to_string(), "CHECK (VALUE > 0)".to_string());Sourcepub fn default_value(&mut self, default: String) -> &mut CreateTypeStatement
pub fn default_value(&mut self, default: String) -> &mut CreateTypeStatement
Set the default value for a DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("my_domain")
.as_domain("integer".to_string())
.default_value("0".to_string());Sourcepub fn not_null(&mut self) -> &mut CreateTypeStatement
pub fn not_null(&mut self) -> &mut CreateTypeStatement
Set NOT NULL for a DOMAIN type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("my_domain")
.as_domain("integer".to_string())
.not_null();Sourcepub fn as_range(&mut self, subtype: String) -> &mut CreateTypeStatement
pub fn as_range(&mut self, subtype: String) -> &mut CreateTypeStatement
Create a RANGE type with the given subtype
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("int_range")
.as_range("integer".to_string());Sourcepub fn subtype_diff(&mut self, subtype_diff: String) -> &mut CreateTypeStatement
pub fn subtype_diff(&mut self, subtype_diff: String) -> &mut CreateTypeStatement
Set the subtype diff function for a RANGE type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("int_range")
.as_range("integer".to_string())
.subtype_diff("int4range_subdiff".to_string());Sourcepub fn canonical(&mut self, canonical: String) -> &mut CreateTypeStatement
pub fn canonical(&mut self, canonical: String) -> &mut CreateTypeStatement
Set the canonical function for a RANGE type
Examples
use reinhardt_query::prelude::*;
let query = Query::create_type()
.name("int_range")
.as_range("integer".to_string())
.canonical("int4range_canonical".to_string());Trait Implementations
Sourceimpl Clone for CreateTypeStatement
impl Clone for CreateTypeStatement
Sourcefn clone(&self) -> CreateTypeStatement
fn clone(&self) -> CreateTypeStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTypeStatement
impl Debug for CreateTypeStatement
Sourceimpl Default for CreateTypeStatement
impl Default for CreateTypeStatement
Sourcefn default() -> CreateTypeStatement
fn default() -> CreateTypeStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for CreateTypeStatement
impl QueryStatementBuilder for CreateTypeStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for CreateTypeStatement