pub struct DropFunctionStatement { /* private fields */ }Available on crate feature
database and non-WebAssembly only.Expand description
DROP FUNCTION statement builder
This struct provides a fluent API for constructing DROP FUNCTION queries.
Examples
use reinhardt_query::prelude::*;
// DROP FUNCTION my_func
let query = Query::drop_function()
.name("my_func");
// DROP FUNCTION IF EXISTS my_func(integer) CASCADE
let query = Query::drop_function()
.name("my_func")
.if_exists()
.add_parameter("", "integer")
.cascade();Implementations
Sourceimpl DropFunctionStatement
impl DropFunctionStatement
Sourcepub fn new() -> DropFunctionStatement
pub fn new() -> DropFunctionStatement
Create a new DROP FUNCTION statement
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_function();Sourcepub fn take(&mut self) -> DropFunctionStatement
pub fn take(&mut self) -> DropFunctionStatement
Take the ownership of data in the current DropFunctionStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut DropFunctionStatementwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut DropFunctionStatementwhere
N: IntoIden,
Set the function name
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_function()
.name("my_func");Sourcepub fn add_parameter<N, T>(
&mut self,
name: N,
param_type: T,
) -> &mut DropFunctionStatement
pub fn add_parameter<N, T>( &mut self, name: N, param_type: T, ) -> &mut DropFunctionStatement
Add a function parameter (for identifying which overloaded function to drop)
Examples
use reinhardt_query::prelude::*;
// DROP FUNCTION my_func(integer, text)
let query = Query::drop_function()
.name("my_func")
.add_parameter("", "integer")
.add_parameter("", "text");Sourcepub fn if_exists(&mut self) -> &mut DropFunctionStatement
pub fn if_exists(&mut self) -> &mut DropFunctionStatement
Add IF EXISTS clause
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_function()
.name("my_func")
.if_exists();Sourcepub fn cascade(&mut self) -> &mut DropFunctionStatement
pub fn cascade(&mut self) -> &mut DropFunctionStatement
Add CASCADE clause
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_function()
.name("my_func")
.cascade();Trait Implementations
Sourceimpl Clone for DropFunctionStatement
impl Clone for DropFunctionStatement
Sourcefn clone(&self) -> DropFunctionStatement
fn clone(&self) -> DropFunctionStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DropFunctionStatement
impl Debug for DropFunctionStatement
Sourceimpl Default for DropFunctionStatement
impl Default for DropFunctionStatement
Sourcefn default() -> DropFunctionStatement
fn default() -> DropFunctionStatement
Returns the “default value” for a type. Read more
Sourceimpl QueryStatementBuilder for DropFunctionStatement
impl QueryStatementBuilder for DropFunctionStatement
Sourcefn build_any(
&self,
query_builder: &(dyn QueryBuilderTrait + 'static),
) -> (String, Values)
fn build_any( &self, query_builder: &(dyn QueryBuilderTrait + 'static), ) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for DropFunctionStatement