InsertStatement

Struct InsertStatement 

pub struct InsertStatement { /* private fields */ }
Available on crate feature database and non-WebAssembly only.
INSERT statement builder

This struct provides a fluent API for constructing INSERT queries.

Examples

use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .values_panic(["Alice", "alice@example.com"])
    .values_panic(["Bob", "bob@example.com"]);

Implementations

Source

impl InsertStatement

pub fn new() -> InsertStatement

Create a new INSERT statement

pub fn take(&mut self) -> InsertStatement

Take the ownership of data in the current InsertStatement

pub fn into_table<T>(&mut self, tbl: T) -> &mut InsertStatement
where T: IntoTableRef,

Set the table to insert into

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users");
pub fn column<C>(&mut self, col: C) -> &mut InsertStatement
where C: IntoIden,

Add a column to insert into

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .column("name")
    .column("email");
pub fn columns<I, C>(&mut self, cols: I) -> &mut InsertStatement
where I: IntoIterator<Item = C>, C: IntoIden,

Add multiple columns to insert into

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email", "created_at"]);
pub fn values( &mut self, values: Vec<Value>, ) -> Result<&mut InsertStatement, String>

Add values for the columns

Returns Err if the number of values doesn’t match the number of columns.

Examples
use reinhardt_query::prelude::*;

let result = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .values(vec!["Alice".into(), "alice@example.com".into()]);
pub fn values_panic<I, V>(&mut self, values: I) -> &mut InsertStatement
where I: IntoIterator<Item = V>, V: IntoValue,

Add values for the columns (panics on mismatch)

Panics

Panics if the number of values doesn’t match the number of columns.

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .values_panic(["Alice", "alice@example.com"])
    .values_panic(["Bob", "bob@example.com"]);
pub fn returning<I, C>(&mut self, cols: I) -> &mut InsertStatement
where I: IntoIterator<Item = C>, C: IntoColumnRef,

Add a RETURNING clause with multiple columns

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .values_panic(["Alice", "alice@example.com"])
    .returning(["id", "created_at"]);
pub fn returning_col<C>(&mut self, col: C) -> &mut InsertStatement
where C: IntoColumnRef,

Add a RETURNING clause for a single column

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name"])
    .values_panic(["Alice"])
    .returning_col(Alias::new("id"));
pub fn on_conflict(&mut self, on_conflict: OnConflict) -> &mut InsertStatement

Set ON CONFLICT clause for upsert behavior.

Examples
use reinhardt_query::prelude::*;
use reinhardt_query::query::OnConflict;

let query = Query::insert()
    .into_table("users")
    .columns(["id", "name"])
    .values_panic([1, "Alice"])
    .on_conflict(OnConflict::column("id").update_columns(["name"]));
pub fn returning_all(&mut self) -> &mut InsertStatement

Add a RETURNING * clause

Examples
use reinhardt_query::prelude::*;

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .values_panic(["Alice", "alice@example.com"])
    .returning_all();
pub fn from_subquery(&mut self, select: SelectStatement) -> &mut InsertStatement

Use a subquery as the data source for INSERT

Examples
use reinhardt_query::prelude::*;

let select = Query::select()
    .column("name")
    .column("email")
    .from("temp_users");

let query = Query::insert()
    .into_table("users")
    .columns(["name", "email"])
    .from_subquery(select);
pub fn get_values(&self) -> Option<&Vec<Vec<Value>>>

Get the values if this is a VALUES source

Returns None if the source is a subquery.