pub struct OrderExpr {
pub expr: OrderExprKind,
pub order: Order,
pub nulls: Option<NullOrdering>,
}Available on
native and crate feature database only.Expand description
An expression with its ordering specification.
This represents a single item in an ORDER BY clause.
Fields
expr: OrderExprKindThe expression to order by (column or expression)
order: OrderThe ordering direction
nulls: Option<NullOrdering>Optional NULL ordering
Implementations
Sourceimpl OrderExpr
impl OrderExpr
Sourcepub fn new<I>(column: I) -> OrderExprwhere
I: IntoIden,
pub fn new<I>(column: I) -> OrderExprwhere
I: IntoIden,
Create a new order expression for a column with the default order (ASC).
Sourcepub fn new_table_column<T, C>(table: T, column: C) -> OrderExpr
pub fn new_table_column<T, C>(table: T, column: C) -> OrderExpr
Create a new order expression for a qualified column.
Sourcepub fn nulls(self, nulls: NullOrdering) -> OrderExpr
pub fn nulls(self, nulls: NullOrdering) -> OrderExpr
Set NULL ordering.