Error

Struct Error 

pub struct Error { /* private fields */ }
Available on crate feature openapi only.
This type represents all possible errors that can occur when serializing or deserializing JSON data.

Implementations

Source

impl Error

pub fn line(&self) -> usize

Available on native and crate feature serde only.

One-based line number at which the error was detected.

Characters in the first line of the input (before the first newline character) are in line 1.

pub fn column(&self) -> usize

Available on native and crate feature serde only.

One-based column number at which the error was detected.

The first character in the input and any characters immediately following a newline character are in column 1.

Note that errors may occur in column 0, for example if a read from an I/O stream fails immediately following a previously read newline character.

pub fn classify(&self) -> Category

Available on native and crate feature serde only.

Categorizes the cause of this error.

  • Category::Io - failure to read or write bytes on an I/O stream
  • Category::Syntax - input that is not syntactically valid JSON
  • Category::Data - input data that is semantically incorrect
  • Category::Eof - unexpected end of the input data
pub fn is_io(&self) -> bool

Available on native and crate feature serde only.

Returns true if this error was caused by a failure to read or write bytes on an I/O stream.

pub fn is_syntax(&self) -> bool

Available on native and crate feature serde only.

Returns true if this error was caused by input that was not syntactically valid JSON.

pub fn is_data(&self) -> bool

Available on native and crate feature serde only.

Returns true if this error was caused by input data that was semantically incorrect.

For example, JSON containing a number is semantically incorrect when the type being deserialized into holds a String.

pub fn is_eof(&self) -> bool

Available on native and crate feature serde only.

Returns true if this error was caused by prematurely reaching the end of the input data.

Callers that process streaming input may be interested in retrying the deserialization once more data is available.

pub fn io_error_kind(&self) -> Option<ErrorKind>

Available on native and crate feature serde and crate feature std only.

The kind reported by the underlying standard library I/O error, if this error was caused by a failure to read or write bytes on an I/O stream.

Example
use serde_json::Value;
use std::io::{self, ErrorKind, Read};
use std::process;

struct ReaderThatWillTimeOut<'a>(&'a [u8]);

impl<'a> Read for ReaderThatWillTimeOut<'a> {
    fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
        if self.0.is_empty() {
            Err(io::Error::new(ErrorKind::TimedOut, "timed out"))
        } else {
            self.0.read(buf)
        }
    }
}

fn main() {
    let reader = ReaderThatWillTimeOut(br#" {"k": "#);

    let _: Value = match serde_json::from_reader(reader) {
        Ok(value) => value,
        Err(error) => {
            if error.io_error_kind() == Some(ErrorKind::TimedOut) {
                // Maybe this application needs to retry certain kinds of errors.

            } else {
                eprintln!("error: {}", error);
                process::exit(1);
            }
        }
    };
}