pub enum DatabaseValidatorError {
UniqueConstraintViolation {
field: String,
value: String,
table: String,
message: Option<String>,
},
UniqueTogetherViolation {
fields: Vec<String>,
values: Vec<String>,
table: String,
message: Option<String>,
},
DatabaseError {
message: String,
query: Option<String>,
},
FieldNotFound {
field: String,
},
}Available on crate feature
rest and native only.Expand description
Errors that can occur during database validation
Variants
UniqueConstraintViolation
A unique constraint was violated for a single field
Fields
UniqueTogetherViolation
A unique together constraint was violated for multiple fields
Fields
DatabaseError
A database error occurred during validation
Fields
FieldNotFound
A required field was not found in the data