pub struct AcceptHeaderVersioning {
pub default_version: Option<String>,
pub allowed_versions: HashSet<String>,
pub version_param: String,
}Available on crate feature
rest and non-WebAssembly only.Expand description
Accept header versioning
Example: Accept: application/json; version=1.0
Fields
default_version: Option<String>The fallback version when no version is specified in the Accept header.
allowed_versions: HashSet<String>The set of allowed API versions.
version_param: StringThe parameter name to look for in the Accept header (default: "version").
Implementations
Sourceimpl AcceptHeaderVersioning
impl AcceptHeaderVersioning
Sourcepub fn new() -> AcceptHeaderVersioning
pub fn new() -> AcceptHeaderVersioning
Create a new AcceptHeaderVersioning instance
Examples
use reinhardt_rest::versioning::{AcceptHeaderVersioning, BaseVersioning};
let versioning = AcceptHeaderVersioning::new();
assert_eq!(versioning.default_version.as_deref(), None);
assert_eq!(versioning.version_param.as_str(), "version");Sourcepub fn with_default_version(
self,
version: impl Into<String>,
) -> AcceptHeaderVersioning
pub fn with_default_version( self, version: impl Into<String>, ) -> AcceptHeaderVersioning
Set the default version to use when no version is specified
Examples
use reinhardt_rest::versioning::{AcceptHeaderVersioning, BaseVersioning};
let versioning = AcceptHeaderVersioning::new()
.with_default_version("1.0");
assert_eq!(versioning.default_version.as_deref(), Some("1.0"));Sourcepub fn with_allowed_versions(
self,
versions: Vec<impl Into<String>>,
) -> AcceptHeaderVersioning
pub fn with_allowed_versions( self, versions: Vec<impl Into<String>>, ) -> AcceptHeaderVersioning
Set the allowed versions
Examples
use reinhardt_rest::versioning::{AcceptHeaderVersioning, BaseVersioning};
let versioning = AcceptHeaderVersioning::new()
.with_allowed_versions(vec!["1.0", "2.0", "3.0"]);
assert!(versioning.is_allowed_version("1.0"));
assert!(versioning.is_allowed_version("2.0"));
assert!(!versioning.is_allowed_version("4.0"));Sourcepub fn with_version_param(
self,
param: impl Into<String>,
) -> AcceptHeaderVersioning
pub fn with_version_param( self, param: impl Into<String>, ) -> AcceptHeaderVersioning
Set the version parameter name to look for in the Accept header
Examples
use reinhardt_rest::versioning::{AcceptHeaderVersioning, BaseVersioning};
let versioning = AcceptHeaderVersioning::new()
.with_version_param("api-version");
assert_eq!(versioning.version_param.as_str(), "api-version");Trait Implementations
Sourceimpl BaseVersioning for AcceptHeaderVersioning
impl BaseVersioning for AcceptHeaderVersioning
Sourcefn determine_version<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 Request,
) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
AcceptHeaderVersioning: 'async_trait,
fn determine_version<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 Request,
) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
AcceptHeaderVersioning: 'async_trait,
Determine the API version from the request
Sourcefn default_version(&self) -> Option<&str>
fn default_version(&self) -> Option<&str>
Get the default version
Sourcefn version_param(&self) -> &str
fn version_param(&self) -> &str
Get the version parameter name
Sourcefn is_allowed_version(&self, version: &str) -> bool
fn is_allowed_version(&self, version: &str) -> bool
Check if a version is allowed
Sourceimpl Clone for AcceptHeaderVersioning
impl Clone for AcceptHeaderVersioning
Sourcefn clone(&self) -> AcceptHeaderVersioning
fn clone(&self) -> AcceptHeaderVersioning
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcceptHeaderVersioning
impl Debug for AcceptHeaderVersioning
Sourceimpl Default for AcceptHeaderVersioning
impl Default for AcceptHeaderVersioning
Sourcefn default() -> AcceptHeaderVersioning
fn default() -> AcceptHeaderVersioning
Returns the “default value” for a type. Read more