ArrayBuilder

Struct ArrayBuilder 

pub struct ArrayBuilder { /* private fields */ }
Available on crate feature openapi and non-WebAssembly only.
Builder for Array with chainable configuration methods to create a new Array.

Implementations

Source

impl ArrayBuilder

pub fn new() -> ArrayBuilder

Available on crate feature rest only.

Constructs a new ArrayBuilder.

pub fn build(self) -> Array

Available on crate feature rest only.

Constructs a new Array taking all fields values from this object.

Source

impl ArrayBuilder

pub fn items<I>(self, items: I) -> ArrayBuilder
where I: Into<ArrayItems>,

Available on crate feature rest only.

Set Schema type for the Array.

pub fn prefix_items<I, S>(self, items: I) -> ArrayBuilder
where I: IntoIterator<Item = S>, S: Into<Schema>,

Available on crate feature rest only.

Add prefix items of Array to define item validation of tuples according JSON schema item validation.

pub fn schema_type<T>(self, schema_type: T) -> ArrayBuilder
where T: Into<SchemaType>,

Available on crate feature rest only.

Change type of the array e.g. to change type to string use value SchemaType::Type(Type::String).

Examples

Make nullable string array.

let _ = ArrayBuilder::new()
    .schema_type(SchemaType::from_iter([Type::Array, Type::Null]))
    .items(Object::with_type(Type::String))
    .build();
pub fn title<I>(self, title: Option<I>) -> ArrayBuilder
where I: Into<String>,

Available on crate feature rest only.

Add or change the title of the Array.

pub fn description<I>(self, description: Option<I>) -> ArrayBuilder
where I: Into<String>,

Available on crate feature rest only.

Add or change description of the property. Markdown syntax is supported.

pub fn deprecated(self, deprecated: Option<Deprecated>) -> ArrayBuilder

Available on crate feature rest only.

Add or change deprecated status for Array.

pub fn example(self, example: Option<Value>) -> ArrayBuilder

👎Deprecated:

Since OpenAPI 3.1 prefer using examples

Available on crate feature rest only.

Add or change example shown in UI of the value for richer documentation.

Deprecated since 3.0.x. Prefer Array::examples instead

pub fn examples<I, V>(self, examples: I) -> ArrayBuilder
where I: IntoIterator<Item = V>, V: Into<Value>,

Available on crate feature rest only.

Add or change examples shown in UI of the value for richer documentation.

pub fn default(self, default: Option<Value>) -> ArrayBuilder

Available on crate feature rest only.

Add or change default value for the object which is provided when user has not provided the input in Swagger UI.

pub fn max_items(self, max_items: Option<usize>) -> ArrayBuilder

Available on crate feature rest only.

Set maximum allowed length for Array.

pub fn min_items(self, min_items: Option<usize>) -> ArrayBuilder

Available on crate feature rest only.

Set minimum allowed length for Array.

pub fn unique_items(self, unique_items: bool) -> ArrayBuilder

Available on crate feature rest only.

Set or change whether Array should enforce all items to be unique.

pub fn xml(self, xml: Option<Xml>) -> ArrayBuilder

Available on crate feature rest only.

Set Xml formatting for Array.

pub fn content_encoding<S>(self, content_encoding: S) -> ArrayBuilder
where S: Into<String>,

Available on crate feature rest only.

Set of change Object::content_encoding. Typically left empty but could be base64 for example.

pub fn content_media_type<S>(self, content_media_type: S) -> ArrayBuilder
where S: Into<String>,

Available on crate feature rest only.

Set of change Object::content_media_type. Value must be valid MIME type e.g. application/json.

pub fn extensions(self, extensions: Option<Extensions>) -> ArrayBuilder

Available on crate feature rest only.

Add openapi extensions (x-something) for Array.

pub fn to_array_builder(self) -> ArrayBuilder

Available on crate feature rest only.

Construct a new ArrayBuilder with this component set to ArrayBuilder::items.