#[non_exhaustive]pub struct Components {
pub schemas: BTreeMap<String, RefOr<Schema>>,
pub responses: BTreeMap<String, RefOr<Response>>,
pub security_schemes: BTreeMap<String, SecurityScheme>,
pub extensions: Option<Extensions>,
}openapi and non-WebAssembly only.Expand description
Implements OpenAPI Components Object which holds supported reusable objects.
Components can hold either reusable types themselves or references to other reusable types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schemas: BTreeMap<String, RefOr<Schema>>Map of reusable OpenAPI Schema Objects.
responses: BTreeMap<String, RefOr<Response>>Map of reusable response name, to OpenAPI Response Objects or OpenAPI References to OpenAPI Response Objects.
security_schemes: BTreeMap<String, SecurityScheme>Map of reusable OpenAPI Security Scheme Objects.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Components
impl Components
Sourcepub fn builder() -> ComponentsBuilder
Available on crate feature rest only.
pub fn builder() -> ComponentsBuilder
rest only.Construct a new ComponentsBuilder.
This is effectively same as calling ComponentsBuilder::new
Sourceimpl Components
impl Components
Sourcepub fn new() -> Components
Available on crate feature rest only.
pub fn new() -> Components
rest only.Construct a new Components.
Sourcepub fn add_security_scheme<N, S>(&mut self, name: N, security_scheme: S)
Available on crate feature rest only.
pub fn add_security_scheme<N, S>(&mut self, name: N, security_scheme: S)
rest only.Add SecurityScheme to Components.
Accepts two arguments where first is the name of the SecurityScheme. This is later when
referenced by SecurityRequirements. Second parameter is the SecurityScheme.
Sourcepub fn add_security_schemes_from_iter<I, N, S>(&mut self, schemas: I)
Available on crate feature rest only.
pub fn add_security_schemes_from_iter<I, N, S>(&mut self, schemas: I)
rest only.Add iterator of SecuritySchemes to Components.
Accepts two arguments where first is the name of the SecurityScheme. This is later when
referenced by SecurityRequirements. Second parameter is the SecurityScheme.