pub struct ConnectionPool<DB>where
DB: Database,{ /* private fields */ }Expand description
A database connection pool
Implementations
Sourceimpl ConnectionPool<Postgres>
impl ConnectionPool<Postgres>
Sourcepub async fn new_postgres(
url: &str,
config: PoolConfig,
) -> Result<ConnectionPool<Postgres>, PoolError>
Available on native and crate feature database only.
pub async fn new_postgres( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<Postgres>, PoolError>
native and crate feature database only.Create a new PostgreSQL connection pool
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of PostgreSQL
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert_eq!(pool.config().max_connections, 10);Sourceimpl ConnectionPool<MySql>
impl ConnectionPool<MySql>
Sourcepub async fn new_mysql(
url: &str,
config: PoolConfig,
) -> Result<ConnectionPool<MySql>, PoolError>
Available on native and crate feature database only.
pub async fn new_mysql( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<MySql>, PoolError>
native and crate feature database only.Create a new MySQL connection pool
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of MySQL
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert_eq!(pool.config().max_connections, 10);Sourceimpl ConnectionPool<Sqlite>
impl ConnectionPool<Sqlite>
Sourcepub async fn new_sqlite(
url: &str,
config: PoolConfig,
) -> Result<ConnectionPool<Sqlite>, PoolError>
Available on native and crate feature database only.
pub async fn new_sqlite( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<Sqlite>, PoolError>
native and crate feature database only.Create a new SQLite connection pool
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
// Using in-memory SQLite for doctest
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert!(pool.config().max_connections > 0);Sourceimpl<DB> ConnectionPool<DB>where
DB: Database,
impl<DB> ConnectionPool<DB>where
DB: Database,
Sourcepub async fn add_listener(&self, listener: Arc<dyn PoolEventListener>)
Available on native and crate feature database only.
pub async fn add_listener(&self, listener: Arc<dyn PoolEventListener>)
native and crate feature database only.Add an event listener
Sourcepub async fn acquire(&self) -> Result<PooledConnection<DB>, PoolError>
Available on native and crate feature database only.
pub async fn acquire(&self) -> Result<PooledConnection<DB>, PoolError>
native and crate feature database only.Acquire a connection from the pool with event emission
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
let pool = ConnectionPool::new_postgres("postgresql://user:pass@localhost/test", config)
.await
.unwrap();
// Acquire a connection
let conn = pool.acquire().await;
assert!(conn.is_ok());Sourcepub fn inner(&self) -> &Pool<DB>
Available on native and crate feature database only.
pub fn inner(&self) -> &Pool<DB>
native and crate feature database only.Get the underlying pool
Sourcepub fn config(&self) -> &PoolConfig
Available on native and crate feature database only.
pub fn config(&self) -> &PoolConfig
native and crate feature database only.Get pool configuration
Sourcepub async fn close(&self)
Available on native and crate feature database only.
pub async fn close(&self)
native and crate feature database only.Close the pool
Attempts to gracefully close the pool with a 5-second timeout. If active connections are not returned within this time, the pool will be forcefully closed.
Sourcepub fn url(&self) -> String
Available on native and crate feature database only.
pub fn url(&self) -> String
native and crate feature database only.Get the database URL with password masked for safe display
Returns the database URL with any password replaced by ***
to prevent credential exposure in logs and debug output.
Use url_raw() when the actual password is needed for reconnection.
Sourceimpl ConnectionPool<Postgres>
impl ConnectionPool<Postgres>
Sourcepub async fn recreate(&mut self) -> Result<(), PoolError>
Available on native and crate feature database only.
pub async fn recreate(&mut self) -> Result<(), PoolError>
native and crate feature database only.Recreate the pool with the same configuration
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of PostgreSQL
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
.await
.unwrap();
// Recreate the pool
pool.recreate().await.unwrap();
assert_eq!(pool.config().max_connections, 10);Sourceimpl ConnectionPool<MySql>
impl ConnectionPool<MySql>
Sourcepub async fn recreate(&mut self) -> Result<(), PoolError>
Available on native and crate feature database only.
pub async fn recreate(&mut self) -> Result<(), PoolError>
native and crate feature database only.Recreate the pool with the same configuration
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of MySQL
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
.await
.unwrap();
// Recreate the pool
pool.recreate().await.unwrap();
assert_eq!(pool.config().max_connections, 10);Sourceimpl ConnectionPool<Sqlite>
impl ConnectionPool<Sqlite>
Sourcepub async fn recreate(&mut self) -> Result<(), PoolError>
Available on native and crate feature database only.
pub async fn recreate(&mut self) -> Result<(), PoolError>
native and crate feature database only.Recreate the pool with the same configuration
Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};
let config = PoolConfig::default();
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
.await
.unwrap();
// Recreate the pool
pool.recreate().await.unwrap();
assert!(pool.url().contains("memory"));Auto Trait Implementations
impl<DB> !RefUnwindSafe for ConnectionPool<DB>
impl<DB> !UnwindSafe for ConnectionPool<DB>
impl<DB> Freeze for ConnectionPool<DB>
impl<DB> Send for ConnectionPool<DB>
impl<DB> Sync for ConnectionPool<DB>
impl<DB> Unpin for ConnectionPool<DB>
impl<DB> UnsafeUnpin for ConnectionPool<DB>where
Pool<DB>: UnsafeUnpin,