CurrentUser

Struct CurrentUser 

pub struct CurrentUser<U>
where U: BaseUser + Clone,
{ /* private fields */ }
👎Deprecated since 0.1.0-rc.12:

Use AuthUser<U> instead. CurrentUser<U> will become a type alias for AuthUser<U> in 0.2.0.

Available on crate feature auth and native only.
Wrapper type representing the currently authenticated user for DI.

This type provides access to the authenticated user within endpoint handlers through dependency injection. It wraps an optional user instance and user ID, allowing handlers to check authentication status and access user data.

Example

ⓘ
use reinhardt_auth::CurrentUser;
use reinhardt_auth::DefaultUser;
use reinhardt_http::Response;

async fn my_handler(
    current_user: CurrentUser<DefaultUser>,
) -> Result<Response, Box<dyn std::error::Error>> {
    if current_user.is_authenticated() {
        let user = current_user.user()?;
        let user_id = current_user.id()?;
        println!("Authenticated user: {} (ID: {})", user.get_username(), user_id);
    }
    Ok(Response::ok())
}

Implementations

Source

impl<U> CurrentUser<U>
where U: BaseUser + Clone,

pub fn authenticated(user: U, user_id: Uuid) -> CurrentUser<U>

Creates a new authenticated CurrentUser.

Arguments
  • user - The authenticated user instance
  • user_id - The user’s unique identifier
pub fn anonymous() -> CurrentUser<U>

Creates an anonymous (unauthenticated) CurrentUser.

pub fn is_authenticated(&self) -> bool

Returns whether the current user is authenticated.

pub fn user(&self) -> Result<&U, AuthenticationError>

Returns a reference to the user if authenticated.

Errors

Returns AuthenticationError::NotAuthenticated if the user is not authenticated.

pub fn id(&self) -> Result<Uuid, AuthenticationError>

Returns the user ID if authenticated.

Errors

Returns AuthenticationError::NotAuthenticated if the user is not authenticated.

pub fn into_user(self) -> Result<U, AuthenticationError>

Consumes this wrapper and returns the user if authenticated.

Errors

Returns AuthenticationError::NotAuthenticated if the user is not authenticated.

pub fn as_any(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
where U: 'static,

Returns the user as a trait object for permission checking.

This method is used to pass the user to ModelAdmin permission methods that accept &(dyn Any + Send + Sync).

Returns

Returns Some with a reference to the user as a trait object if authenticated, or None if the user is anonymous.