DefaultUser

Struct DefaultUser 

pub struct DefaultUser {
Show 13 fields pub id: Uuid, pub username: String, pub email: String, pub first_name: String, pub last_name: String, pub password_hash: Option<String>, pub last_login: Option<DateTime<Utc>>, pub is_active: bool, pub is_staff: bool, pub is_superuser: bool, pub date_joined: DateTime<Utc>, pub user_permissions: Vec<String>, pub groups: Vec<String>,
}
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Available on crate features auth and argon2-hasher only.
DefaultUser struct - Django’s AbstractUser equivalent

A complete, ready-to-use user model that combines BaseUser, FullUser, and PermissionsMixin. This is the default user model provided by Reinhardt, suitable for most applications.

Relationship with Django

This struct is equivalent to Django’s django.contrib.auth.models.AbstractUser. It provides a full-featured user model with:

  • Username-based authentication
  • Email address
  • First and last name
  • Password hashing (Argon2id by default)
  • Active/staff/superuser flags
  • Timestamps (last_login, date_joined)
  • Permissions and groups

Database Schema

The default table name is auth_user with the following columns:

  • id (UUID, primary key)
  • username (String, unique)
  • email (String)
  • first_name (String)
  • last_name (String)
  • password_hash (Option<String>)
  • last_login (Option<DateTime<Utc>>)
  • is_active (bool)
  • is_staff (bool)
  • is_superuser (bool)
  • date_joined (DateTime<Utc>)
  • user_permissions (Vec<String>)
  • groups (Vec<String>)

Examples

Creating a new user with automatic Argon2id password hashing:

use reinhardt_auth::{BaseUser, DefaultUser};
use uuid::Uuid;
use chrono::Utc;

let mut user = DefaultUser {
    id: Uuid::new_v4(),
    username: "alice".to_string(),
    email: "alice@example.com".to_string(),
    first_name: "Alice".to_string(),
    last_name: "Smith".to_string(),
    password_hash: None,
    last_login: None,
    is_active: true,
    is_staff: false,
    is_superuser: false,
    date_joined: Utc::now(),
    user_permissions: Vec::new(),
    groups: Vec::new(),
};

// Password is automatically hashed with Argon2id
user.set_password("securepass123").unwrap();

// Verify password
assert!(user.check_password("securepass123").unwrap());
assert!(!user.check_password("wrongpass").unwrap());

Using with permissions:

use reinhardt_auth::{DefaultUser, PermissionsMixin};
use uuid::Uuid;
use chrono::Utc;

let mut user = DefaultUser {
    id: Uuid::new_v4(),
    username: "bob".to_string(),
    email: "bob@example.com".to_string(),
    first_name: "Bob".to_string(),
    last_name: "Johnson".to_string(),
    password_hash: None,
    last_login: None,
    is_active: true,
    is_staff: true,
    is_superuser: false,
    date_joined: Utc::now(),
    user_permissions: vec![
        "blog.add_post".to_string(),
        "blog.change_post".to_string(),
    ],
    groups: vec!["editors".to_string()],
};

// Check permissions
assert!(user.has_perm("blog.add_post"));
assert!(user.has_perm("blog.change_post"));
assert!(!user.has_perm("blog.delete_post"));
assert!(user.has_module_perms("blog"));

Fields

id: Uuid
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Unique identifier (primary key)

username: String
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Username (unique, used for login)

email: String
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Email address

first_name: String
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

First name

last_name: String
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Last name

password_hash: Option<String>
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Password hash (hashed with Argon2id by default)

last_login: Option<DateTime<Utc>>
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Last login timestamp

is_active: bool
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Whether this user account is active

is_staff: bool
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Whether this user can access the admin site

is_superuser: bool
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

Whether this user has all permissions (superuser)

date_joined: DateTime<Utc>
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

When this user account was created

user_permissions: Vec<String>
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

List of permissions (format: “app_label.permission_name”)

groups: Vec<String>
👎Deprecated since 0.1.0-rc.15:

Use the user attribute macro to define your own user struct instead

List of groups this user belongs to