pub struct Group {
pub id: Uuid,
pub name: String,
pub description: Option<String>,
}Expand description
User group
When the database feature is enabled, this struct is also a database model
mapped to the auth_group table.
Examples
use reinhardt_auth::group_management::Group;
use uuid::Uuid;
let group = Group {
id: Uuid::now_v7(),
name: "Editors".to_string(),
description: Some("Content editors".to_string()),
};
assert_eq!(group.name, "Editors");Fields
id: UuidUnique identifier for the group.
name: StringName of the group.
description: Option<String>Optional description of the group’s purpose.
Implementations
Sourceimpl Group
impl Group
Sourcepub fn new() -> GroupBuilder<GroupBuilderUnset, GroupBuilderUnset>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn new() -> GroupBuilder<GroupBuilderUnset, GroupBuilderUnset>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Begin constructing a new instance via the typestate builder.
This is an alias of Self::build. Each required field is set via
a named setter method, and finish() constructs the model.
The positional Model::new(field1, field2, ...) constructor was
removed in 0.2.0. Use Self::build or this zero-argument alias.
Sourceimpl Group
impl Group
Sourcepub fn build() -> GroupBuilder<GroupBuilderUnset, GroupBuilderUnset>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn build() -> GroupBuilder<GroupBuilderUnset, GroupBuilderUnset>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Begin constructing a [#struct_name] via the typestate builder.
Adding a new required field to this model becomes a non-breaking
change for every caller that uses build() — the new field is
surfaced as a new setter rather than a new positional parameter.
Self::new is a zero-argument alias for this method.
Sourceimpl Group
impl Group
Sourcepub fn id(&self) -> Uuid
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn id(&self) -> Uuid
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Get id
Sourcepub fn name(&self) -> &String
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn name(&self) -> &String
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Get reference to name
Sourcepub fn description(&self) -> &Option<String>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn description(&self) -> &Option<String>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Get reference to description
Sourceimpl Group
impl Group
Sourcepub fn set_name(&mut self, value: String)
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn set_name(&mut self, value: String)
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Set name
Sourcepub fn set_description(&mut self, value: Option<String>)
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub fn set_description(&mut self, value: Option<String>)
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Set description
Sourceimpl Group
impl Group
Sourcepub const fn field_id() -> FieldRef<Group, Uuid>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub const fn field_id() -> FieldRef<Group, Uuid>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Field accessor for type-safe field references
Returns a FieldRef<#struct_name, #field_type> that provides compile-time
type safety for field operations.
Sourcepub const fn field_name() -> FieldRef<Group, String>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub const fn field_name() -> FieldRef<Group, String>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Field accessor for type-safe field references
Returns a FieldRef<#struct_name, #field_type> that provides compile-time
type safety for field operations.
Sourcepub const fn field_description() -> FieldRef<Group, Option<String>>
Available on native and crate feature auth and not (target_family=wasm and target_os=unknown) only.
pub const fn field_description() -> FieldRef<Group, Option<String>>
native and crate feature auth and not (target_family=wasm and target_os=unknown) only.Field accessor for type-safe field references
Returns a FieldRef<#struct_name, #field_type> that provides compile-time
type safety for field operations.