JwtAuth

Struct JwtAuth 

pub struct JwtAuth { /* private fields */ }
Available on crate feature auth-jwt and non-WebAssembly only.
JWT Authentication handler

Implementations

Source

impl JwtAuth

pub fn new(secret: &[u8]) -> JwtAuth

Available on crate features auth and jwt only.

Creates a new JWT authentication handler with the given secret key.

Examples
use reinhardt_auth::jwt::JwtAuth;

let secret = b"my-secret-key-12345";
let jwt_auth = JwtAuth::new(secret);
pub fn encode(&self, claims: &Claims) -> Result<String, JwtError>

Available on crate features auth and jwt only.

Encodes JWT claims into a token string.

Examples
use reinhardt_auth::jwt::{JwtAuth, Claims};
use chrono::Duration;

let jwt_auth = JwtAuth::new(b"secret");
let claims = Claims::new(
    "user123".to_string(),
    "john".to_string(),
    Duration::hours(1)
);

let token = jwt_auth.encode(&claims).unwrap();
assert!(!token.is_empty());
pub fn decode(&self, token: &str) -> Result<Claims, JwtError>

Available on crate features auth and jwt only.

Decodes a JWT token string into claims.

Examples
use reinhardt_auth::jwt::{JwtAuth, Claims};
use chrono::Duration;

let jwt_auth = JwtAuth::new(b"secret");
let claims = Claims::new(
    "user123".to_string(),
    "john".to_string(),
    Duration::hours(1)
);

let token = jwt_auth.encode(&claims).unwrap();
let decoded = jwt_auth.decode(&token).unwrap();
assert_eq!(decoded.sub, "user123");
pub fn generate_token( &self, user_id: String, username: String, ) -> Result<String, JwtError>

Available on crate features auth and jwt only.

Generates a JWT token for the given user with 24-hour expiration.

Examples
use reinhardt_auth::jwt::JwtAuth;

let jwt_auth = JwtAuth::new(b"secret");
let token = jwt_auth.generate_token(
    "user123".to_string(),
    "john_doe".to_string()
).unwrap();

assert!(!token.is_empty());
assert!(token.contains('.'));
pub fn verify_token(&self, token: &str) -> Result<Claims, JwtError>

Available on crate features auth and jwt only.

Verifies a JWT token and returns the claims if valid and not expired.

Returns JwtError::TokenExpired if the token has expired. This method applies a strict zero-leeway expiration check.

Examples
use reinhardt_auth::jwt::{JwtAuth, JwtError};

let jwt_auth = JwtAuth::new(b"secret");
let token = jwt_auth.generate_token(
    "user123".to_string(),
    "john_doe".to_string()
).unwrap();

let claims = jwt_auth.verify_token(&token).unwrap();
assert_eq!(claims.sub, "user123");
assert_eq!(claims.username, "john_doe");
pub fn verify_token_allow_expired( &self, token: &str, ) -> Result<Claims, JwtError>

Available on crate features auth and jwt only.

Verifies a JWT token signature without checking expiration.

Useful for token refresh flows where the caller needs to read claims from an expired token to issue a new one. The token’s signature and structure are still validated.

Examples
use reinhardt_auth::jwt::JwtAuth;

let jwt_auth = JwtAuth::new(b"secret");
let token = jwt_auth.generate_token(
    "user123".to_string(),
    "john_doe".to_string()
).unwrap();

// Even after token expires, claims can be read for refresh
let claims = jwt_auth.verify_token_allow_expired(&token).unwrap();
assert_eq!(claims.sub, "user123");