ListView

Struct ListView 

pub struct ListView<T>
where T: Model + Serialize + for<'de> Deserialize<'de> + Send + Sync + Clone,
{ /* private fields */ }
ListView for displaying multiple objects

Implementations

Source

impl<T> ListView<T>
where T: Model + Serialize + for<'de> Deserialize<'de> + Send + Sync + Clone + 'static,

pub fn new() -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Creates a new ListView with default settings.

Uses JsonSerializer by default. Use with_serializer to provide a custom serializer.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new();
assert!(view.get_context_object_name().is_none());
pub fn with_serializer( self, serializer: Box<dyn Serializer<Input = T, Output = String> + Send + Sync>, ) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets a custom serializer for the view.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_rest::serializers::JsonSerializer;
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new()
    .with_serializer(Box::new(JsonSerializer::<Article>::new()));
pub fn with_objects(self, objects: Vec<T>) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets the list of objects to display in the view.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let articles = vec![
    Article { id: Some(1), title: "First".to_string() },
    Article { id: Some(2), title: "Second".to_string() },
];

let view = ListView::<Article>::new()
    .with_objects(articles.clone());
let objects = view.get_objects().await.unwrap();
assert_eq!(objects.len(), 2);
assert_eq!(objects[0].title, "First");
pub fn with_ordering(self, ordering: Vec<String>) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets the ordering for the object list.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new()
    .with_ordering(vec!["-created_at".to_string(), "title".to_string()]);

assert_eq!(view.get_ordering(), Some(vec!["-created_at".to_string(), "title".to_string()]));
pub fn with_paginate_by(self, paginate_by: usize) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets the number of items per page.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new()
    .with_paginate_by(25);

assert_eq!(view.get_paginate_by(), Some(25));
pub fn with_allow_empty(self, allow_empty: bool) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets whether to allow empty result sets.

When set to false, the view will return an error if no objects are found.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new()
    .with_allow_empty(false);

assert!(!view.allow_empty());
pub fn with_context_object_name(self, name: impl Into<String>) -> ListView<T>

Available on native and (crate features api-only or api or standard) only.

Sets a custom name for the object list in the context.

Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};

#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
    id: Option<i64>,
    title: String,
}

#[derive(Clone)]
struct ArticleFields;

impl reinhardt_db::orm::FieldSelector for ArticleFields {
    fn with_alias(self, _alias: &str) -> Self {
        self
    }
}

impl Model for Article {
    type PrimaryKey = i64;
    type Fields = ArticleFields;
    type Objects = reinhardt_db::orm::Manager<Self>;
    fn table_name() -> &'static str { "articles" }
    fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
    fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
    fn new_fields() -> Self::Fields { ArticleFields }
}

let view = ListView::<Article>::new()
    .with_context_object_name("articles");

assert_eq!(view.get_context_object_name(), Some("articles"));