#[non_exhaustive]pub struct Parameter {
pub name: String,
pub parameter_in: ParameterIn,
pub description: Option<String>,
pub required: Required,
pub deprecated: Option<Deprecated>,
pub schema: Option<RefOr<Schema>>,
pub style: Option<ParameterStyle>,
pub explode: Option<bool>,
pub allow_reserved: Option<bool>,
pub extensions: Option<Extensions>,
/* private fields */
}openapi and non-WebAssembly only.Expand description
Implements OpenAPI Parameter Object for Operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the parameter.
- For
ParameterIn::Paththis must in accordance to path templating. - For
ParameterIn::QueryContent-TypeorAuthorizationvalue will be ignored.
parameter_in: ParameterInParameter location.
description: Option<String>Markdown supported description of the parameter.
required: RequiredDeclares whether the parameter is required or not for api.
- For
ParameterIn::Paththis must and will beRequired::True.
deprecated: Option<Deprecated>Declares the parameter deprecated status.
schema: Option<RefOr<Schema>>Schema of the parameter. Typically Schema::Object is used.
style: Option<ParameterStyle>Describes how Parameter is being serialized depending on Parameter::schema (type of a content).
Default value is based on ParameterIn.
explode: Option<bool>When true it will generate separate parameter value for each parameter with array and object type.
This is also true by default for ParameterStyle::Form.
With explode false:
color=blue,black,brownWith explode true:
color=blue&color=black&color=brownallow_reserved: Option<bool>Defines whether parameter should allow reserved characters defined by
RFC3986 :/?#[]@!$&'()*+,;=.
This is only applicable with ParameterIn::Query. Default value is false.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Parameter
impl Parameter
Sourcepub fn builder() -> ParameterBuilder
Available on crate feature rest only.
pub fn builder() -> ParameterBuilder
rest only.Construct a new ParameterBuilder.
This is effectively same as calling ParameterBuilder::new