#[non_exhaustive]pub struct PathItem {Show 13 fields
pub summary: Option<String>,
pub description: Option<String>,
pub servers: Option<Vec<Server>>,
pub parameters: Option<Vec<Parameter>>,
pub get: Option<Operation>,
pub put: Option<Operation>,
pub post: Option<Operation>,
pub delete: Option<Operation>,
pub options: Option<Operation>,
pub head: Option<Operation>,
pub patch: Option<Operation>,
pub trace: Option<Operation>,
pub extensions: Option<Extensions>,
}openapi and non-WebAssembly only.Expand description
Implements OpenAPI Path Item Object what describes Operations available on
a single path.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.summary: Option<String>Optional summary intended to apply all operations in this PathItem.
description: Option<String>Optional description intended to apply all operations in this PathItem.
Description supports markdown syntax.
servers: Option<Vec<Server>>Alternative Server array to serve all Operations in this PathItem overriding
the global server array.
parameters: Option<Vec<Parameter>>List of Parameters common to all Operations in this PathItem. Parameters cannot
contain duplicate parameters. They can be overridden in Operation level but cannot be
removed there.
get: Option<Operation>put: Option<Operation>post: Option<Operation>delete: Option<Operation>options: Option<Operation>head: Option<Operation>patch: Option<Operation>trace: Option<Operation>extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl PathItem
impl PathItem
Sourcepub fn builder() -> PathItemBuilder
Available on crate feature rest only.
pub fn builder() -> PathItemBuilder
rest only.Construct a new PathItemBuilder.
This is effectively same as calling PathItemBuilder::new
Sourceimpl PathItem
impl PathItem
Sourcepub fn new<O>(http_method: HttpMethod, operation: O) -> PathItem
Available on crate feature rest only.
pub fn new<O>(http_method: HttpMethod, operation: O) -> PathItem
rest only.Construct a new PathItem with provided Operation mapped to given HttpMethod.
Sourcepub fn from_http_methods<I, O>(http_methods: I, operation: O) -> PathItem
Available on crate feature rest only.
pub fn from_http_methods<I, O>(http_methods: I, operation: O) -> PathItem
rest only.Constructs a new PathItem with given Operation set for provided HttpMethods.
Sourcepub fn merge_operations(&mut self, path_item: PathItem)
Available on crate feature rest only.
pub fn merge_operations(&mut self, path_item: PathItem)
rest only.Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PathItem
impl<'de> Deserialize<'de> for PathItem
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PathItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PathItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl From<PathItem> for PathItemBuilder
impl From<PathItem> for PathItemBuilder
Sourcefn from(value: PathItem) -> PathItemBuilder
fn from(value: PathItem) -> PathItemBuilder
Sourceimpl From<PathItemBuilder> for PathItem
impl From<PathItemBuilder> for PathItem
Sourcefn from(value: PathItemBuilder) -> PathItem
fn from(value: PathItemBuilder) -> PathItem
Sourceimpl Serialize for PathItem
impl Serialize for PathItem
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl StructuralPartialEq for PathItem