#[non_exhaustive]pub struct PoolConfig {
pub max_size: u32,
pub min_idle: Option<u32>,
pub max_lifetime: Option<Duration>,
pub idle_timeout: Option<Duration>,
pub connect_timeout: Duration,
pub max_connections: u32,
pub min_connections: u32,
pub acquire_timeout: Duration,
pub test_before_acquire: bool,
}Available on crate feature
database and non-WebAssembly only.Expand description
Represents a pool config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_size: u32The max size.
min_idle: Option<u32>The min idle.
max_lifetime: Option<Duration>The max lifetime.
idle_timeout: Option<Duration>The idle timeout.
connect_timeout: DurationThe connect timeout.
max_connections: u32The max connections.
min_connections: u32The min connections.
acquire_timeout: DurationThe acquire timeout.
test_before_acquire: boolThe test before acquire.
Implementations
Sourceimpl PoolConfig
impl PoolConfig
Sourcepub fn new() -> PoolConfig
pub fn new() -> PoolConfig
Create a new pool configuration with default values
Examples
use reinhardt_db::pool::PoolConfig;
let config = PoolConfig::new();
assert_eq!(config.max_connections, 10);Sourcepub fn with_max_connections(self, max: u32) -> PoolConfig
pub fn with_max_connections(self, max: u32) -> PoolConfig
Sets the max connections and returns self for chaining.
Sourcepub fn with_min_connections(self, min: u32) -> PoolConfig
pub fn with_min_connections(self, min: u32) -> PoolConfig
Sets the min connections and returns self for chaining.
Sourcepub fn with_connection_timeout(self, timeout: Duration) -> PoolConfig
pub fn with_connection_timeout(self, timeout: Duration) -> PoolConfig
Sets the connection timeout and returns self for chaining.
Sourcepub fn with_connect_timeout(self, timeout: Duration) -> PoolConfig
pub fn with_connect_timeout(self, timeout: Duration) -> PoolConfig
Sets the connect timeout and returns self for chaining.
Sourcepub fn with_acquire_timeout(self, timeout: Duration) -> PoolConfig
pub fn with_acquire_timeout(self, timeout: Duration) -> PoolConfig
Sets the acquire timeout and returns self for chaining.
Sourcepub fn with_max_lifetime(self, lifetime: Option<Duration>) -> PoolConfig
pub fn with_max_lifetime(self, lifetime: Option<Duration>) -> PoolConfig
Sets the max lifetime and returns self for chaining.
Sourcepub fn with_idle_timeout(self, timeout: Option<Duration>) -> PoolConfig
pub fn with_idle_timeout(self, timeout: Option<Duration>) -> PoolConfig
Sets the idle timeout and returns self for chaining.
Sourcepub fn with_test_before_acquire(self, test: bool) -> PoolConfig
pub fn with_test_before_acquire(self, test: bool) -> PoolConfig
Sets the test before acquire and returns self for chaining.