pub struct QueryParameterVersioning {
pub default_version: Option<String>,
pub allowed_versions: HashSet<String>,
pub version_param: String,
}Available on crate feature
rest and non-WebAssembly only.Expand description
Query parameter versioning
Example: /users/?version=1.0 or /users/?v=2.0
Fields
default_version: Option<String>The fallback version when no version query parameter is present.
allowed_versions: HashSet<String>The set of allowed API versions.
version_param: StringThe query parameter name for the version (default: "version").
Implementations
Sourceimpl QueryParameterVersioning
impl QueryParameterVersioning
Sourcepub fn new() -> QueryParameterVersioning
pub fn new() -> QueryParameterVersioning
Create a new QueryParameterVersioning instance
Examples
use reinhardt_rest::versioning::QueryParameterVersioning;
let versioning = QueryParameterVersioning::new();
assert_eq!(versioning.default_version.as_deref(), None);
assert_eq!(versioning.version_param.as_str(), "version");Sourcepub fn with_default_version(
self,
version: impl Into<String>,
) -> QueryParameterVersioning
pub fn with_default_version( self, version: impl Into<String>, ) -> QueryParameterVersioning
Set the default version to use when no version is in query parameters
Examples
use reinhardt_rest::versioning::QueryParameterVersioning;
let versioning = QueryParameterVersioning::new()
.with_default_version("1.0");
assert_eq!(versioning.default_version.as_deref(), Some("1.0"));Sourcepub fn with_allowed_versions(
self,
versions: Vec<impl Into<String>>,
) -> QueryParameterVersioning
pub fn with_allowed_versions( self, versions: Vec<impl Into<String>>, ) -> QueryParameterVersioning
Set the allowed versions
Examples
use reinhardt_rest::versioning::{QueryParameterVersioning, BaseVersioning};
let versioning = QueryParameterVersioning::new()
.with_allowed_versions(vec!["1.0", "2.0", "3.0"]);
assert!(versioning.is_allowed_version("1.0"));
assert!(!versioning.is_allowed_version("4.0"));Sourcepub fn with_version_param(
self,
param: impl Into<String>,
) -> QueryParameterVersioning
pub fn with_version_param( self, param: impl Into<String>, ) -> QueryParameterVersioning
Set the query parameter name to use for version detection
Examples
use reinhardt_rest::versioning::QueryParameterVersioning;
let versioning = QueryParameterVersioning::new()
.with_version_param("v");
assert_eq!(versioning.version_param.as_str(), "v");
// This will now look for ?v=1.0 instead of ?version=1.0Trait Implementations
Sourceimpl BaseVersioning for QueryParameterVersioning
impl BaseVersioning for QueryParameterVersioning
Sourcefn determine_version<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 Request,
) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
QueryParameterVersioning: 'async_trait,
fn determine_version<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 Request,
) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
QueryParameterVersioning: 'async_trait,
Determine the API version from the request
Sourcefn default_version(&self) -> Option<&str>
fn default_version(&self) -> Option<&str>
Get the default version
Sourcefn version_param(&self) -> &str
fn version_param(&self) -> &str
Get the version parameter name
Sourcefn is_allowed_version(&self, version: &str) -> bool
fn is_allowed_version(&self, version: &str) -> bool
Check if a version is allowed
Sourceimpl Clone for QueryParameterVersioning
impl Clone for QueryParameterVersioning
Sourcefn clone(&self) -> QueryParameterVersioning
fn clone(&self) -> QueryParameterVersioning
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryParameterVersioning
impl Debug for QueryParameterVersioning
Sourceimpl Default for QueryParameterVersioning
impl Default for QueryParameterVersioning
Sourcefn default() -> QueryParameterVersioning
fn default() -> QueryParameterVersioning
Returns the “default value” for a type. Read more