pub struct ReadOnlyModelViewSet<M, S> { /* private fields */ }Available on non-WebAssembly only.
ReadOnlyModelViewSet - only list and retrieve Demonstrates selective composition of mixins
Implementations
Sourceimpl<M, S> ReadOnlyModelViewSet<M, S>where
M: 'static,
S: 'static,
impl<M, S> ReadOnlyModelViewSet<M, S>where
M: 'static,
S: 'static,
Sourcepub fn new(basename: impl Into<String>) -> ReadOnlyModelViewSet<M, S>
pub fn new(basename: impl Into<String>) -> ReadOnlyModelViewSet<M, S>
Creates a new ReadOnlyModelViewSet with the given basename.
Examples
use reinhardt_views::viewsets::{ReadOnlyModelViewSet, ViewSet};
use reinhardt_db::prelude::Model;
use serde::{Serialize, Deserialize};
#[derive(Serialize, Deserialize, Clone, Debug)]
struct User {
id: Option<i64>,
username: String,
}
#[derive(Clone)]
struct UserFields;
impl reinhardt_db::orm::FieldSelector for UserFields {
fn with_alias(self, _alias: &str) -> Self { self }
}
impl Model for User {
type PrimaryKey = i64;
type Fields = UserFields;
fn table_name() -> &'static str { "users" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { UserFields }
}
let viewset = ReadOnlyModelViewSet::<User, reinhardt_rest::serializers::JsonSerializer<User>>::new("users");
assert_eq!(viewset.get_basename(), "users");Sourcepub fn with_lookup_field(
self,
field: impl Into<String>,
) -> ReadOnlyModelViewSet<M, S>
pub fn with_lookup_field( self, field: impl Into<String>, ) -> ReadOnlyModelViewSet<M, S>
Set custom lookup field for this ViewSet
Sourcepub fn with_pagination(
self,
config: PaginationConfig,
) -> ReadOnlyModelViewSet<M, S>
pub fn with_pagination( self, config: PaginationConfig, ) -> ReadOnlyModelViewSet<M, S>
Set pagination configuration for this ViewSet
Sourcepub fn without_pagination(self) -> ReadOnlyModelViewSet<M, S>
pub fn without_pagination(self) -> ReadOnlyModelViewSet<M, S>
Disable pagination for this ViewSet
Sourcepub fn with_filters(self, config: FilterConfig) -> ReadOnlyModelViewSet<M, S>
pub fn with_filters(self, config: FilterConfig) -> ReadOnlyModelViewSet<M, S>
Set filter configuration for this ViewSet
Examples
ⓘ
use reinhardt_views::viewsets::{ReadOnlyModelViewSet, FilterConfig};
let viewset = ReadOnlyModelViewSet::<MyModel, MySerializer>::new("items")
.with_filters(
FilterConfig::new()
.with_filterable_fields(vec!["status", "category"])
.with_search_fields(vec!["title", "description"])
);Sourcepub fn with_ordering(self, config: OrderingConfig) -> ReadOnlyModelViewSet<M, S>
pub fn with_ordering(self, config: OrderingConfig) -> ReadOnlyModelViewSet<M, S>
Set ordering configuration for this ViewSet
Examples
ⓘ
use reinhardt_views::viewsets::{ReadOnlyModelViewSet, OrderingConfig};
let viewset = ReadOnlyModelViewSet::<MyModel, MySerializer>::new("items")
.with_ordering(
OrderingConfig::new()
.with_ordering_fields(vec!["created_at", "title"])
.with_default_ordering(vec!["-created_at"])
);Sourcepub fn as_view(self) -> ViewSetBuilder<ReadOnlyModelViewSet<M, S>>
pub fn as_view(self) -> ViewSetBuilder<ReadOnlyModelViewSet<M, S>>
Convert ViewSet to Handler with action mapping Returns a ViewSetBuilder for configuration