pub struct RequestContext { /* private fields */ }Available on crate feature
di and non-WebAssembly only.Expand description
Context for per-request dependency injection resolution.
Wraps an InjectionContext with request-scoped lifetime management.
Implementations
Sourceimpl RequestContext
impl RequestContext
Sourcepub fn new(singleton_scope: SingletonScope) -> RequestContext
pub fn new(singleton_scope: SingletonScope) -> RequestContext
Creates a new RequestContext with a shared singleton scope.
This is typically used to create a context for each incoming request.
Examples
use reinhardt_di::{RequestContext, SingletonScope};
let singleton_scope = SingletonScope::new();
let request_ctx = RequestContext::new(singleton_scope);Sourcepub fn injection_context(&self) -> &InjectionContext
pub fn injection_context(&self) -> &InjectionContext
Returns a reference to the underlying injection context.
This allows access to the dependency injection context for resolving dependencies.
Examples
use reinhardt_di::{RequestContext, SingletonScope};
let singleton_scope = SingletonScope::new();
let request_ctx = RequestContext::new(singleton_scope);
let ctx = request_ctx.injection_context();
ctx.set_request(42i32);Auto Trait Implementations
impl Freeze for RequestContext
impl !RefUnwindSafe for RequestContext
impl Send for RequestContext
impl Sync for RequestContext
impl Unpin for RequestContext
impl UnsafeUnpin for RequestContext
impl !UnwindSafe for RequestContext