pub struct StatusCode(/* private fields */);native only.Expand description
An HTTP status code (status-code in RFC 9110 et al.).
Constants are provided for known status codes, including those in the IANA HTTP Status Code Registry.
Status code values in the range 100-999 (inclusive) are supported by this
type. Values in the range 100-599 are semantically classified by the most
significant digit. See StatusCode::is_success, etc. Values above 599
are unclassified but allowed for legacy compatibility, though their use is
discouraged. Applications may interpret such values as protocol errors.
Examples
use http::StatusCode;
assert_eq!(StatusCode::from_u16(200).unwrap(), StatusCode::OK);
assert_eq!(StatusCode::NOT_FOUND.as_u16(), 404);
assert!(StatusCode::OK.is_success());Implementations
Sourceimpl StatusCode
impl StatusCode
Sourcepub const fn from_u16(src: u16) -> Result<StatusCode, InvalidStatusCode>
Available on crate feature exception only.
pub const fn from_u16(src: u16) -> Result<StatusCode, InvalidStatusCode>
exception only.Converts a u16 to a status code.
The function validates the correctness of the supplied u16. It must be greater or equal to 100 and less than 1000.
Example
use http::StatusCode;
let ok = StatusCode::from_u16(200).unwrap();
assert_eq!(ok, StatusCode::OK);
let err = StatusCode::from_u16(99);
assert!(err.is_err());Sourcepub fn from_bytes(src: &[u8]) -> Result<StatusCode, InvalidStatusCode>
Available on crate feature exception only.
pub fn from_bytes(src: &[u8]) -> Result<StatusCode, InvalidStatusCode>
exception only.Converts a &[u8] to a status code.
Sourcepub const fn as_u16(&self) -> u16
Available on crate feature exception only.
pub const fn as_u16(&self) -> u16
exception only.Returns the u16 corresponding to this StatusCode.
Note
This is the same as the From<StatusCode> implementation, but
included as an inherent method because that implementation doesn’t
appear in rustdocs, as well as a way to force the type instead of
relying on inference.
Example
let status = http::StatusCode::OK;
assert_eq!(status.as_u16(), 200);Sourcepub fn as_str(&self) -> &str
Available on crate feature exception only.
pub fn as_str(&self) -> &str
exception only.Returns a &str representation of the StatusCode
The return value only includes a numerical representation of the status code. The canonical reason is not included.
Example
let status = http::StatusCode::OK;
assert_eq!(status.as_str(), "200");Sourcepub fn canonical_reason(&self) -> Option<&'static str>
Available on crate feature exception only.
pub fn canonical_reason(&self) -> Option<&'static str>
exception only.Get the standardised reason-phrase for this status code.
This is mostly here for servers writing responses, but could potentially have application at other times.
The reason phrase is defined as being exclusively for human readers. You should avoid deriving any meaning from it at all costs.
Bear in mind also that in HTTP/2.0 and HTTP/3.0 the reason phrase is abolished from transmission, and so this canonical reason phrase really is the only reason phrase you’ll find.
Example
let status = http::StatusCode::OK;
assert_eq!(status.canonical_reason(), Some("OK"));Sourcepub fn is_informational(&self) -> bool
Available on crate feature exception only.
pub fn is_informational(&self) -> bool
exception only.Check if status is within 100-199.
Sourcepub fn is_success(&self) -> bool
Available on crate feature exception only.
pub fn is_success(&self) -> bool
exception only.Check if status is within 200-299.
Sourcepub fn is_redirection(&self) -> bool
Available on crate feature exception only.
pub fn is_redirection(&self) -> bool
exception only.Check if status is within 300-399.
Sourcepub fn is_client_error(&self) -> bool
Available on crate feature exception only.
pub fn is_client_error(&self) -> bool
exception only.Check if status is within 400-499.
Sourcepub fn is_server_error(&self) -> bool
Available on crate feature exception only.
pub fn is_server_error(&self) -> bool
exception only.Check if status is within 500-599.
Sourceimpl StatusCode
impl StatusCode
Sourcepub const CONTINUE: StatusCode
Available on crate feature exception only.
pub const CONTINUE: StatusCode
exception only.100 Continue [RFC9110, Section 15.2.1]
Sourcepub const SWITCHING_PROTOCOLS: StatusCode
Available on crate feature exception only.
pub const SWITCHING_PROTOCOLS: StatusCode
exception only.101 Switching Protocols [RFC9110, Section 15.2.2]
Sourcepub const PROCESSING: StatusCode
Available on crate feature exception only.
pub const PROCESSING: StatusCode
exception only.102 Processing [RFC2518, Section 10.1]
Sourcepub const EARLY_HINTS: StatusCode
Available on crate feature exception only.
pub const EARLY_HINTS: StatusCode
exception only.103 Early Hints [RFC8297, Section 2]
Sourcepub const OK: StatusCode
Available on crate feature exception only.
pub const OK: StatusCode
exception only.200 OK [RFC9110, Section 15.3.1]
Sourcepub const CREATED: StatusCode
Available on crate feature exception only.
pub const CREATED: StatusCode
exception only.201 Created [RFC9110, Section 15.3.2]
Sourcepub const ACCEPTED: StatusCode
Available on crate feature exception only.
pub const ACCEPTED: StatusCode
exception only.202 Accepted [RFC9110, Section 15.3.3]
Sourcepub const NON_AUTHORITATIVE_INFORMATION: StatusCode
Available on crate feature exception only.
pub const NON_AUTHORITATIVE_INFORMATION: StatusCode
exception only.203 Non-Authoritative Information [RFC9110, Section 15.3.4]
Sourcepub const NO_CONTENT: StatusCode
Available on crate feature exception only.
pub const NO_CONTENT: StatusCode
exception only.204 No Content [RFC9110, Section 15.3.5]
Sourcepub const RESET_CONTENT: StatusCode
Available on crate feature exception only.
pub const RESET_CONTENT: StatusCode
exception only.205 Reset Content [RFC9110, Section 15.3.6]
Sourcepub const PARTIAL_CONTENT: StatusCode
Available on crate feature exception only.
pub const PARTIAL_CONTENT: StatusCode
exception only.206 Partial Content [RFC9110, Section 15.3.7]
Sourcepub const MULTI_STATUS: StatusCode
Available on crate feature exception only.
pub const MULTI_STATUS: StatusCode
exception only.207 Multi-Status [RFC4918, Section 11.1]
Sourcepub const ALREADY_REPORTED: StatusCode
Available on crate feature exception only.
pub const ALREADY_REPORTED: StatusCode
exception only.208 Already Reported [RFC5842, Section 7.1]
Sourcepub const IM_USED: StatusCode
Available on crate feature exception only.
pub const IM_USED: StatusCode
exception only.226 IM Used [RFC3229, Section 10.4.1]
Sourcepub const MULTIPLE_CHOICES: StatusCode
Available on crate feature exception only.
pub const MULTIPLE_CHOICES: StatusCode
exception only.300 Multiple Choices [RFC9110, Section 15.4.1]
Sourcepub const MOVED_PERMANENTLY: StatusCode
Available on crate feature exception only.
pub const MOVED_PERMANENTLY: StatusCode
exception only.301 Moved Permanently [RFC9110, Section 15.4.2]
Sourcepub const FOUND: StatusCode
Available on crate feature exception only.
pub const FOUND: StatusCode
exception only.302 Found [RFC9110, Section 15.4.3]
Sourcepub const SEE_OTHER: StatusCode
Available on crate feature exception only.
pub const SEE_OTHER: StatusCode
exception only.303 See Other [RFC9110, Section 15.4.4]
Sourcepub const NOT_MODIFIED: StatusCode
Available on crate feature exception only.
pub const NOT_MODIFIED: StatusCode
exception only.304 Not Modified [RFC9110, Section 15.4.5]
Sourcepub const USE_PROXY: StatusCode
Available on crate feature exception only.
pub const USE_PROXY: StatusCode
exception only.305 Use Proxy [RFC9110, Section 15.4.6]
Sourcepub const TEMPORARY_REDIRECT: StatusCode
Available on crate feature exception only.
pub const TEMPORARY_REDIRECT: StatusCode
exception only.307 Temporary Redirect [RFC9110, Section 15.4.7]
Sourcepub const PERMANENT_REDIRECT: StatusCode
Available on crate feature exception only.
pub const PERMANENT_REDIRECT: StatusCode
exception only.308 Permanent Redirect [RFC9110, Section 15.4.8]
Sourcepub const BAD_REQUEST: StatusCode
Available on crate feature exception only.
pub const BAD_REQUEST: StatusCode
exception only.400 Bad Request [RFC9110, Section 15.5.1]
Sourcepub const UNAUTHORIZED: StatusCode
Available on crate feature exception only.
pub const UNAUTHORIZED: StatusCode
exception only.401 Unauthorized [RFC9110, Section 15.5.2]
Sourcepub const PAYMENT_REQUIRED: StatusCode
Available on crate feature exception only.
pub const PAYMENT_REQUIRED: StatusCode
exception only.402 Payment Required [RFC9110, Section 15.5.3]
Sourcepub const FORBIDDEN: StatusCode
Available on crate feature exception only.
pub const FORBIDDEN: StatusCode
exception only.403 Forbidden [RFC9110, Section 15.5.4]
Sourcepub const NOT_FOUND: StatusCode
Available on crate feature exception only.
pub const NOT_FOUND: StatusCode
exception only.404 Not Found [RFC9110, Section 15.5.5]
Sourcepub const METHOD_NOT_ALLOWED: StatusCode
Available on crate feature exception only.
pub const METHOD_NOT_ALLOWED: StatusCode
exception only.405 Method Not Allowed [RFC9110, Section 15.5.6]
Sourcepub const NOT_ACCEPTABLE: StatusCode
Available on crate feature exception only.
pub const NOT_ACCEPTABLE: StatusCode
exception only.406 Not Acceptable [RFC9110, Section 15.5.7]
Sourcepub const PROXY_AUTHENTICATION_REQUIRED: StatusCode
Available on crate feature exception only.
pub const PROXY_AUTHENTICATION_REQUIRED: StatusCode
exception only.407 Proxy Authentication Required [RFC9110, Section 15.5.8]
Sourcepub const REQUEST_TIMEOUT: StatusCode
Available on crate feature exception only.
pub const REQUEST_TIMEOUT: StatusCode
exception only.408 Request Timeout [RFC9110, Section 15.5.9]
Sourcepub const CONFLICT: StatusCode
Available on crate feature exception only.
pub const CONFLICT: StatusCode
exception only.409 Conflict [RFC9110, Section 15.5.10]
Sourcepub const GONE: StatusCode
Available on crate feature exception only.
pub const GONE: StatusCode
exception only.410 Gone [RFC9110, Section 15.5.11]
Sourcepub const LENGTH_REQUIRED: StatusCode
Available on crate feature exception only.
pub const LENGTH_REQUIRED: StatusCode
exception only.411 Length Required [RFC9110, Section 15.5.12]
Sourcepub const PRECONDITION_FAILED: StatusCode
Available on crate feature exception only.
pub const PRECONDITION_FAILED: StatusCode
exception only.412 Precondition Failed [RFC9110, Section 15.5.13]
Sourcepub const PAYLOAD_TOO_LARGE: StatusCode
Available on crate feature exception only.
pub const PAYLOAD_TOO_LARGE: StatusCode
exception only.413 Payload Too Large [RFC9110, Section 15.5.14]
Sourcepub const URI_TOO_LONG: StatusCode
Available on crate feature exception only.
pub const URI_TOO_LONG: StatusCode
exception only.414 URI Too Long [RFC9110, Section 15.5.15]
Sourcepub const UNSUPPORTED_MEDIA_TYPE: StatusCode
Available on crate feature exception only.
pub const UNSUPPORTED_MEDIA_TYPE: StatusCode
exception only.415 Unsupported Media Type [RFC9110, Section 15.5.16]
Sourcepub const RANGE_NOT_SATISFIABLE: StatusCode
Available on crate feature exception only.
pub const RANGE_NOT_SATISFIABLE: StatusCode
exception only.416 Range Not Satisfiable [RFC9110, Section 15.5.17]
Sourcepub const EXPECTATION_FAILED: StatusCode
Available on crate feature exception only.
pub const EXPECTATION_FAILED: StatusCode
exception only.417 Expectation Failed [RFC9110, Section 15.5.18]
Sourcepub const IM_A_TEAPOT: StatusCode
Available on crate feature exception only.
pub const IM_A_TEAPOT: StatusCode
exception only.418 I’m a teapot [curiously not registered by IANA but RFC2324, Section 2.3.2]
Sourcepub const MISDIRECTED_REQUEST: StatusCode
Available on crate feature exception only.
pub const MISDIRECTED_REQUEST: StatusCode
exception only.421 Misdirected Request [RFC9110, Section 15.5.20]
Sourcepub const UNPROCESSABLE_ENTITY: StatusCode
Available on crate feature exception only.
pub const UNPROCESSABLE_ENTITY: StatusCode
exception only.422 Unprocessable Entity [RFC9110, Section 15.5.21]
Sourcepub const LOCKED: StatusCode
Available on crate feature exception only.
pub const LOCKED: StatusCode
exception only.423 Locked [RFC4918, Section 11.3]
Sourcepub const FAILED_DEPENDENCY: StatusCode
Available on crate feature exception only.
pub const FAILED_DEPENDENCY: StatusCode
exception only.424 Failed Dependency [RFC4918, Section 11.4]
Sourcepub const TOO_EARLY: StatusCode
Available on crate feature exception only.
pub const TOO_EARLY: StatusCode
exception only.425 Too early [RFC8470, Section 5.2]
Sourcepub const UPGRADE_REQUIRED: StatusCode
Available on crate feature exception only.
pub const UPGRADE_REQUIRED: StatusCode
exception only.426 Upgrade Required [RFC9110, Section 15.5.22]
Sourcepub const PRECONDITION_REQUIRED: StatusCode
Available on crate feature exception only.
pub const PRECONDITION_REQUIRED: StatusCode
exception only.428 Precondition Required [RFC6585, Section 3]
Sourcepub const TOO_MANY_REQUESTS: StatusCode
Available on crate feature exception only.
pub const TOO_MANY_REQUESTS: StatusCode
exception only.429 Too Many Requests [RFC6585, Section 4]
Sourcepub const REQUEST_HEADER_FIELDS_TOO_LARGE: StatusCode
Available on crate feature exception only.
pub const REQUEST_HEADER_FIELDS_TOO_LARGE: StatusCode
exception only.431 Request Header Fields Too Large [RFC6585, Section 5]
Sourcepub const UNAVAILABLE_FOR_LEGAL_REASONS: StatusCode
Available on crate feature exception only.
pub const UNAVAILABLE_FOR_LEGAL_REASONS: StatusCode
exception only.451 Unavailable For Legal Reasons [RFC7725, Section 3]
Sourcepub const INTERNAL_SERVER_ERROR: StatusCode
Available on crate feature exception only.
pub const INTERNAL_SERVER_ERROR: StatusCode
exception only.500 Internal Server Error [RFC9110, Section 15.6.1]
Sourcepub const NOT_IMPLEMENTED: StatusCode
Available on crate feature exception only.
pub const NOT_IMPLEMENTED: StatusCode
exception only.501 Not Implemented [RFC9110, Section 15.6.2]
Sourcepub const BAD_GATEWAY: StatusCode
Available on crate feature exception only.
pub const BAD_GATEWAY: StatusCode
exception only.502 Bad Gateway [RFC9110, Section 15.6.3]
Sourcepub const SERVICE_UNAVAILABLE: StatusCode
Available on crate feature exception only.
pub const SERVICE_UNAVAILABLE: StatusCode
exception only.503 Service Unavailable [RFC9110, Section 15.6.4]
Sourcepub const GATEWAY_TIMEOUT: StatusCode
Available on crate feature exception only.
pub const GATEWAY_TIMEOUT: StatusCode
exception only.504 Gateway Timeout [RFC9110, Section 15.6.5]
Sourcepub const HTTP_VERSION_NOT_SUPPORTED: StatusCode
Available on crate feature exception only.
pub const HTTP_VERSION_NOT_SUPPORTED: StatusCode
exception only.505 HTTP Version Not Supported [RFC9110, Section 15.6.6]
Sourcepub const VARIANT_ALSO_NEGOTIATES: StatusCode
Available on crate feature exception only.
pub const VARIANT_ALSO_NEGOTIATES: StatusCode
exception only.506 Variant Also Negotiates [RFC2295, Section 8.1]
Sourcepub const INSUFFICIENT_STORAGE: StatusCode
Available on crate feature exception only.
pub const INSUFFICIENT_STORAGE: StatusCode
exception only.507 Insufficient Storage [RFC4918, Section 11.5]
Sourcepub const LOOP_DETECTED: StatusCode
Available on crate feature exception only.
pub const LOOP_DETECTED: StatusCode
exception only.508 Loop Detected [RFC5842, Section 7.2]
Sourcepub const NOT_EXTENDED: StatusCode
Available on crate feature exception only.
pub const NOT_EXTENDED: StatusCode
exception only.510 Not Extended [RFC2774, Section 7]
Sourcepub const NETWORK_AUTHENTICATION_REQUIRED: StatusCode
Available on crate feature exception only.
pub const NETWORK_AUTHENTICATION_REQUIRED: StatusCode
exception only.511 Network Authentication Required [RFC6585, Section 6]