pub enum ClientError {
Http(Error),
Hyper(Error),
Serialization(Error),
InvalidHeaderValue(InvalidHeaderValue),
Reqwest(Error),
RequestFailed(String),
}Available on crate feature
test and non-WebAssembly only.Expand description
Errors that can occur when using the API test client.
Variants
Http(Error)
HTTP protocol error.
Hyper(Error)
Hyper transport error.
Serialization(Error)
JSON serialization/deserialization error.
InvalidHeaderValue(InvalidHeaderValue)
Invalid HTTP header value.
Reqwest(Error)
Reqwest HTTP client error.
RequestFailed(String)
General request failure.
Implementations
Sourceimpl ClientError
impl ClientError
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the error is a timeout error
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Returns true if the error is a connection error
Sourcepub fn is_request(&self) -> bool
pub fn is_request(&self) -> bool
Returns true if the error occurred during request building