Error

Enum Error 

pub enum Error {
Show 30 variants NoHomePathError, CertPathError { path: PathBuf, }, CertMultipleKeys { count: usize, path: PathBuf, }, CertParseError { path: PathBuf, }, NoNativeCertsError { err: Error, }, LoadNativeCertsErrors { errors: Vec<Error>, }, DockerResponseServerError { status_code: u16, message: String, }, JsonDataError { message: String, column: usize, }, APIVersionParseError {}, RequestTimeoutError, DockerStreamError { error: String, }, DockerContainerWaitError { error: String, code: i64, }, MissingSessionBuildkitError {}, MissingVersionBuildkitError {}, JsonSerdeError { err: Error, }, StrParseError { err: Utf8Error, }, IOError { err: Error, }, StrFmtError { err: Error, }, HttpClientError { err: Error, }, HyperResponseError { err: Error, }, URLEncodedError { err: Error, }, URLParseError { err: ParseError, }, InvalidURIError { err: InvalidUri, }, InvalidURIPartsError { err: InvalidUriParts, }, HyperLegacyError { err: Error, }, UnsupportedURISchemeError { uri: String, }, SocketNotFoundError(String), HttpHeaderNotFoundError(String), HttpHeaderToStrError { err: ToStrError, }, Base64DecodeError { err: DecodeError, },
}
Available on crate feature test only.
Generic Docker errors

Variants



NoHomePathError

Available on crate feature ssl_providerless only.

Error emitted during client instantiation when the DOCKER_CERT_PATH environment variable is invalid.



CertPathError

Available on crate feature ssl_providerless only.

Generic error when reading a certificate from the filesystem

Fields

path: PathBuf

Path for the failing certificate file



CertMultipleKeys

Available on crate feature ssl_providerless only.

Error emitted when multiple keys are found in a certificate file

Fields

count: usize

Number of keys found in the certificate file

path: PathBuf

Path for the failing certificate file



CertParseError

Available on crate feature ssl_providerless only.

Parse error for RSA encrypted keys

Fields

path: PathBuf

Path for the failing certificate file



NoNativeCertsError

Available on crate feature ssl_providerless only.

Error emitted when the client is unable to parse a native pki cert for SSL

Fields

err: Error

The original error emitted.



LoadNativeCertsErrors

Available on crate feature ssl_providerless only.

Error emitted when the client is unable to load native certs for SSL

Fields

errors: Vec<Error>

The original errors emitted.



DockerResponseServerError

Generic error emitted by the docker server.

Fields

status_code: u16

Status code returned by the docker server.

message: String

Message returned by the docker server.



JsonDataError

Error facilitating debugging failed JSON parsing.

Fields

message: String

Short section of the json close to the error.

column: usize

Character sequence at error location.



APIVersionParseError

Error emitted when the docker is requested to build with buildkit without a session id



RequestTimeoutError

Error emitted when a request times out.



DockerStreamError

Error emitted mid-stream as part of a successful docker operation

Fields

error: String

error string emitted by the Stream



DockerContainerWaitError

Error emitted as part of a container wait response

Fields

error: String

error string returned from container wait call

code: i64

error code returned from container wait call



MissingSessionBuildkitError

Error emitted when a session is not provided to the buildkit engine



MissingVersionBuildkitError

Error emitted when a session is not provided to the buildkit engine



JsonSerdeError

Error emitted when JSON fails to serialize.

Fields

err: Error

The original error emitted by serde.



StrParseError

Error emitted when log output generates an I/O error.

Fields

err: Utf8Error

The original error emitted.



IOError

Error emitted from an I/O error.

Fields

err: Error

The original error emitted.



StrFmtError

Error emitted from a formatting error.

Fields

err: Error

The original error emitted.



HttpClientError

Error emitted from an HTTP error.

Fields

err: Error

The original error emitted.



HyperResponseError

Error emitted from an HTTP error.

Fields

err: Error

The original error emitted.



URLEncodedError

Error emitted when serde fails to urlencod a struct of options

Fields

err: Error

The original error emitted.



URLParseError

Error encountered when parsing a URL

Fields

err: ParseError

The original error emitted.



InvalidURIError

Error emitted when encoding a URI

Fields

err: InvalidUri

The original error emitted.



InvalidURIPartsError

Error emitted when encoding a URIParts

Fields

err: InvalidUriParts

The original error emitted.



HyperLegacyError

Available on crate features http or pipe or ssh only.

Error that is never emitted

Fields

err: Error

The original error emitted.



UnsupportedURISchemeError

Error emitted when connecting to a URI with an unsupported scheme

Fields

uri: String

The URI that was attempted to be connected to



SocketNotFoundError(String)

Error emitted when the Docker socket file is not found at the expected location.



HttpHeaderNotFoundError(String)

Error emitted when an expected header is not found in the HTTP response.



HttpHeaderToStrError

Error encountered when getting a string slice from a HTTP header

Fields

err: ToStrError

The original error emitted.



Base64DecodeError

Error emitted when failing to decode a base64 string

Fields

err: DecodeError

The original error emitted.