SchemaObject

Type Alias SchemaObject 

pub type SchemaObject = Schema;
Available on crate feature openapi and non-WebAssembly only.
A complete schema object with metadata This is an alias to utoipa’s Schema for convenience

Aliased Type

pub enum SchemaObject {
    Array(Array),
    Object(Object),
    OneOf(OneOf),
    AllOf(AllOf),
    AnyOf(AnyOf),
}

Variants



Array(Array)

Defines array schema from another schema. Typically used with Schema::Object. Slice and Vec types are translated to Schema::Array types.



Object(Object)

Defines object schema. Object is either object holding properties which are other Schemas or can be a field within the Object.



OneOf(OneOf)

Creates a OneOf type composite Object schema. This schema is used to map multiple schemas together where API endpoint could return any of them. Schema::OneOf is created form mixed enum where enum contains various variants.



AllOf(AllOf)

Creates a AllOf type composite Object schema.



AnyOf(AnyOf)

Creates a AnyOf type composite Object schema.