pub struct QueryFilter {
pub conditions: Vec<FilterCondition>,
}Available on
native and crate feature proxy and crate feature routing only.Expand description
A collection of filter conditions applied together as a conjunction.
Fields
conditions: Vec<FilterCondition>The list of filter conditions.
Implementations
Sourceimpl QueryFilter
impl QueryFilter
Sourcepub fn new() -> QueryFilter
Available on crate feature test only.
pub fn new() -> QueryFilter
test only.Create a new empty query filter.
Sourcepub fn add_condition(&mut self, condition: FilterCondition)
Available on crate feature test only.
pub fn add_condition(&mut self, condition: FilterCondition)
test only.Add a filter condition to this query filter.