pub struct TemplateStaticConfig {
pub static_url: String,
pub use_manifest: bool,
pub manifest: HashMap<String, String>,
}Available on non-WebAssembly only.
Configuration for static files in templates
This configuration can be used with template systems to generate URLs for static files.
It can be constructed from StaticFilesConfig.
Fields
static_url: StringBase URL for static files (e.g., “/static/”)
use_manifest: boolWhether to use hashed filenames from manifest
manifest: HashMap<String, String>Manifest mapping original paths to hashed paths
Implementations
Sourceimpl TemplateStaticConfig
impl TemplateStaticConfig
Sourcepub fn new(static_url: String) -> TemplateStaticConfig
pub fn new(static_url: String) -> TemplateStaticConfig
Create a new template static configuration
Examples
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
let config = TemplateStaticConfig::new("/static/".to_string());
assert_eq!(config.static_url, "/static/");
assert!(!config.use_manifest);Sourcepub fn with_manifest(
self,
manifest: HashMap<String, String>,
) -> TemplateStaticConfig
pub fn with_manifest( self, manifest: HashMap<String, String>, ) -> TemplateStaticConfig
Enable manifest-based hashed filenames
Examples
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
use std::collections::HashMap;
let mut manifest = HashMap::new();
manifest.insert("css/style.css".to_string(), "css/style.abc123.css".to_string());
let config = TemplateStaticConfig::new("/static/".to_string())
.with_manifest(manifest);
assert!(config.use_manifest);
assert_eq!(config.manifest.len(), 1);Sourcepub async fn from_storage(
storage: &ManifestStaticFilesStorage,
) -> Result<TemplateStaticConfig, Error>
pub async fn from_storage( storage: &ManifestStaticFilesStorage, ) -> Result<TemplateStaticConfig, Error>
Load manifest from ManifestStaticFilesStorage
Examples
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
use reinhardt_utils::staticfiles::ManifestStaticFilesStorage;
use std::path::PathBuf;
let storage = ManifestStaticFilesStorage::new(
PathBuf::from("/var/www/static"),
"/static/"
);
let config = TemplateStaticConfig::from_storage(&storage).await?;
assert!(config.use_manifest);Sourcepub fn resolve_url(&self, name: &str) -> String
pub fn resolve_url(&self, name: &str) -> String
Resolve a static file path to a URL
This method generates a URL for a static file, optionally using manifest-based hashed filenames for cache busting.
Arguments
name- The file path relative to static root, optionally with query string and/or fragment
Examples
Basic usage:
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
let config = TemplateStaticConfig::new("/static/".to_string());
assert_eq!(config.resolve_url("css/style.css"), "/static/css/style.css");With manifest:
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
use std::collections::HashMap;
let mut manifest = HashMap::new();
manifest.insert("css/style.css".to_string(), "css/style.abc123.css".to_string());
let config = TemplateStaticConfig::new("/static/".to_string())
.with_manifest(manifest);
assert_eq!(config.resolve_url("css/style.css"), "/static/css/style.abc123.css");With query string and fragment:
use reinhardt_utils::staticfiles::template_integration::TemplateStaticConfig;
let config = TemplateStaticConfig::new("/static/".to_string());
assert_eq!(
config.resolve_url("test.css?v=1#section"),
"/static/test.css?v=1#section"
);Trait Implementations
Sourceimpl Clone for TemplateStaticConfig
impl Clone for TemplateStaticConfig
Sourcefn clone(&self) -> TemplateStaticConfig
fn clone(&self) -> TemplateStaticConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateStaticConfig
impl Debug for TemplateStaticConfig
Sourceimpl From<&StaticFilesConfig> for TemplateStaticConfig
impl From<&StaticFilesConfig> for TemplateStaticConfig
Sourcefn from(config: &StaticFilesConfig) -> TemplateStaticConfig
fn from(config: &StaticFilesConfig) -> TemplateStaticConfig
Converts to this type from the input type.