ExampleBuilder

Struct ExampleBuilder 

pub struct ExampleBuilder { /* private fields */ }
Available on crate feature openapi and non-WebAssembly only.
Builder for Example with chainable configuration methods to create a new Example.

Examples

Construct a new Example via builder

let example = ExampleBuilder::new()
    .summary("Example string response")
    .value(Some(serde_json::json!("Example value")))
    .build();

Implementations

Source

impl ExampleBuilder

pub fn new() -> ExampleBuilder

Available on crate feature rest only.

Constructs a new ExampleBuilder.

pub fn build(self) -> Example

Available on crate feature rest only.

Constructs a new Example taking all fields values from this object.

Source

impl ExampleBuilder

pub fn summary<S>(self, summary: S) -> ExampleBuilder
where S: Into<String>,

Available on crate feature rest only.

Add or change a short description for the Example. Setting this to empty String will make it not render in the generated OpenAPI document.

pub fn description<D>(self, description: D) -> ExampleBuilder
where D: Into<String>,

Available on crate feature rest only.

Add or change a long description for the Example. Markdown syntax is supported for rich text representation.

Setting this to empty String will make it not render in the generated OpenAPI document.

pub fn value(self, value: Option<Value>) -> ExampleBuilder

Available on crate feature rest only.

Add or change embedded literal example value. Example::value and Example::external_value are mutually exclusive.

pub fn external_value<E>(self, external_value: E) -> ExampleBuilder
where E: Into<String>,

Available on crate feature rest only.

Add or change an URI that points to a literal example value. Example::external_value provides the capability to references an example that cannot be easily included in JSON or YAML. Example::value and Example::external_value are mutually exclusive.

Setting this to an empty String will make the field not to render in the generated OpenAPI document.