#[non_exhaustive]pub struct AuthorizationCode {
pub authorization_url: String,
pub token_url: String,
pub refresh_url: Option<String>,
pub scopes: Scopes,
pub extensions: Option<Extensions>,
}Available on crate feature
openapi only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Url for authorization token.
token_url: StringToken url for the flow.
refresh_url: Option<String>Optional refresh token url for the flow.
scopes: ScopesScopes required by the flow.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl AuthorizationCode
impl AuthorizationCode
Sourcepub fn new<A, T>(
authorization_url: A,
token_url: T,
scopes: Scopes,
) -> AuthorizationCode
Available on native and crate feature rest only.
pub fn new<A, T>( authorization_url: A, token_url: T, scopes: Scopes, ) -> AuthorizationCode
native and crate feature rest only.Construct a new authorization code oauth flow.
Accepts three arguments: one which is authorization url, two a token url and three a map of scopes for oauth flow.
Examples
Create new authorization code flow with scopes.
AuthorizationCode::new(
"https://localhost/auth/dialog",
"https://localhost/token",
Scopes::from_iter([
("edit:items", "edit my items"),
("read:items", "read my items")
]),
);Create new authorization code flow without any scopes.
AuthorizationCode::new(
"https://localhost/auth/dialog",
"https://localhost/token",
Scopes::new(),
);Sourcepub fn with_refresh_url<S>(
authorization_url: S,
token_url: S,
scopes: Scopes,
refresh_url: S,
) -> AuthorizationCode
Available on native and crate feature rest only.
pub fn with_refresh_url<S>( authorization_url: S, token_url: S, scopes: Scopes, refresh_url: S, ) -> AuthorizationCode
native and crate feature rest only.Construct a new AuthorizationCode OAuth2 flow with additional refresh token url.
This is essentially same as AuthorizationCode::new but allows defining extra parameter refresh_url
for fetching refresh token.
Examples
Create AuthorizationCode OAuth2 flow with refresh url.
AuthorizationCode::with_refresh_url(
"https://localhost/auth/dialog",
"https://localhost/token",
Scopes::new(),
"https://localhost/refresh-token"
);Trait Implementations
Sourceimpl Clone for AuthorizationCode
impl Clone for AuthorizationCode
Sourcefn clone(&self) -> AuthorizationCode
fn clone(&self) -> AuthorizationCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AuthorizationCode
impl<'de> Deserialize<'de> for AuthorizationCode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AuthorizationCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AuthorizationCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuthorizationCode
Sourceimpl PartialEq for AuthorizationCode
impl PartialEq for AuthorizationCode
Sourceimpl Serialize for AuthorizationCode
impl Serialize for AuthorizationCode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AuthorizationCode