pub struct ServerVariableBuilder { /* private fields */ }Available on crate feature
openapi only.Expand description
Builder for ServerVariable with chainable configuration methods to create a new ServerVariable.
Implementations
Sourceimpl ServerVariableBuilder
impl ServerVariableBuilder
Sourcepub fn new() -> ServerVariableBuilder
Available on native and crate feature rest only.
pub fn new() -> ServerVariableBuilder
native and crate feature rest only.Constructs a new ServerVariableBuilder.
Sourcepub fn build(self) -> ServerVariable
Available on native and crate feature rest only.
pub fn build(self) -> ServerVariable
native and crate feature rest only.Constructs a new ServerVariable taking all fields values from this object.
Sourceimpl ServerVariableBuilder
impl ServerVariableBuilder
Sourcepub fn default_value<S>(self, default_value: S) -> ServerVariableBuilder
Available on native and crate feature rest only.
pub fn default_value<S>(self, default_value: S) -> ServerVariableBuilder
native and crate feature rest only.Add default value for substitution.
Sourcepub fn description<S>(self, description: Option<S>) -> ServerVariableBuilder
Available on native and crate feature rest only.
pub fn description<S>(self, description: Option<S>) -> ServerVariableBuilder
native and crate feature rest only.Add or change description of substituted parameter.
Sourcepub fn enum_values<I, V>(self, enum_values: Option<I>) -> ServerVariableBuilder
Available on native and crate feature rest only.
pub fn enum_values<I, V>(self, enum_values: Option<I>) -> ServerVariableBuilder
native and crate feature rest only.Add or change possible values used to substitute parameter.
Sourcepub fn extensions(self, extensions: Option<Extensions>) -> ServerVariableBuilder
Available on native and crate feature rest only.
pub fn extensions(self, extensions: Option<Extensions>) -> ServerVariableBuilder
native and crate feature rest only.Add openapi extensions (x-something) of the API.