#[non_exhaustive]pub struct Http {
pub scheme: HttpAuthScheme,
pub bearer_format: Option<String>,
pub description: Option<String>,
pub extensions: Option<Extensions>,
}Available on crate feature
openapi and non-WebAssembly only.Expand description
Http authentication SecurityScheme builder.
Methods can be chained to configure bearer_format or to add description.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scheme: HttpAuthSchemeHttp authorization scheme in HTTP Authorization header value.
bearer_format: Option<String>Optional hint to client how the bearer token is formatted. Valid only with HttpAuthScheme::Bearer.
description: Option<String>Optional description of Http SecurityScheme supporting markdown syntax.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Http
impl Http
Sourcepub fn builder() -> HttpBuilder
Available on crate feature rest only.
pub fn builder() -> HttpBuilder
rest only.Construct a new HttpBuilder.
This is effectively same as calling HttpBuilder::new
Sourceimpl Http
impl Http
Sourcepub fn new(scheme: HttpAuthScheme) -> Http
Available on crate feature rest only.
pub fn new(scheme: HttpAuthScheme) -> Http
rest only.Create new http authentication security schema.
Accepts one argument which defines the scheme of the http authentication.
Examples
Create http security schema with basic authentication.
SecurityScheme::Http(Http::new(HttpAuthScheme::Basic));Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Http
impl<'de> Deserialize<'de> for Http
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Http, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Http, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Http> for HttpBuilder
impl From<Http> for HttpBuilder
Sourcefn from(value: Http) -> HttpBuilder
fn from(value: Http) -> HttpBuilder
Converts to this type from the input type.
Sourceimpl From<HttpBuilder> for Http
impl From<HttpBuilder> for Http
Sourcefn from(value: HttpBuilder) -> Http
fn from(value: HttpBuilder) -> Http
Converts to this type from the input type.
Sourceimpl Serialize for Http
impl Serialize for Http
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Http
impl StructuralPartialEq for Http