pub struct SelectStatement { /* private fields */ }native and crate feature database only.Expand description
SELECT statement builder
This struct provides a fluent API for constructing SELECT queries.
Examples
use reinhardt_query::prelude::*;
let query = Query::select()
.column(Expr::col("id"))
.column(Expr::col("name"))
.from("users")
.and_where(Expr::col("active").eq(true))
.order_by("name", Order::Asc)
.limit(10);Implementations
Sourceimpl SelectStatement
impl SelectStatement
Sourcepub fn new() -> SelectStatement
pub fn new() -> SelectStatement
Create a new SELECT statement
Sourcepub fn take(&mut self) -> SelectStatement
pub fn take(&mut self) -> SelectStatement
Take the ownership of data in the current SelectStatement
Sourcepub fn column<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
pub fn column<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
Sourcepub fn columns<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
pub fn columns<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
Sourcepub fn expr<E>(&mut self, expr: E) -> &mut SelectStatementwhere
E: Into<SimpleExpr>,
pub fn expr<E>(&mut self, expr: E) -> &mut SelectStatementwhere
E: Into<SimpleExpr>,
Sourcepub fn expr_as<E, A>(&mut self, expr: E, alias: A) -> &mut SelectStatement
pub fn expr_as<E, A>(&mut self, expr: E, alias: A) -> &mut SelectStatement
Sourcepub fn from<T>(&mut self, tbl: T) -> &mut SelectStatementwhere
T: IntoTableRef,
pub fn from<T>(&mut self, tbl: T) -> &mut SelectStatementwhere
T: IntoTableRef,
Sourcepub fn from_as<T, A>(&mut self, tbl: T, alias: A) -> &mut SelectStatement
pub fn from_as<T, A>(&mut self, tbl: T, alias: A) -> &mut SelectStatement
Add a table with alias to the FROM clause
Equivalent to FROM table AS alias.
Sourcepub fn from_subquery(
&mut self,
query: SelectStatement,
alias: impl IntoIden,
) -> &mut SelectStatement
pub fn from_subquery( &mut self, query: SelectStatement, alias: impl IntoIden, ) -> &mut SelectStatement
Add a subquery to the FROM clause
Equivalent to FROM (SELECT ...) AS alias.
Sourcepub fn clear_selects(&mut self) -> &mut SelectStatement
pub fn clear_selects(&mut self) -> &mut SelectStatement
Clear all column selections
Sourcepub fn join<T, C>(
&mut self,
join: JoinType,
tbl: T,
condition: C,
) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
pub fn join<T, C>(
&mut self,
join: JoinType,
tbl: T,
condition: C,
) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
Sourcepub fn left_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
pub fn left_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
Sourcepub fn right_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
pub fn right_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
Add a RIGHT JOIN clause
Sourcepub fn full_outer_join<T, C>(
&mut self,
tbl: T,
condition: C,
) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
pub fn full_outer_join<T, C>(
&mut self,
tbl: T,
condition: C,
) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
Add a FULL OUTER JOIN clause
Sourcepub fn inner_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
pub fn inner_join<T, C>(&mut self, tbl: T, condition: C) -> &mut SelectStatementwhere
T: IntoTableRef,
C: IntoCondition,
Add an INNER JOIN clause
Sourcepub fn cross_join<T>(&mut self, tbl: T) -> &mut SelectStatementwhere
T: IntoTableRef,
pub fn cross_join<T>(&mut self, tbl: T) -> &mut SelectStatementwhere
T: IntoTableRef,
Add a CROSS JOIN clause
Sourcepub fn and_where<C>(&mut self, condition: C) -> &mut SelectStatementwhere
C: IntoCondition,
pub fn and_where<C>(&mut self, condition: C) -> &mut SelectStatementwhere
C: IntoCondition,
Sourcepub fn cond_where(&mut self, condition: Condition) -> &mut SelectStatement
pub fn cond_where(&mut self, condition: Condition) -> &mut SelectStatement
Add a condition to the WHERE clause using Condition
Sourcepub fn group_by<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
pub fn group_by<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
Sourcepub fn group_by_col<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
pub fn group_by_col<C>(&mut self, col: C) -> &mut SelectStatementwhere
C: IntoColumnRef,
Add a column to the GROUP BY clause (alias for group_by)
Sourcepub fn group_by_columns<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
pub fn group_by_columns<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
Add multiple GROUP BY columns
Sourcepub fn and_having<C>(&mut self, condition: C) -> &mut SelectStatementwhere
C: IntoCondition,
pub fn and_having<C>(&mut self, condition: C) -> &mut SelectStatementwhere
C: IntoCondition,
Sourcepub fn cond_having(&mut self, condition: Condition) -> &mut SelectStatement
pub fn cond_having(&mut self, condition: Condition) -> &mut SelectStatement
Add a condition to the HAVING clause using Condition
Sourcepub fn order_by<C>(&mut self, col: C, order: Order) -> &mut SelectStatementwhere
C: IntoColumnRef,
pub fn order_by<C>(&mut self, col: C, order: Order) -> &mut SelectStatementwhere
C: IntoColumnRef,
Sourcepub fn order_by_expr<E>(
&mut self,
expr: E,
order: Order,
) -> &mut SelectStatementwhere
E: Into<SimpleExpr>,
pub fn order_by_expr<E>(
&mut self,
expr: E,
order: Order,
) -> &mut SelectStatementwhere
E: Into<SimpleExpr>,
Add an ORDER BY clause with expression
Sourcepub fn limit<V>(&mut self, limit: V) -> &mut SelectStatementwhere
V: IntoValue,
pub fn limit<V>(&mut self, limit: V) -> &mut SelectStatementwhere
V: IntoValue,
Sourcepub fn offset<V>(&mut self, offset: V) -> &mut SelectStatementwhere
V: IntoValue,
pub fn offset<V>(&mut self, offset: V) -> &mut SelectStatementwhere
V: IntoValue,
Sourcepub fn distinct(&mut self) -> &mut SelectStatement
pub fn distinct(&mut self) -> &mut SelectStatement
Sourcepub fn distinct_on<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
pub fn distinct_on<I, C>(&mut self, cols: I) -> &mut SelectStatementwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
Set DISTINCT ON (PostgreSQL only)
Sourcepub fn union(&mut self, query: SelectStatement) -> &mut SelectStatement
pub fn union(&mut self, query: SelectStatement) -> &mut SelectStatement
Add a UNION clause
Sourcepub fn union_all(&mut self, query: SelectStatement) -> &mut SelectStatement
pub fn union_all(&mut self, query: SelectStatement) -> &mut SelectStatement
Add a UNION ALL clause
Sourcepub fn intersect(&mut self, query: SelectStatement) -> &mut SelectStatement
pub fn intersect(&mut self, query: SelectStatement) -> &mut SelectStatement
Add an INTERSECT clause
Sourcepub fn except(&mut self, query: SelectStatement) -> &mut SelectStatement
pub fn except(&mut self, query: SelectStatement) -> &mut SelectStatement
Add an EXCEPT clause
Sourcepub fn with_cte<N>(
&mut self,
name: N,
query: SelectStatement,
) -> &mut SelectStatementwhere
N: IntoIden,
pub fn with_cte<N>(
&mut self,
name: N,
query: SelectStatement,
) -> &mut SelectStatementwhere
N: IntoIden,
Add a Common Table Expression (CTE) to the WITH clause
Examples
use reinhardt_query::prelude::*;
let cte = Query::select()
.column("id")
.column("name")
.from("users")
.and_where(Expr::col("active").eq(true));
let query = Query::select()
.with_cte("active_users", cte)
.column("*")
.from("active_users");Sourcepub fn with_recursive_cte<N>(
&mut self,
name: N,
query: SelectStatement,
) -> &mut SelectStatementwhere
N: IntoIden,
pub fn with_recursive_cte<N>(
&mut self,
name: N,
query: SelectStatement,
) -> &mut SelectStatementwhere
N: IntoIden,
Add a RECURSIVE Common Table Expression (CTE) to the WITH clause
Examples
use reinhardt_query::prelude::*;
// Recursive CTE for hierarchical data
let cte = Query::select()
.column("id")
.column("parent_id")
.column("name")
.from("categories")
.and_where(Expr::col("parent_id").is_null())
.union_all(
Query::select()
.column(Expr::col(("c", "id")))
.column(Expr::col(("c", "parent_id")))
.column(Expr::col(("c", "name")))
.from_as("categories", "c")
.join(
JoinType::InnerJoin,
"category_tree",
Expr::col(("c", "parent_id")).eq(Expr::col(("category_tree", "id")))
)
);
let query = Query::select()
.with_recursive_cte("category_tree", cte)
.column("*")
.from("category_tree");Sourcepub fn window_as<T>(
&mut self,
name: T,
window: WindowStatement,
) -> &mut SelectStatementwhere
T: IntoIden,
pub fn window_as<T>(
&mut self,
name: T,
window: WindowStatement,
) -> &mut SelectStatementwhere
T: IntoIden,
Add a named window specification to the WINDOW clause
Named windows can be referenced by window functions using OVER window_name.
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::window::WindowStatement;
let window = WindowStatement {
partition_by: vec![Expr::col("department_id").into_simple_expr()],
order_by: vec![OrderExpr {
expr: Expr::col("salary").into_simple_expr(),
order: Order::Desc,
nulls: None,
}],
frame: None,
};
let query = Query::select()
.column("name")
.expr_as(Expr::row_number().over_named("w"), "rank")
.from("employees")
.window_as("w", window);Sourcepub fn lock(&mut self, lock_type: LockType) -> &mut SelectStatement
pub fn lock(&mut self, lock_type: LockType) -> &mut SelectStatement
Set FOR UPDATE lock
Sourcepub fn lock_exclusive(&mut self) -> &mut SelectStatement
pub fn lock_exclusive(&mut self) -> &mut SelectStatement
Set FOR UPDATE lock
Set FOR SHARE lock
Sourcepub fn apply_if<T, F>(
&mut self,
val: Option<T>,
func: F,
) -> &mut SelectStatementwhere
F: FnOnce(&mut SelectStatement, T),
pub fn apply_if<T, F>(
&mut self,
val: Option<T>,
func: F,
) -> &mut SelectStatementwhere
F: FnOnce(&mut SelectStatement, T),
Apply a function conditionally
Sourcepub fn conditions<T, F>(
&mut self,
b: bool,
if_true: T,
if_false: F,
) -> &mut SelectStatement
pub fn conditions<T, F>( &mut self, b: bool, if_true: T, if_false: F, ) -> &mut SelectStatement
Conditional execution