pub struct Error { /* private fields */ }openapi only.Expand description
This type represents all possible errors that can occur when serializing or deserializing JSON data.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn line(&self) -> usize
Available on native and crate feature serde only.
pub fn line(&self) -> usize
native and crate feature serde only.One-based line number at which the error was detected.
Characters in the first line of the input (before the first newline character) are in line 1.
Sourcepub fn column(&self) -> usize
Available on native and crate feature serde only.
pub fn column(&self) -> usize
native and crate feature serde only.One-based column number at which the error was detected.
The first character in the input and any characters immediately following a newline character are in column 1.
Note that errors may occur in column 0, for example if a read from an I/O stream fails immediately following a previously read newline character.
Sourcepub fn classify(&self) -> Category
Available on native and crate feature serde only.
pub fn classify(&self) -> Category
native and crate feature serde only.Categorizes the cause of this error.
Category::Io- failure to read or write bytes on an I/O streamCategory::Syntax- input that is not syntactically valid JSONCategory::Data- input data that is semantically incorrectCategory::Eof- unexpected end of the input data
Sourcepub fn is_io(&self) -> bool
Available on native and crate feature serde only.
pub fn is_io(&self) -> bool
native and crate feature serde only.Returns true if this error was caused by a failure to read or write bytes on an I/O stream.
Sourcepub fn is_syntax(&self) -> bool
Available on native and crate feature serde only.
pub fn is_syntax(&self) -> bool
native and crate feature serde only.Returns true if this error was caused by input that was not syntactically valid JSON.
Sourcepub fn is_data(&self) -> bool
Available on native and crate feature serde only.
pub fn is_data(&self) -> bool
native and crate feature serde only.Returns true if this error was caused by input data that was semantically incorrect.
For example, JSON containing a number is semantically incorrect when the type being deserialized into holds a String.
Sourcepub fn is_eof(&self) -> bool
Available on native and crate feature serde only.
pub fn is_eof(&self) -> bool
native and crate feature serde only.Returns true if this error was caused by prematurely reaching the end of the input data.
Callers that process streaming input may be interested in retrying the deserialization once more data is available.
Sourcepub fn io_error_kind(&self) -> Option<ErrorKind>
Available on native and crate feature serde and crate feature std only.
pub fn io_error_kind(&self) -> Option<ErrorKind>
native and crate feature serde and crate feature std only.The kind reported by the underlying standard library I/O error, if this error was caused by a failure to read or write bytes on an I/O stream.
Example
use serde_json::Value;
use std::io::{self, ErrorKind, Read};
use std::process;
struct ReaderThatWillTimeOut<'a>(&'a [u8]);
impl<'a> Read for ReaderThatWillTimeOut<'a> {
fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
if self.0.is_empty() {
Err(io::Error::new(ErrorKind::TimedOut, "timed out"))
} else {
self.0.read(buf)
}
}
}
fn main() {
let reader = ReaderThatWillTimeOut(br#" {"k": "#);
let _: Value = match serde_json::from_reader(reader) {
Ok(value) => value,
Err(error) => {
if error.io_error_kind() == Some(ErrorKind::TimedOut) {
// Maybe this application needs to retry certain kinds of errors.
} else {
eprintln!("error: {}", error);
process::exit(1);
}
}
};
}Trait Implementations
Sourceimpl Error for Error
impl Error for Error
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
Sourceimpl Error for Error
impl Error for Error
Sourcefn custom<T>(msg: T) -> Errorwhere
T: Display,
fn custom<T>(msg: T) -> Errorwhere
T: Display,
Sourcefn invalid_type(unexp: Unexpected<'_>, exp: &dyn Expected) -> Error
fn invalid_type(unexp: Unexpected<'_>, exp: &dyn Expected) -> Error
Deserialize receives a type different from what it was
expecting. Read moreSourcefn invalid_value(unexp: Unexpected<'_>, exp: &dyn Expected) -> Error
fn invalid_value(unexp: Unexpected<'_>, exp: &dyn Expected) -> Error
Deserialize receives a value of the right type but that
is wrong for some other reason. Read moreSourcefn invalid_length(len: usize, exp: &dyn Expected) -> Self
fn invalid_length(len: usize, exp: &dyn Expected) -> Self
Sourcefn unknown_variant(variant: &str, expected: &'static [&'static str]) -> Self
fn unknown_variant(variant: &str, expected: &'static [&'static str]) -> Self
Deserialize enum type received a variant with an
unrecognized name.Sourcefn unknown_field(field: &str, expected: &'static [&'static str]) -> Self
fn unknown_field(field: &str, expected: &'static [&'static str]) -> Self
Deserialize struct type received a field with an
unrecognized name.Sourcefn missing_field(field: &'static str) -> Self
fn missing_field(field: &'static str) -> Self
Deserialize struct type expected to receive a required
field with a particular name but that field was not present in the
input.Sourcefn duplicate_field(field: &'static str) -> Self
fn duplicate_field(field: &'static str) -> Self
Deserialize struct type received more than one of the
same field.Sourceimpl From<Error> for SchemaError
impl From<Error> for SchemaError
Sourcefn from(e: Error) -> SchemaError
fn from(e: Error) -> SchemaError
Sourceimpl From<Error> for DatabaseError
impl From<Error> for DatabaseError
Sourcefn from(err: Error) -> DatabaseError
fn from(err: Error) -> DatabaseError
Sourceimpl From<Error> for NoSQLError
impl From<Error> for NoSQLError
Sourcefn from(err: Error) -> NoSQLError
fn from(err: Error) -> NoSQLError
Sourceimpl From<Error> for ExecutionError
impl From<Error> for ExecutionError
Sourcefn from(source: Error) -> ExecutionError
fn from(source: Error) -> ExecutionError
Sourceimpl From<Error> for SourceError
impl From<Error> for SourceError
Sourcefn from(source: Error) -> SourceError
fn from(source: Error) -> SourceError
Sourceimpl From<Error> for DynamicError
impl From<Error> for DynamicError
Sourcefn from(source: Error) -> DynamicError
fn from(source: Error) -> DynamicError
Sourceimpl From<Error> for SerializationError
impl From<Error> for SerializationError
Sourcefn from(source: Error) -> SerializationError
fn from(source: Error) -> SerializationError
Sourceimpl From<Error> for SocialAuthError
Conversion from serde_json::Error
impl From<Error> for SocialAuthError
Conversion from serde_json::Error
Sourcefn from(error: Error) -> SocialAuthError
fn from(error: Error) -> SocialAuthError
Sourceimpl From<Error> for BrowsableApiError
impl From<Error> for BrowsableApiError
Sourcefn from(source: Error) -> BrowsableApiError
fn from(source: Error) -> BrowsableApiError
Sourceimpl From<Error> for SchemaError
impl From<Error> for SchemaError
Sourcefn from(source: Error) -> SchemaError
fn from(source: Error) -> SchemaError
Sourceimpl From<Error> for CommandError
impl From<Error> for CommandError
Sourcefn from(err: Error) -> CommandError
fn from(err: Error) -> CommandError
Sourceimpl From<Error> for ClientError
impl From<Error> for ClientError
Sourcefn from(source: Error) -> ClientError
fn from(source: Error) -> ClientError
Sourceimpl From<Error> for GrpcAuthError
impl From<Error> for GrpcAuthError
Sourcefn from(source: Error) -> GrpcAuthError
fn from(source: Error) -> GrpcAuthError
Sourceimpl From<Error> for DeeplinkError
impl From<Error> for DeeplinkError
Sourcefn from(source: Error) -> DeeplinkError
fn from(source: Error) -> DeeplinkError
Sourceimpl<'de> IntoDeserializer<'de, Error> for Map<String, Value>
impl<'de> IntoDeserializer<'de, Error> for Map<String, Value>
Sourcefn into_deserializer(
self,
) -> <Map<String, Value> as IntoDeserializer<'de, Error>>::Deserializer
fn into_deserializer( self, ) -> <Map<String, Value> as IntoDeserializer<'de, Error>>::Deserializer
Sourceimpl<'de> IntoDeserializer<'de, Error> for &'de Map<String, Value>
impl<'de> IntoDeserializer<'de, Error> for &'de Map<String, Value>
Sourcetype Deserializer = &'de Map<String, Value>
type Deserializer = &'de Map<String, Value>
Sourcefn into_deserializer(
self,
) -> <&'de Map<String, Value> as IntoDeserializer<'de, Error>>::Deserializer
fn into_deserializer( self, ) -> <&'de Map<String, Value> as IntoDeserializer<'de, Error>>::Deserializer
Sourceimpl<'de> IntoDeserializer<'de, Error> for Value
impl<'de> IntoDeserializer<'de, Error> for Value
Sourcetype Deserializer = Value
type Deserializer = Value
Sourcefn into_deserializer(
self,
) -> <Value as IntoDeserializer<'de, Error>>::Deserializer
fn into_deserializer( self, ) -> <Value as IntoDeserializer<'de, Error>>::Deserializer
Sourceimpl<'de> IntoDeserializer<'de, Error> for &'de Value
impl<'de> IntoDeserializer<'de, Error> for &'de Value
Sourcetype Deserializer = &'de Value
type Deserializer = &'de Value
Sourcefn into_deserializer(
self,
) -> <&'de Value as IntoDeserializer<'de, Error>>::Deserializer
fn into_deserializer( self, ) -> <&'de Value as IntoDeserializer<'de, Error>>::Deserializer
Sourceimpl<'de> IntoDeserializer<'de, Error> for &'de RawValue
impl<'de> IntoDeserializer<'de, Error> for &'de RawValue
Sourcetype Deserializer = &'de RawValue
type Deserializer = &'de RawValue
Sourcefn into_deserializer(
self,
) -> <&'de RawValue as IntoDeserializer<'de, Error>>::Deserializer
fn into_deserializer( self, ) -> <&'de RawValue as IntoDeserializer<'de, Error>>::Deserializer