pub struct ArrayBuilder { /* private fields */ }openapi and non-WebAssembly only.Implementations
Sourceimpl ArrayBuilder
impl ArrayBuilder
Sourcepub fn new() -> ArrayBuilder
Available on crate feature rest only.
pub fn new() -> ArrayBuilder
rest only.Constructs a new ArrayBuilder.
Sourceimpl ArrayBuilder
impl ArrayBuilder
Sourcepub fn items<I>(self, items: I) -> ArrayBuilderwhere
I: Into<ArrayItems>,
Available on crate feature rest only.
pub fn items<I>(self, items: I) -> ArrayBuilderwhere
I: Into<ArrayItems>,
rest only.Sourcepub fn prefix_items<I, S>(self, items: I) -> ArrayBuilder
Available on crate feature rest only.
pub fn prefix_items<I, S>(self, items: I) -> ArrayBuilder
rest only.Add prefix items of Array to define item validation of tuples according JSON schema
item validation.
Sourcepub fn schema_type<T>(self, schema_type: T) -> ArrayBuilderwhere
T: Into<SchemaType>,
Available on crate feature rest only.
pub fn schema_type<T>(self, schema_type: T) -> ArrayBuilderwhere
T: Into<SchemaType>,
rest only.Change type of the array e.g. to change type to string
use value SchemaType::Type(Type::String).
Examples
Make nullable string array.
let _ = ArrayBuilder::new()
.schema_type(SchemaType::from_iter([Type::Array, Type::Null]))
.items(Object::with_type(Type::String))
.build();Sourcepub fn title<I>(self, title: Option<I>) -> ArrayBuilder
Available on crate feature rest only.
pub fn title<I>(self, title: Option<I>) -> ArrayBuilder
rest only.Add or change the title of the Array.
Sourcepub fn description<I>(self, description: Option<I>) -> ArrayBuilder
Available on crate feature rest only.
pub fn description<I>(self, description: Option<I>) -> ArrayBuilder
rest only.Add or change description of the property. Markdown syntax is supported.
Sourcepub fn deprecated(self, deprecated: Option<Deprecated>) -> ArrayBuilder
Available on crate feature rest only.
pub fn deprecated(self, deprecated: Option<Deprecated>) -> ArrayBuilder
rest only.Add or change deprecated status for Array.
Sourcepub fn example(self, example: Option<Value>) -> ArrayBuilder
👎Deprecated: Since OpenAPI 3.1 prefer using examples
Available on crate feature rest only.
pub fn example(self, example: Option<Value>) -> ArrayBuilder
Since OpenAPI 3.1 prefer using examples
rest only.Add or change example shown in UI of the value for richer documentation.
Deprecated since 3.0.x. Prefer Array::examples instead
Sourcepub fn examples<I, V>(self, examples: I) -> ArrayBuilder
Available on crate feature rest only.
pub fn examples<I, V>(self, examples: I) -> ArrayBuilder
rest only.Add or change examples shown in UI of the value for richer documentation.
Sourcepub fn default(self, default: Option<Value>) -> ArrayBuilder
Available on crate feature rest only.
pub fn default(self, default: Option<Value>) -> ArrayBuilder
rest only.Add or change default value for the object which is provided when user has not provided the input in Swagger UI.
Sourcepub fn max_items(self, max_items: Option<usize>) -> ArrayBuilder
Available on crate feature rest only.
pub fn max_items(self, max_items: Option<usize>) -> ArrayBuilder
rest only.Set maximum allowed length for Array.
Sourcepub fn min_items(self, min_items: Option<usize>) -> ArrayBuilder
Available on crate feature rest only.
pub fn min_items(self, min_items: Option<usize>) -> ArrayBuilder
rest only.Set minimum allowed length for Array.
Sourcepub fn unique_items(self, unique_items: bool) -> ArrayBuilder
Available on crate feature rest only.
pub fn unique_items(self, unique_items: bool) -> ArrayBuilder
rest only.Set or change whether Array should enforce all items to be unique.
Sourcepub fn xml(self, xml: Option<Xml>) -> ArrayBuilder
Available on crate feature rest only.
pub fn xml(self, xml: Option<Xml>) -> ArrayBuilder
rest only.Sourcepub fn content_encoding<S>(self, content_encoding: S) -> ArrayBuilder
Available on crate feature rest only.
pub fn content_encoding<S>(self, content_encoding: S) -> ArrayBuilder
rest only.Set of change Object::content_encoding. Typically left empty but could be base64 for
example.
Sourcepub fn content_media_type<S>(self, content_media_type: S) -> ArrayBuilder
Available on crate feature rest only.
pub fn content_media_type<S>(self, content_media_type: S) -> ArrayBuilder
rest only.Set of change Object::content_media_type. Value must be valid MIME type e.g.
application/json.
Sourcepub fn extensions(self, extensions: Option<Extensions>) -> ArrayBuilder
Available on crate feature rest only.
pub fn extensions(self, extensions: Option<Extensions>) -> ArrayBuilder
rest only.Add openapi extensions (x-something) for Array.
Sourcepub fn to_array_builder(self) -> ArrayBuilder
Available on crate feature rest only.
pub fn to_array_builder(self) -> ArrayBuilder
rest only.Construct a new ArrayBuilder with this component set to ArrayBuilder::items.