ClientRouter

Struct ClientRouter 

pub struct ClientRouter { /* private fields */ }
Available on crate feature client-router only.
The main client-side router.

ClientRouter renders views using the Page type.

Implementations

Source

impl ClientRouter

pub fn new() -> ClientRouter

Available on crate feature test and non-WebAssembly only.

Creates a new router.

pub fn route<F>(self, pattern: &str, component: F) -> ClientRouter
where F: Fn() -> Page + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route to the router.

pub fn named_route<F>( self, name: &str, pattern: &str, component: F, ) -> ClientRouter
where F: Fn() -> Page + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route to the router.

pub fn route_params<F, T>(self, pattern: &str, handler: F) -> ClientRouter
where F: Fn(Path<T>) -> Page + Send + Sync + 'static, T: FromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with typed path parameters.

pub fn named_route_params<F, T>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T>) -> Page + Send + Sync + 'static, T: FromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route with typed path parameters.

pub fn route_result<F, T, E>(self, pattern: &str, handler: F) -> ClientRouter
where F: Fn(Path<T>) -> Result<Page, E> + Send + Sync + 'static, T: FromPath + Send + Sync + 'static, E: Into<RouterError> + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with typed path parameters that returns a Result.

pub fn named_route_result<F, T, E>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T>) -> Result<Page, E> + Send + Sync + 'static, T: FromPath + Send + Sync + 'static, E: Into<RouterError> + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route with typed path parameters that returns a Result.

pub fn guarded_route<F, G>( self, pattern: &str, component: F, guard: G, ) -> ClientRouter
where F: Fn() -> Page + Send + Sync + 'static, G: Fn(&ClientRouteMatch) -> bool + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with a guard.

pub fn route_path<F, T>(self, pattern: &str, handler: F) -> ClientRouter
where F: Fn(Path<T>) -> Page + Send + Sync + 'static, T: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with a single path parameter using Path<T> extractor.

Example
let router = ClientRouter::new()
    .route_path("/users/{id}/", |Path(id): Path<i64>| {
        user_detail(id)
    });
pub fn named_route_path<F, T>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T>) -> Page + Send + Sync + 'static, T: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route with a single path parameter using Path<T> extractor.

pub fn route_path2<F, T1, T2>(self, pattern: &str, handler: F) -> ClientRouter
where F: Fn(Path<T1>, Path<T2>) -> Page + Send + Sync + 'static, T1: SingleFromPath + Send + Sync + 'static, T2: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with two path parameters using multiple Path<T> extractors.

Example
let router = ClientRouter::new()
    .route_path2("/users/{user_id}/posts/{post_id}/",
        |Path(user_id): Path<i64>, Path(post_id): Path<i64>| {
            user_post_detail(user_id, post_id)
        });
pub fn named_route_path2<F, T1, T2>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T1>, Path<T2>) -> Page + Send + Sync + 'static, T1: SingleFromPath + Send + Sync + 'static, T2: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route with two path parameters.

pub fn route_path3<F, T1, T2, T3>( self, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T1>, Path<T2>, Path<T3>) -> Page + Send + Sync + 'static, T1: SingleFromPath + Send + Sync + 'static, T2: SingleFromPath + Send + Sync + 'static, T3: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a route with three path parameters using multiple Path<T> extractors.

Example
let router = ClientRouter::new()
    .route_path3("/org/{org}/repos/{repo}/issues/{issue}/",
        |Path(org): Path<String>, Path(repo): Path<String>, Path(issue): Path<i32>| {
            issue_detail(org, repo, issue)
        });
pub fn named_route_path3<F, T1, T2, T3>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
where F: Fn(Path<T1>, Path<T2>, Path<T3>) -> Page + Send + Sync + 'static, T1: SingleFromPath + Send + Sync + 'static, T2: SingleFromPath + Send + Sync + 'static, T3: SingleFromPath + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Adds a named route with three path parameters.

pub fn not_found<F>(self, component: F) -> ClientRouter
where F: Fn() -> Page + Send + Sync + 'static,

Available on crate feature test and non-WebAssembly only.

Sets the not found handler.

pub fn current_path(&self) -> &Signal<String>

Available on crate feature test and non-WebAssembly only.

Returns the current path signal.

pub fn current_params(&self) -> &Signal<HashMap<String, String>>

Available on crate feature test and non-WebAssembly only.

Returns the current params signal.

pub fn current_route_name(&self) -> &Signal<Option<String>>

Available on crate feature test and non-WebAssembly only.

Returns the current route name signal.

pub fn match_path(&self, path: &str) -> Option<ClientRouteMatch>

Available on crate feature test and non-WebAssembly only.

Matches a path against registered routes.

pub fn push(&self, path: &str) -> Result<(), RouterError>

Available on crate feature test and non-WebAssembly only.

Navigates to a path using pushState.

pub fn replace(&self, path: &str) -> Result<(), RouterError>

Available on crate feature test and non-WebAssembly only.

Navigates to a path using replaceState.

pub fn reverse( &self, name: &str, params: &[(&str, &str)], ) -> Result<String, RouterError>

Available on crate feature test and non-WebAssembly only.

Generates a URL by route name with parameters.

pub fn render_current(&self) -> Option<Page>

Available on crate feature test and non-WebAssembly only.

Renders the current route’s component.

This method renders the view for the current path. If no route matches, it returns None if no not_found handler is set.

pub fn route_count(&self) -> usize

Available on crate feature test and non-WebAssembly only.

Returns the number of registered routes.

pub fn has_route(&self, name: &str) -> bool

Available on crate feature test and non-WebAssembly only.

Checks if a route name exists.

pub fn setup_history_listener(&self)

Available on crate feature test and non-WebAssembly only.

Non-WASM version of setup_history_listener.