pub struct ClientRouter { /* private fields */ }client-router only.Expand description
The main client-side router.
ClientRouter renders views using the Page type.
Implementations
Sourceimpl ClientRouter
impl ClientRouter
Sourcepub fn new() -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn new() -> ClientRouter
test and non-WebAssembly only.Creates a new router.
Sourcepub fn route<F>(self, pattern: &str, component: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route<F>(self, pattern: &str, component: F) -> ClientRouter
test and non-WebAssembly only.Adds a route to the router.
Sourcepub fn named_route<F>(
self,
name: &str,
pattern: &str,
component: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route<F>( self, name: &str, pattern: &str, component: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route to the router.
Sourcepub fn route_params<F, T>(self, pattern: &str, handler: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route_params<F, T>(self, pattern: &str, handler: F) -> ClientRouter
test and non-WebAssembly only.Adds a route with typed path parameters.
Sourcepub fn named_route_params<F, T>(
self,
name: &str,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route_params<F, T>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route with typed path parameters.
Sourcepub fn route_result<F, T, E>(self, pattern: &str, handler: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route_result<F, T, E>(self, pattern: &str, handler: F) -> ClientRouter
test and non-WebAssembly only.Adds a route with typed path parameters that returns a Result.
Sourcepub fn named_route_result<F, T, E>(
self,
name: &str,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route_result<F, T, E>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route with typed path parameters that returns a Result.
Sourcepub fn guarded_route<F, G>(
self,
pattern: &str,
component: F,
guard: G,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn guarded_route<F, G>( self, pattern: &str, component: F, guard: G, ) -> ClientRouter
test and non-WebAssembly only.Adds a route with a guard.
Sourcepub fn route_path<F, T>(self, pattern: &str, handler: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route_path<F, T>(self, pattern: &str, handler: F) -> ClientRouter
test and non-WebAssembly only.Sourcepub fn named_route_path<F, T>(
self,
name: &str,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route_path<F, T>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route with a single path parameter using Path<T> extractor.
Sourcepub fn route_path2<F, T1, T2>(self, pattern: &str, handler: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route_path2<F, T1, T2>(self, pattern: &str, handler: F) -> ClientRouter
test and non-WebAssembly only.Sourcepub fn named_route_path2<F, T1, T2>(
self,
name: &str,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route_path2<F, T1, T2>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route with two path parameters.
Sourcepub fn route_path3<F, T1, T2, T3>(
self,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn route_path3<F, T1, T2, T3>( self, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Sourcepub fn named_route_path3<F, T1, T2, T3>(
self,
name: &str,
pattern: &str,
handler: F,
) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn named_route_path3<F, T1, T2, T3>( self, name: &str, pattern: &str, handler: F, ) -> ClientRouter
test and non-WebAssembly only.Adds a named route with three path parameters.
Sourcepub fn not_found<F>(self, component: F) -> ClientRouter
Available on crate feature test and non-WebAssembly only.
pub fn not_found<F>(self, component: F) -> ClientRouter
test and non-WebAssembly only.Sets the not found handler.
Sourcepub fn current_path(&self) -> &Signal<String>
Available on crate feature test and non-WebAssembly only.
pub fn current_path(&self) -> &Signal<String>
test and non-WebAssembly only.Returns the current path signal.
Sourcepub fn current_params(&self) -> &Signal<HashMap<String, String>>
Available on crate feature test and non-WebAssembly only.
pub fn current_params(&self) -> &Signal<HashMap<String, String>>
test and non-WebAssembly only.Returns the current params signal.
Sourcepub fn current_route_name(&self) -> &Signal<Option<String>>
Available on crate feature test and non-WebAssembly only.
pub fn current_route_name(&self) -> &Signal<Option<String>>
test and non-WebAssembly only.Returns the current route name signal.
Sourcepub fn match_path(&self, path: &str) -> Option<ClientRouteMatch>
Available on crate feature test and non-WebAssembly only.
pub fn match_path(&self, path: &str) -> Option<ClientRouteMatch>
test and non-WebAssembly only.Matches a path against registered routes.
Sourcepub fn push(&self, path: &str) -> Result<(), RouterError>
Available on crate feature test and non-WebAssembly only.
pub fn push(&self, path: &str) -> Result<(), RouterError>
test and non-WebAssembly only.Navigates to a path using pushState.
Sourcepub fn replace(&self, path: &str) -> Result<(), RouterError>
Available on crate feature test and non-WebAssembly only.
pub fn replace(&self, path: &str) -> Result<(), RouterError>
test and non-WebAssembly only.Navigates to a path using replaceState.
Sourcepub fn reverse(
&self,
name: &str,
params: &[(&str, &str)],
) -> Result<String, RouterError>
Available on crate feature test and non-WebAssembly only.
pub fn reverse( &self, name: &str, params: &[(&str, &str)], ) -> Result<String, RouterError>
test and non-WebAssembly only.Generates a URL by route name with parameters.
Sourcepub fn render_current(&self) -> Option<Page>
Available on crate feature test and non-WebAssembly only.
pub fn render_current(&self) -> Option<Page>
test and non-WebAssembly only.Renders the current route’s component.
This method renders the view for the current path. If no route matches,
it returns None if no not_found handler is set.
Sourcepub fn route_count(&self) -> usize
Available on crate feature test and non-WebAssembly only.
pub fn route_count(&self) -> usize
test and non-WebAssembly only.Returns the number of registered routes.
Sourcepub fn has_route(&self, name: &str) -> bool
Available on crate feature test and non-WebAssembly only.
pub fn has_route(&self, name: &str) -> bool
test and non-WebAssembly only.Checks if a route name exists.
Sourcepub fn setup_history_listener(&self)
Available on crate feature test and non-WebAssembly only.
pub fn setup_history_listener(&self)
test and non-WebAssembly only.Non-WASM version of setup_history_listener.