ConnectionPool

Struct ConnectionPool 

pub struct ConnectionPool<DB>
where DB: Database,
{ /* private fields */ }
Available on crate feature database and non-WebAssembly only.
A database connection pool

Implementations

Source

impl ConnectionPool<Postgres>

pub async fn new_postgres( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<Postgres>, PoolError>

Create a new PostgreSQL connection pool

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of PostgreSQL
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert_eq!(pool.config().max_connections, 10);
Source

impl ConnectionPool<MySql>

pub async fn new_mysql( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<MySql>, PoolError>

Create a new MySQL connection pool

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of MySQL
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert_eq!(pool.config().max_connections, 10);
Source

impl ConnectionPool<Sqlite>

pub async fn new_sqlite( url: &str, config: PoolConfig, ) -> Result<ConnectionPool<Sqlite>, PoolError>

Create a new SQLite connection pool

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
// Using in-memory SQLite for doctest
let pool = ConnectionPool::new_sqlite("sqlite::memory:", config).await.unwrap();
assert!(pool.url().contains("memory"));
assert!(pool.config().max_connections > 0);
Source

impl<DB> ConnectionPool<DB>
where DB: Database,

pub async fn add_listener(&self, listener: Arc<dyn PoolEventListener>)

Add an event listener

pub async fn acquire(&self) -> Result<PooledConnection<DB>, PoolError>

Acquire a connection from the pool with event emission

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
let pool = ConnectionPool::new_postgres("postgresql://user:pass@localhost/test", config)
    .await
    .unwrap();

// Acquire a connection
let conn = pool.acquire().await;
assert!(conn.is_ok());
pub fn inner(&self) -> &Pool<DB>

Get the underlying pool

pub fn config(&self) -> &PoolConfig

Get pool configuration

pub async fn close(&self)

Close the pool

Attempts to gracefully close the pool with a 5-second timeout. If active connections are not returned within this time, the pool will be forcefully closed.

pub fn url(&self) -> String

Get the database URL with password masked for safe display

Returns the database URL with any password replaced by *** to prevent credential exposure in logs and debug output. Use url_raw() when the actual password is needed for reconnection.

Source

impl ConnectionPool<Postgres>

pub async fn recreate(&mut self) -> Result<(), PoolError>

Recreate the pool with the same configuration

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of PostgreSQL
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
    .await
    .unwrap();

// Recreate the pool
pool.recreate().await.unwrap();
assert_eq!(pool.config().max_connections, 10);
Source

impl ConnectionPool<MySql>

pub async fn recreate(&mut self) -> Result<(), PoolError>

Recreate the pool with the same configuration

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
// For doctest purposes, using SQLite in-memory instead of MySQL
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
    .await
    .unwrap();

// Recreate the pool
pool.recreate().await.unwrap();
assert_eq!(pool.config().max_connections, 10);
Source

impl ConnectionPool<Sqlite>

pub async fn recreate(&mut self) -> Result<(), PoolError>

Recreate the pool with the same configuration

Examples
use reinhardt_db::pool::{ConnectionPool, PoolConfig};

let config = PoolConfig::default();
let mut pool = ConnectionPool::new_sqlite("sqlite::memory:", config)
    .await
    .unwrap();

// Recreate the pool
pool.recreate().await.unwrap();
assert!(pool.url().contains("memory"));