pub struct DefaultRouter { /* private fields */ }native only.Expand description
Default router implementation Similar to Django REST Framework’s DefaultRouter and Django’s URLResolver
Implementations
Sourceimpl DefaultRouter
impl DefaultRouter
Sourcepub fn new() -> DefaultRouter
Available on crate feature test only.
pub fn new() -> DefaultRouter
test only.Create a new DefaultRouter
Examples
use reinhardt_urls::routers::DefaultRouter;
let router = DefaultRouter::new();
assert_eq!(router.get_routes().len(), 0);Sourcepub fn reverser(&self) -> &UrlReverser
Available on crate feature test only.
pub fn reverser(&self) -> &UrlReverser
test only.Get a reference to the URL reverser This allows for URL name resolution (reverse routing)
Examples
use reinhardt_urls::routers::DefaultRouter;
let router = DefaultRouter::new();
let reverser = router.reverser();
assert_eq!(reverser.route_names().len(), 0);Sourcepub fn reverse(
&self,
name: &str,
params: &HashMap<String, String>,
) -> Result<String, Error>
Available on crate feature test only.
pub fn reverse( &self, name: &str, params: &HashMap<String, String>, ) -> Result<String, Error>
test only.Reverse a URL name to a path Similar to Django’s reverse() function
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
use std::collections::HashMap;
let handler = Arc::new(DummyHandler);
let mut router = DefaultRouter::new();
let mut route = path("/users/{id}/", handler)
.with_namespace("users");
route.name = Some("detail".to_string());
router.add_route(route);
let mut params = HashMap::new();
params.insert("id".to_string(), "123".to_string());
let url = router.reverse("users:detail", ¶ms).unwrap();
assert_eq!(url, "/users/123/");Sourcepub fn reverse_with<S>(
&self,
name: &str,
params: &[(S, S)],
) -> Result<String, Error>
Available on crate feature test only.
pub fn reverse_with<S>( &self, name: &str, params: &[(S, S)], ) -> Result<String, Error>
test only.Reverse a URL name with positional parameters Convenience method for simple parameter passing
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
let handler = Arc::new(DummyHandler);
let mut router = DefaultRouter::new();
let mut route = path("/users/{id}/", handler);
route.name = Some("detail".to_string());
router.add_route(route);
let url = router.reverse_with("detail", &[("id", "123")]).unwrap();
assert_eq!(url, "/users/123/");Sourcepub fn register_viewset<V>(&mut self, prefix: &str, viewset: Arc<V>)where
V: ViewSet + 'static,
Available on crate features test and viewsets only.
pub fn register_viewset<V>(&mut self, prefix: &str, viewset: Arc<V>)where
V: ViewSet + 'static,
test and viewsets only.Register a ViewSet with automatic URL pattern generation Similar to DRF’s router.register()
Examples
use reinhardt_urls::routers::DefaultRouter;
use reinhardt_views::viewsets::ViewSet;
use std::sync::Arc;
let viewset = Arc::new(DummyViewSet);
let mut router = DefaultRouter::new();
router.register_viewset("users", viewset);
assert_eq!(router.get_routes().len(), 2);Sourcepub fn get_action_url_map<V>(
&self,
viewset: &V,
base_url: &str,
) -> HashMap<String, String>where
V: ViewSet,
Available on crate features test and viewsets only.
pub fn get_action_url_map<V>(
&self,
viewset: &V,
base_url: &str,
) -> HashMap<String, String>where
V: ViewSet,
test and viewsets only.Get URL map for a ViewSet’s extra actions Returns a map of action names to their full URLs
Examples
use reinhardt_urls::routers::DefaultRouter;
use reinhardt_views::viewsets::{ViewSet, register_action, ActionMetadata, FunctionActionHandler};
use std::sync::Arc;
let viewset = Arc::new(DummyViewSet);
let mut router = DefaultRouter::new();
router.register_viewset("test", viewset.clone());
let url_map = router.get_action_url_map(viewset.as_ref(), "http://testserver");
// The ViewSet has no extra actions, so the map will be empty
assert!(url_map.is_empty());Sourcepub fn get_routes(&self) -> &[Route]
Available on crate feature test only.
pub fn get_routes(&self) -> &[Route]
test only.Get all registered routes
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
let handler = Arc::new(DummyHandler);
let mut router = DefaultRouter::new();
router.add_route(path("/users/", handler));
assert_eq!(router.get_routes().len(), 1);
assert_eq!(router.get_routes()[0].path, "/users/");Sourcepub fn find_routes_by_namespace_pattern(&self, pattern: &str) -> Vec<&Route>
Available on crate feature test only.
pub fn find_routes_by_namespace_pattern(&self, pattern: &str) -> Vec<&Route>
test only.Find routes that match a namespace pattern Used for namespace-based versioning
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
let handler = Arc::new(DummyHandler);
let mut router = DefaultRouter::new();
router.add_route(path("/v1/users/", handler.clone()).with_namespace("v1"));
router.add_route(path("/v2/users/", handler).with_namespace("v2"));
let v1_routes = router.find_routes_by_namespace_pattern("/v{version}/");
assert_eq!(v1_routes.len(), 2);Sourcepub fn extract_version_from_path<'a>(
&self,
path: &'a str,
pattern: &str,
) -> Option<&'a str>
Available on crate feature test only.
pub fn extract_version_from_path<'a>( &self, path: &'a str, pattern: &str, ) -> Option<&'a str>
test only.Extract version from a path using namespace pattern Returns the version string if the path matches the pattern
Examples
use reinhardt_urls::routers::DefaultRouter;
let router = DefaultRouter::new();
assert_eq!(router.extract_version_from_path("/v1/users/", "/v{version}/"), Some("1"));
assert_eq!(router.extract_version_from_path("/v2/api/", "/v{version}/"), Some("2"));
assert_eq!(router.extract_version_from_path("/users/", "/v{version}/"), None);Sourcepub fn get_available_versions(&self, pattern: &str) -> Vec<String>
Available on crate feature test only.
pub fn get_available_versions(&self, pattern: &str) -> Vec<String>
test only.Get all unique versions found in registered routes for a given pattern Used for namespace-based versioning to discover available versions
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
let handler = Arc::new(DummyHandler);
let mut router = DefaultRouter::new();
router.add_route(path("/v1/users/", handler.clone()).with_namespace("v1"));
router.add_route(path("/v2/users/", handler.clone()).with_namespace("v2"));
router.add_route(path("/v1/posts/", handler).with_namespace("v1"));
let versions = router.get_available_versions("/v{version}/");
assert!(versions.contains(&"1".to_string()));
assert!(versions.contains(&"2".to_string()));
assert_eq!(versions.len(), 2);Trait Implementations
Sourceimpl Default for DefaultRouter
impl Default for DefaultRouter
Sourcefn default() -> DefaultRouter
fn default() -> DefaultRouter
Sourceimpl Handler for DefaultRouter
impl Handler for DefaultRouter
Sourceimpl Router for DefaultRouter
impl Router for DefaultRouter
Sourcefn mount(&mut self, prefix: &str, routes: Vec<Route>, namespace: Option<String>)
fn mount(&mut self, prefix: &str, routes: Vec<Route>, namespace: Option<String>)
Mount routes at the given prefix
Examples
use reinhardt_urls::routers::{DefaultRouter, Router, path};
use reinhardt_http::Handler;
use std::sync::Arc;
let handler = Arc::new(DummyHandler);
let mut list_route = path("/", handler.clone());
list_route.name = Some("list".to_string());
let mut detail_route = path("/{id}/", handler);
detail_route.name = Some("detail".to_string());
let users_routes = vec![list_route, detail_route];
let mut router = DefaultRouter::new();
router.mount("/users", users_routes, Some("users".to_string()));
// Routes are prefixed: /users/ and /users/{id}/
assert_eq!(router.get_routes().len(), 2);Sourceimpl VersionedRouter for DefaultRouter
impl VersionedRouter for DefaultRouter
Sourcefn route_version_infos(&self) -> Vec<RouteVersionInfo>
fn route_version_infos(&self) -> Vec<RouteVersionInfo>
RouteVersionInfo entry per registered route.Auto Trait Implementations
impl !Freeze for DefaultRouter
impl !RefUnwindSafe for DefaultRouter
impl !UnwindSafe for DefaultRouter
impl Send for DefaultRouter
impl Sync for DefaultRouter
impl Unpin for DefaultRouter
impl UnsafeUnpin for DefaultRouter