pub struct ObjectBuilder { /* private fields */ }openapi and non-WebAssembly only.Implementations
Sourceimpl ObjectBuilder
impl ObjectBuilder
Sourcepub fn new() -> ObjectBuilder
Available on crate feature rest only.
pub fn new() -> ObjectBuilder
rest only.Constructs a new ObjectBuilder.
Sourceimpl ObjectBuilder
impl ObjectBuilder
Sourcepub fn schema_type<T>(self, schema_type: T) -> ObjectBuilderwhere
T: Into<SchemaType>,
Available on crate feature rest only.
pub fn schema_type<T>(self, schema_type: T) -> ObjectBuilderwhere
T: Into<SchemaType>,
rest only.Add or change type of the object e.g. to change type to string
use value SchemaType::Type(Type::String).
Sourcepub fn format(self, format: Option<SchemaFormat>) -> ObjectBuilder
Available on crate feature rest only.
pub fn format(self, format: Option<SchemaFormat>) -> ObjectBuilder
rest only.Add or change additional format for detailing the schema type.
Sourcepub fn property<S, I>(self, property_name: S, component: I) -> ObjectBuilder
Available on crate feature rest only.
pub fn property<S, I>(self, property_name: S, component: I) -> ObjectBuilder
rest only.Add new property to the Object.
Method accepts property name and property component as an arguments.
Sourcepub fn additional_properties<I>(
self,
additional_properties: Option<I>,
) -> ObjectBuilder
Available on crate feature rest only.
pub fn additional_properties<I>( self, additional_properties: Option<I>, ) -> ObjectBuilder
rest only.Add additional Schema for non specified fields (Useful for typed maps).
Sourcepub fn property_names<S>(self, property_name: Option<S>) -> ObjectBuilder
Available on crate feature rest only.
pub fn property_names<S>(self, property_name: Option<S>) -> ObjectBuilder
rest only.Add additional Schema to describe property names of an object such as a map. See more
details https://json-schema.org/draft/2020-12/draft-bhutton-json-schema-01#name-propertynames
Sourcepub fn required<I>(self, required_field: I) -> ObjectBuilder
Available on crate feature rest only.
pub fn required<I>(self, required_field: I) -> ObjectBuilder
rest only.Add field to the required fields of Object.
Sourcepub fn title<I>(self, title: Option<I>) -> ObjectBuilder
Available on crate feature rest only.
pub fn title<I>(self, title: Option<I>) -> ObjectBuilder
rest only.Add or change the title of the Object.
Sourcepub fn description<I>(self, description: Option<I>) -> ObjectBuilder
Available on crate feature rest only.
pub fn description<I>(self, description: Option<I>) -> ObjectBuilder
rest only.Add or change description of the property. Markdown syntax is supported.
Sourcepub fn default(self, default: Option<Value>) -> ObjectBuilder
Available on crate feature rest only.
pub fn default(self, default: Option<Value>) -> ObjectBuilder
rest only.Add or change default value for the object which is provided when user has not provided the input in Swagger UI.
Sourcepub fn deprecated(self, deprecated: Option<Deprecated>) -> ObjectBuilder
Available on crate feature rest only.
pub fn deprecated(self, deprecated: Option<Deprecated>) -> ObjectBuilder
rest only.Add or change deprecated status for Object.
Sourcepub fn enum_values<I, E>(self, enum_values: Option<I>) -> ObjectBuilder
Available on crate feature rest only.
pub fn enum_values<I, E>(self, enum_values: Option<I>) -> ObjectBuilder
rest only.Add or change enum property variants.
Sourcepub fn example(self, example: Option<Value>) -> ObjectBuilder
👎Deprecated: Since OpenAPI 3.1 prefer using examples
Available on crate feature rest only.
pub fn example(self, example: Option<Value>) -> ObjectBuilder
Since OpenAPI 3.1 prefer using examples
rest only.Add or change example shown in UI of the value for richer documentation.
Deprecated since 3.0.x. Prefer Object::examples instead
Sourcepub fn examples<I, V>(self, examples: I) -> ObjectBuilder
Available on crate feature rest only.
pub fn examples<I, V>(self, examples: I) -> ObjectBuilder
rest only.Add or change examples shown in UI of the value for richer documentation.
Sourcepub fn write_only(self, write_only: Option<bool>) -> ObjectBuilder
Available on crate feature rest only.
pub fn write_only(self, write_only: Option<bool>) -> ObjectBuilder
rest only.Add or change write only flag for Object.
Sourcepub fn read_only(self, read_only: Option<bool>) -> ObjectBuilder
Available on crate feature rest only.
pub fn read_only(self, read_only: Option<bool>) -> ObjectBuilder
rest only.Add or change read only flag for Object.
Sourcepub fn xml(self, xml: Option<Xml>) -> ObjectBuilder
Available on crate feature rest only.
pub fn xml(self, xml: Option<Xml>) -> ObjectBuilder
rest only.Sourcepub fn multiple_of<N>(self, multiple_of: Option<N>) -> ObjectBuilder
Available on crate feature rest only.
pub fn multiple_of<N>(self, multiple_of: Option<N>) -> ObjectBuilder
rest only.Set or change multiple_of validation flag for number and integer type values.
Sourcepub fn maximum<N>(self, maximum: Option<N>) -> ObjectBuilder
Available on crate feature rest only.
pub fn maximum<N>(self, maximum: Option<N>) -> ObjectBuilder
rest only.Set or change inclusive maximum value for number and integer values.
Sourcepub fn minimum<N>(self, minimum: Option<N>) -> ObjectBuilder
Available on crate feature rest only.
pub fn minimum<N>(self, minimum: Option<N>) -> ObjectBuilder
rest only.Set or change inclusive minimum value for number and integer values.
Sourcepub fn exclusive_maximum<N>(self, exclusive_maximum: Option<N>) -> ObjectBuilder
Available on crate feature rest only.
pub fn exclusive_maximum<N>(self, exclusive_maximum: Option<N>) -> ObjectBuilder
rest only.Set or change exclusive maximum value for number and integer values.
Sourcepub fn exclusive_minimum<N>(self, exclusive_minimum: Option<N>) -> ObjectBuilder
Available on crate feature rest only.
pub fn exclusive_minimum<N>(self, exclusive_minimum: Option<N>) -> ObjectBuilder
rest only.Set or change exclusive minimum value for number and integer values.
Sourcepub fn max_length(self, max_length: Option<usize>) -> ObjectBuilder
Available on crate feature rest only.
pub fn max_length(self, max_length: Option<usize>) -> ObjectBuilder
rest only.Set or change maximum length for string values.
Sourcepub fn min_length(self, min_length: Option<usize>) -> ObjectBuilder
Available on crate feature rest only.
pub fn min_length(self, min_length: Option<usize>) -> ObjectBuilder
rest only.Set or change minimum length for string values.
Sourcepub fn pattern<I>(self, pattern: Option<I>) -> ObjectBuilder
Available on crate feature rest only.
pub fn pattern<I>(self, pattern: Option<I>) -> ObjectBuilder
rest only.Set or change a valid regular expression for string value to match.
Sourcepub fn max_properties(self, max_properties: Option<usize>) -> ObjectBuilder
Available on crate feature rest only.
pub fn max_properties(self, max_properties: Option<usize>) -> ObjectBuilder
rest only.Set or change maximum number of properties the Object can hold.
Sourcepub fn min_properties(self, min_properties: Option<usize>) -> ObjectBuilder
Available on crate feature rest only.
pub fn min_properties(self, min_properties: Option<usize>) -> ObjectBuilder
rest only.Set or change minimum number of properties the Object can hold.
Sourcepub fn extensions(self, extensions: Option<Extensions>) -> ObjectBuilder
Available on crate feature rest only.
pub fn extensions(self, extensions: Option<Extensions>) -> ObjectBuilder
rest only.Add openapi extensions (x-something) for Object.
Sourcepub fn content_encoding<S>(self, content_encoding: S) -> ObjectBuilder
Available on crate feature rest only.
pub fn content_encoding<S>(self, content_encoding: S) -> ObjectBuilder
rest only.Set of change Object::content_encoding. Typically left empty but could be base64 for
example.
Sourcepub fn content_media_type<S>(self, content_media_type: S) -> ObjectBuilder
Available on crate feature rest only.
pub fn content_media_type<S>(self, content_media_type: S) -> ObjectBuilder
rest only.Set of change Object::content_media_type. Value must be valid MIME type e.g.
application/json.
Sourcepub fn to_array_builder(self) -> ArrayBuilder
Available on crate feature rest only.
pub fn to_array_builder(self) -> ArrayBuilder
rest only.Construct a new ArrayBuilder with this component set to ArrayBuilder::items.