#[non_exhaustive]pub struct Response {
pub description: String,
pub headers: BTreeMap<String, Header>,
pub content: IndexMap<String, Content>,
pub extensions: Option<Extensions>,
pub links: BTreeMap<String, RefOr<Link>>,
}Available on crate feature
openapi only.Expand description
Implements OpenAPI Response Object.
Response is api operation response.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: StringDescription of the response. Response support markdown syntax.
headers: BTreeMap<String, Header>Map of headers identified by their name. Content-Type header will be ignored.
content: IndexMap<String, Content>Map of response Content objects identified by response body content type e.g application/json.
Contents are stored within IndexMap to retain their insertion order. Swagger UI
will create and show default example according to the first entry in content map.
extensions: Option<Extensions>Optional extensions “x-something”.
links: BTreeMap<String, RefOr<Link>>A map of operations links that can be followed from the response. The key of the map is a short name for the link.
Implementations
Sourceimpl Response
impl Response
Sourcepub fn builder() -> ResponseBuilder
Available on native and crate feature rest only.
pub fn builder() -> ResponseBuilder
native and crate feature rest only.Construct a new ResponseBuilder.
This is effectively same as calling ResponseBuilder::new