#[non_exhaustive]pub struct Server {
pub url: String,
pub description: Option<String>,
pub variables: Option<BTreeMap<String, ServerVariable>>,
pub extensions: Option<Extensions>,
}openapi only.Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringTarget url of the Server. It can be valid http url or relative path.
Url also supports variable substitution with {variable} syntax. The substitutions
then can be configured with Server::variables map.
description: Option<String>Optional description describing the target server url. Description supports markdown syntax.
variables: Option<BTreeMap<String, ServerVariable>>Optional map of variable name and its substitution value used in Server::url.
extensions: Option<Extensions>Optional extensions “x-something”.
Implementations
Sourceimpl Server
impl Server
Sourcepub fn builder() -> ServerBuilder
Available on native and crate feature rest only.
pub fn builder() -> ServerBuilder
native and crate feature rest only.Construct a new ServerBuilder.
This is effectively same as calling ServerBuilder::new
Sourceimpl Server
impl Server
Sourcepub fn new<S>(url: S) -> Server
Available on native and crate feature rest only.
pub fn new<S>(url: S) -> Server
native and crate feature rest only.Construct a new Server with given url. Url can be valid http url or context path of the url.
If url is valid http url then all path operation request’s will be forwarded to the selected Server.
If url is path of url e.g. /api/v1 then the url will be appended to the servers address and the
operations will be forwarded to location server address + url.
Examples
Create new server with url path.
Server::new("/api/v1");Create new server with alternative server.
Server::new("https://alternative.pet-api.test/api/v1");Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Server
impl<'de> Deserialize<'de> for Server
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Server, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Server, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for Server
Sourceimpl From<Server> for ServerBuilder
impl From<Server> for ServerBuilder
Sourcefn from(value: Server) -> ServerBuilder
fn from(value: Server) -> ServerBuilder
Sourceimpl From<ServerBuilder> for Server
impl From<ServerBuilder> for Server
Sourcefn from(value: ServerBuilder) -> Server
fn from(value: ServerBuilder) -> Server
Sourceimpl Serialize for Server
impl Serialize for Server
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl StructuralPartialEq for Server