pub struct Session<B>where
B: SessionBackend,{ /* private fields */ }native and crate feature sessions only.Expand description
Django-style session object with dictionary-like interface
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// Set session data
session.set("user_id", 42)?;
session.set("username", "alice")?;
// Get session data
let user_id: i32 = session.get("user_id")?.unwrap();
assert_eq!(user_id, 42);
// Check if key exists
assert!(session.contains_key("username"));
// Delete a key
session.delete("username");
// Save session
session.save().await?;Implementations
Sourceimpl<B> Session<B>where
B: SessionBackend,
impl<B> Session<B>where
B: SessionBackend,
Sourcepub fn new(backend: B) -> Session<B>
Available on crate feature auth only.
pub fn new(backend: B) -> Session<B>
auth only.Create a new session with the given backend
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let session = Session::new(backend);Sourcepub async fn from_key(
backend: B,
session_key: String,
) -> Result<Session<B>, SessionError>
Available on crate feature auth only.
pub async fn from_key( backend: B, session_key: String, ) -> Result<Session<B>, SessionError>
auth only.Create a session from an existing session key
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let session = Session::from_key(backend, "session_key_123".to_string()).await?;Sourcepub fn get<T>(&mut self, key: &str) -> Result<Option<T>, Error>where
T: for<'de> Deserialize<'de>,
Available on crate feature auth only.
pub fn get<T>(&mut self, key: &str) -> Result<Option<T>, Error>where
T: for<'de> Deserialize<'de>,
auth only.Get a value from the session
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("count", 42)?;
let count: i32 = session.get("count")?.unwrap();
assert_eq!(count, 42);Sourcepub fn set<T>(&mut self, key: &str, value: T) -> Result<(), Error>where
T: Serialize,
Available on crate feature auth only.
pub fn set<T>(&mut self, key: &str, value: T) -> Result<(), Error>where
T: Serialize,
auth only.Set a value in the session
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("user_id", 123)?;
session.set("username", "alice")?;Sourcepub fn delete(&mut self, key: &str) -> Option<Value>
Available on crate feature auth only.
pub fn delete(&mut self, key: &str) -> Option<Value>
auth only.Delete a key from the session
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("temp", "value")?;
assert!(session.contains_key("temp"));
session.delete("temp");
assert!(!session.contains_key("temp"));Sourcepub fn contains_key(&self, key: &str) -> bool
Available on crate feature auth only.
pub fn contains_key(&self, key: &str) -> bool
auth only.Check if a key exists in the session
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("key", "value")?;
assert!(session.contains_key("key"));
assert!(!session.contains_key("nonexistent"));Sourcepub fn get_or_create_key(&mut self) -> &str
Available on crate feature auth only.
pub fn get_or_create_key(&mut self) -> &str
auth only.Get the session key (creates one if it doesn’t exist)
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
let key = session.get_or_create_key();
assert!(!key.is_empty());Sourcepub fn generate_key() -> String
Available on crate feature auth only.
pub fn generate_key() -> String
auth only.Generate a new random session key
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let key = Session::<InMemorySessionBackend>::generate_key();
assert!(!key.is_empty());
assert!(key.len() > 20);Sourcepub async fn flush(&mut self) -> Result<(), SessionError>
Available on crate feature auth only.
pub async fn flush(&mut self) -> Result<(), SessionError>
auth only.Flush the session (delete all data and create new key)
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("key", "value")?;
let old_key = session.get_or_create_key().to_string();
session.flush().await?;
// Data is cleared
assert!(!session.contains_key("key"));
// New session key is generated
assert_ne!(session.get_or_create_key(), old_key);Sourcepub async fn cycle_key(&mut self) -> Result<(), SessionError>
Available on crate feature auth only.
pub async fn cycle_key(&mut self) -> Result<(), SessionError>
auth only.Cycle the session key (keep data but change key)
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("user_id", 123)?;
let old_key = session.get_or_create_key().to_string();
session.cycle_key().await?;
// Data is preserved
let user_id: i32 = session.get("user_id")?.unwrap();
assert_eq!(user_id, 123);
// Session key has changed
assert_ne!(session.get_or_create_key(), old_key);Sourcepub async fn regenerate_id(&mut self) -> Result<(), SessionError>
Available on crate feature auth only.
pub async fn regenerate_id(&mut self) -> Result<(), SessionError>
auth only.Regenerate session ID to prevent session fixation attacks
This method creates a new session ID while preserving all session data. It should be called after authentication (login) to prevent session fixation attacks.
Security
Session fixation is an attack where an attacker sets a victim’s session ID to a known value. By regenerating the session ID after login, we ensure that even if an attacker knew the pre-authentication session ID, it becomes invalid after the user logs in.
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// User logs in
session.set("user_id", 123)?;
// Regenerate session ID to prevent session fixation
session.regenerate_id().await?;
// Session data is preserved
let user_id: i32 = session.get("user_id")?.unwrap();
assert_eq!(user_id, 123);Sourcepub async fn save(&mut self) -> Result<(), SessionError>
Available on crate feature auth only.
pub async fn save(&mut self) -> Result<(), SessionError>
auth only.Save the session to the backend
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("data", "value")?;
session.save().await?;Sourcepub fn is_modified(&self) -> bool
Available on crate feature auth only.
pub fn is_modified(&self) -> bool
auth only.Check if the session has been modified
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
assert!(!session.is_modified());
session.set("key", "value")?;
assert!(session.is_modified());Sourcepub fn is_accessed(&self) -> bool
Available on crate feature auth only.
pub fn is_accessed(&self) -> bool
auth only.Check if the session has been accessed
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
assert!(!session.is_accessed());
session.get::<String>("key")?;
assert!(session.is_accessed());Sourcepub fn session_key(&self) -> Option<&str>
Available on crate feature auth only.
pub fn session_key(&self) -> Option<&str>
auth only.Get the current session key (if any)
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let session = Session::new(backend);
assert!(session.session_key().is_none());Sourcepub fn keys(&mut self) -> Vec<String>
Available on crate feature auth only.
pub fn keys(&mut self) -> Vec<String>
auth only.Get all session keys
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("user_id", 123)?;
session.set("username", "alice")?;
let keys = session.keys();
assert_eq!(keys.len(), 2);
assert!(keys.contains(&"user_id".to_string()));
assert!(keys.contains(&"username".to_string()));Sourcepub fn values(&mut self) -> Vec<&Value>
Available on crate feature auth only.
pub fn values(&mut self) -> Vec<&Value>
auth only.Get all session values
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("count", 42)?;
session.set("name", "test")?;
let values = session.values();
assert_eq!(values.len(), 2);Sourcepub fn items(&mut self) -> Vec<(&String, &Value)>
Available on crate feature auth only.
pub fn items(&mut self) -> Vec<(&String, &Value)>
auth only.Get all session key-value pairs
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("user_id", 123)?;
session.set("role", "admin")?;
let items = session.items();
assert_eq!(items.len(), 2);
// Find specific item
let user_id_item = items.iter()
.find(|(k, _)| k.as_str() == "user_id")
.unwrap();
assert_eq!(user_id_item.1.as_i64().unwrap(), 123);Sourcepub fn clear(&mut self)
Available on crate feature auth only.
pub fn clear(&mut self)
auth only.Clear all session data
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("user_id", 123)?;
session.set("username", "alice")?;
assert_eq!(session.keys().len(), 2);
session.clear();
assert_eq!(session.keys().len(), 0);
assert!(session.is_modified());Sourcepub fn mark_modified(&mut self)
Available on crate feature auth only.
pub fn mark_modified(&mut self)
auth only.Manually mark the session as modified
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
assert!(!session.is_modified());
session.mark_modified();
assert!(session.is_modified());Sourcepub fn mark_unmodified(&mut self)
Available on crate feature auth only.
pub fn mark_unmodified(&mut self)
auth only.Manually mark the session as unmodified
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
session.set("key", "value")?;
assert!(session.is_modified());
session.mark_unmodified();
assert!(!session.is_modified());Sourcepub fn set_timeout(&mut self, timeout: u64)
Available on crate feature auth only.
pub fn set_timeout(&mut self, timeout: u64)
auth only.Set session timeout in seconds
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// Set timeout to 1 hour (3600 seconds)
session.set_timeout(3600);Sourcepub fn get_timeout(&self) -> u64
Available on crate feature auth only.
pub fn get_timeout(&self) -> u64
auth only.Get session timeout in seconds
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let session = Session::new(backend);
// Default timeout is 1800 seconds (30 minutes)
assert_eq!(session.get_timeout(), 1800);Sourcepub fn update_activity(&mut self)
Available on crate feature auth only.
pub fn update_activity(&mut self)
auth only.Update last activity timestamp
This should be called on each request to update the session’s last activity time.
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// Update activity timestamp
session.update_activity();Sourcepub fn get_last_activity(&self) -> Option<DateTime<Utc>>
Available on crate feature auth only.
pub fn get_last_activity(&self) -> Option<DateTime<Utc>>
auth only.Get last activity timestamp
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let session = Session::new(backend);
// Last activity is set on creation
assert!(session.get_last_activity().is_some());Sourcepub fn is_timed_out(&self) -> bool
Available on crate feature auth only.
pub fn is_timed_out(&self) -> bool
auth only.Check if session has timed out
Returns true if the session has exceeded its timeout period based on last activity.
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// New session should not be timed out
assert!(!session.is_timed_out());
// Set very short timeout
session.set_timeout(0);
// Still not timed out immediately (last_activity is now)
assert!(!session.is_timed_out());Sourcepub fn validate_timeout(&self) -> Result<(), SessionError>
Available on crate feature auth only.
pub fn validate_timeout(&self) -> Result<(), SessionError>
auth only.Validate session timeout
Returns an error if the session has timed out.
Example
use reinhardt_auth::sessions::Session;
use reinhardt_auth::sessions::backends::InMemorySessionBackend;
let backend = InMemorySessionBackend::new();
let mut session = Session::new(backend);
// Validate timeout (should succeed for new session)
session.validate_timeout()?;Trait Implementations