pub enum Error {
Show 30 variants
NoHomePathError,
CertPathError {
path: PathBuf,
},
CertMultipleKeys {
count: usize,
path: PathBuf,
},
CertParseError {
path: PathBuf,
},
NoNativeCertsError {
err: Error,
},
LoadNativeCertsErrors {
errors: Vec<Error>,
},
DockerResponseServerError {
status_code: u16,
message: String,
},
JsonDataError {
message: String,
column: usize,
},
APIVersionParseError {},
RequestTimeoutError,
DockerStreamError {
error: String,
},
DockerContainerWaitError {
error: String,
code: i64,
},
MissingSessionBuildkitError {},
MissingVersionBuildkitError {},
JsonSerdeError {
err: Error,
},
StrParseError {
err: Utf8Error,
},
IOError {
err: Error,
},
StrFmtError {
err: Error,
},
HttpClientError {
err: Error,
},
HyperResponseError {
err: Error,
},
URLEncodedError {
err: Error,
},
URLParseError {
err: ParseError,
},
InvalidURIError {
err: InvalidUri,
},
InvalidURIPartsError {
err: InvalidUriParts,
},
HyperLegacyError {
err: Error,
},
UnsupportedURISchemeError {
uri: String,
},
SocketNotFoundError(String),
HttpHeaderNotFoundError(String),
HttpHeaderToStrError {
err: ToStrError,
},
Base64DecodeError {
err: DecodeError,
},
}test only.Expand description
Generic Docker errors
Variants
NoHomePathError
ssl_providerless only.Error emitted during client instantiation when the DOCKER_CERT_PATH environment variable
is invalid.
CertPathError
ssl_providerless only.Generic error when reading a certificate from the filesystem
CertMultipleKeys
ssl_providerless only.Error emitted when multiple keys are found in a certificate file
Fields
CertParseError
ssl_providerless only.Parse error for RSA encrypted keys
NoNativeCertsError
ssl_providerless only.Error emitted when the client is unable to parse a native pki cert for SSL
LoadNativeCertsErrors
ssl_providerless only.Error emitted when the client is unable to load native certs for SSL
DockerResponseServerError
Generic error emitted by the docker server.
Fields
JsonDataError
Error facilitating debugging failed JSON parsing.
Fields
APIVersionParseError
Error emitted when the docker is requested to build with buildkit without a session id
RequestTimeoutError
Error emitted when a request times out.
DockerStreamError
Error emitted mid-stream as part of a successful docker operation
DockerContainerWaitError
Error emitted as part of a container wait response
Fields
MissingSessionBuildkitError
Error emitted when a session is not provided to the buildkit engine
MissingVersionBuildkitError
Error emitted when a session is not provided to the buildkit engine
JsonSerdeError
Error emitted when JSON fails to serialize.
StrParseError
Error emitted when log output generates an I/O error.
IOError
Error emitted from an I/O error.
StrFmtError
Error emitted from a formatting error.
HttpClientError
Error emitted from an HTTP error.
HyperResponseError
Error emitted from an HTTP error.
URLEncodedError
Error emitted when serde fails to urlencod a struct of options
URLParseError
Error encountered when parsing a URL
Fields
err: ParseErrorThe original error emitted.
InvalidURIError
Error emitted when encoding a URI
Fields
err: InvalidUriThe original error emitted.
InvalidURIPartsError
Error emitted when encoding a URIParts
Fields
err: InvalidUriPartsThe original error emitted.
HyperLegacyError
http or pipe or ssh only.Error that is never emitted
UnsupportedURISchemeError
Error emitted when connecting to a URI with an unsupported scheme
SocketNotFoundError(String)
Error emitted when the Docker socket file is not found at the expected location.
HttpHeaderNotFoundError(String)
Error emitted when an expected header is not found in the HTTP response.
HttpHeaderToStrError
Error encountered when getting a string slice from a HTTP header
Fields
err: ToStrErrorThe original error emitted.
Base64DecodeError
Error emitted when failing to decode a base64 string
Fields
err: DecodeErrorThe original error emitted.