pub struct ExampleBuilder { /* private fields */ }openapi and non-WebAssembly only.Expand description
Implementations
Sourceimpl ExampleBuilder
impl ExampleBuilder
Sourcepub fn new() -> ExampleBuilder
Available on crate feature rest only.
pub fn new() -> ExampleBuilder
rest only.Constructs a new ExampleBuilder.
Sourceimpl ExampleBuilder
impl ExampleBuilder
Sourcepub fn summary<S>(self, summary: S) -> ExampleBuilder
Available on crate feature rest only.
pub fn summary<S>(self, summary: S) -> ExampleBuilder
rest only.Add or change a short description for the Example. Setting this to empty String
will make it not render in the generated OpenAPI document.
Sourcepub fn description<D>(self, description: D) -> ExampleBuilder
Available on crate feature rest only.
pub fn description<D>(self, description: D) -> ExampleBuilder
rest only.Add or change a long description for the Example. Markdown syntax is supported for rich
text representation.
Setting this to empty String will make it not render in the generated
OpenAPI document.
Sourcepub fn value(self, value: Option<Value>) -> ExampleBuilder
Available on crate feature rest only.
pub fn value(self, value: Option<Value>) -> ExampleBuilder
rest only.Add or change embedded literal example value. Example::value and Example::external_value
are mutually exclusive.
Sourcepub fn external_value<E>(self, external_value: E) -> ExampleBuilder
Available on crate feature rest only.
pub fn external_value<E>(self, external_value: E) -> ExampleBuilder
rest only.Add or change an URI that points to a literal example value. Example::external_value
provides the capability to references an example that cannot be easily included
in JSON or YAML. Example::value and Example::external_value are mutually exclusive.
Setting this to an empty String will make the field not to render in the generated OpenAPI document.